/*!
LTC2937: Programmable Six Channel Sequencer and Voltage Supervisor with EEPROM

@verbatim
The LTC®2937 is a six-channel power supply sequencer and voltage supervisor.
Supplies are ENABLED or disabled with precise user controlled order and time
spacing. To detect power supply output faults during sequencing and monitoring,
the LTC2937 accurately monitors supply turn-ON/-OFF delays and output voltage
levels. In the event of a fault, response actions include complete power supply
shutdown and optional restarts. Root cause of power faults are logged to EEPROM.
For systems with high supply count, a simple single wire connection between
multiple LTC2937 devices allows sequencing expansion to 300 supplies. After
successful sequencing and supply voltage stabilization, the reset output pulls
high to initiate microprocessor or other system activity. To accommodate supply
margin testing, the reset output can be disabled. Upon supply turn-OFF,
integrated current sources are available as needed to discharge slowly decaying
supplies. Configuration EEPROM supports autonomous operation without software.
@endverbatim

http://www.linear.com/product/LTC2937

http://www.linear.com/product/LTC2937#demoboards

REVISION HISTORY
$Revision$
$Date$

Copyright (c) 2016, Linear Technology Corp.(LTC)
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1.  Redistributions  of source code must retain the above copyright notice, this
    list  of conditions and the following disclaimer.

2.  Redistributions  in  binary  form must reproduce the above copyright notice,
    this  list of conditions and  the following disclaimer in the  documentation
    and/or other materials provided with the distribution.

THIS  SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY  EXPRESS  OR  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES   OF  MERCHANTABILITY  AND  FITNESS  FOR  A  PARTICULAR  PURPOSE  ARE
DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY  DIRECT,  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING,  BUT  NOT  LIMITED  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS  OF  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY  THEORY  OF  LIABILITY,  WHETHER  IN  CONTRACT,  STRICT  LIABILITY,  OR TORT
(INCLUDING  NEGLIGENCE  OR  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The  views and conclusions contained in the software and documentation are those
of  the authors and should not be interpreted as representing official policies,
either expressed or implied, of Linear Technology Corp.

The Linear Technology Linduino is not affiliated with the official Arduino team.
However,  the Linduino is only possible because of the Arduino team's commitment
to   the   open-source   community.   Please,  visit  http://www.arduino.cc  and
http://store.arduino.cc,  and consider  a purchase  that  will  help fund  their
ongoing work.

Generated on: 2016-07-27
*/

/*! @file
 *  @ingroup LTC2937
 *  @brief LTC2937 Register Map Definition Header
 *
 *
 *  This file contains LTC2937 definitions for each command_code as well as
 *  each individual bit field for the case when a register contains multiple
 *  bit-packed fields smaller than the register width.
 *  Each bit field name is prepended with LTC2937_.
 *  Each bit field has individual definitions for its _SIZE, _OFFSET (LSB) and _MASK,
 *  as well as the three fields stored in a single 16-bit word for use with the access
 *  functions provided by LTC2937.c and LTC2937_SDK.h.
 *  In the case that the bit field contents represent an enumeration, _PRESET
 *  definitions exists to translate from human readable format to the encoded value.
 *  See @ref LTC2937_register_map for detailed descriptions of each bit field.
 */

/*! @defgroup LTC2937_register_map LTC2937 Register Map Definitions
 *  @ingroup LTC2937
 */

#ifndef LTC2937_REG_DEFS_H_
#define LTC2937_REG_DEFS_H_

#define LTC2937_ADDR_36 0x36 //!<LTC2937 I2C address in 7-bit format: GLOBAL
#define LTC2937_ADDR_37 0x37 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LLL
#define LTC2937_ADDR_38 0x38 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LLZ
#define LTC2937_ADDR_39 0x39 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LLH
#define LTC2937_ADDR_3a 0x3a //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LZL
#define LTC2937_ADDR_3b 0x3b //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LZZ
#define LTC2937_ADDR_3c 0x3c //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LZH
#define LTC2937_ADDR_3d 0x3d //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LHL
#define LTC2937_ADDR_3e 0x3e //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LHZ
#define LTC2937_ADDR_3f 0x3f //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=LHH
#define LTC2937_ADDR_40 0x40 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZLL
#define LTC2937_ADDR_41 0x41 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZLZ
#define LTC2937_ADDR_42 0x42 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZLH
#define LTC2937_ADDR_43 0x43 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZZL
#define LTC2937_ADDR_44 0x44 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZZZ
#define LTC2937_ADDR_45 0x45 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZZH
#define LTC2937_ADDR_46 0x46 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZHL
#define LTC2937_ADDR_47 0x47 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZHZ
#define LTC2937_ADDR_48 0x48 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=ZHH
#define LTC2937_ADDR_49 0x49 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HLL
#define LTC2937_ADDR_4a 0x4a //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HLZ
#define LTC2937_ADDR_4b 0x4b //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HLH
#define LTC2937_ADDR_4c 0x4c //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HZL
#define LTC2937_ADDR_4d 0x4d //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HZZ
#define LTC2937_ADDR_4e 0x4e //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HZH
#define LTC2937_ADDR_4f 0x4f //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HHL
#define LTC2937_ADDR_50 0x50 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HHZ
#define LTC2937_ADDR_51 0x51 //!<LTC2937 I2C address in 7-bit format: ASEL[3:1]=HHH

/*! @defgroup LTC2937_WRITE_PROTECTION_CMD WRITE_PROTECTION_CMD
 *  @ingroup LTC2937_register_map
 *  @brief WRITE_PROTECTION_CMD Register
 *
 * |       15:2 |           1 |           0 |
 * |:----------:|:-----------:|:-----------:|
 * | DEVICE_KEY | HW_LOCK_BIT | SW_LOCK_BIT |
 *
 * Contains lock key code and lock bit to prevent accidental changes.
 *   - CommandCode: 0
 *   - Contains Bit Fields:
 *     + @ref LTC2937_DEVICE_KEY "DEVICE_KEY" : Must match against programmed word to change lock bit.
 *     + @ref LTC2937_HW_LOCK_BIT "HW_LOCK_BIT" : State of external WP Input. No register writes are possible when locked.
 *     + @ref LTC2937_SW_LOCK_BIT "SW_LOCK_BIT" : Write lock bit. No register writes are possible when locked.
*/

//!@{
#define LTC2937_WRITE_PROTECTION_CMD_SUBADDR 0
#define LTC2937_WRITE_PROTECTION_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_WRITE_PROTECTION_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_DEVICE_KEY DEVICE_KEY
 *  @ingroup LTC2937_register_map
 *  @brief DEVICE_KEY Bit Field
 *
 *  Must match against programmed word to change lock bit.
 *   - Register: @ref LTC2937_WRITE_PROTECTION_CMD "WRITE_PROTECTION_CMD"
 *   - CommandCode: 0
 *   - Size: 14
 *   - Offset: 2
 *   - MSB: 15
 *   - MASK: 0xFFFC
 *   - Access: R/W
 *   - Default: 3754
 */
//!@{
#define LTC2937_DEVICE_KEY_SUBADDR LTC2937_WRITE_PROTECTION_CMD_SUBADDR //!< @ref LTC2937_DEVICE_KEY "DEVICE_KEY"
#define LTC2937_DEVICE_KEY_SIZE 14
#define LTC2937_DEVICE_KEY_OFFSET 2
#define LTC2937_DEVICE_KEY_MSK 0xFFFC
#define LTC2937_DEVICE_KEY (LTC2937_DEVICE_KEY_OFFSET << 12 | (LTC2937_DEVICE_KEY_SIZE - 1) << 8 | LTC2937_DEVICE_KEY_SUBADDR)
#define LTC2937_DEVICE_KEY_PRESET_DEFAULT 3754
//!@}
/*! @defgroup LTC2937_HW_LOCK_BIT HW_LOCK_BIT
 *  @ingroup LTC2937_register_map
 *  @brief HW_LOCK_BIT Bit Field
 *
 *  State of external WP Input. No register writes are possible when locked.
 *   - Register: @ref LTC2937_WRITE_PROTECTION_CMD "WRITE_PROTECTION_CMD"
 *   - CommandCode: 0
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R/W
 *   - Default: n/a
 */
//!@{
#define LTC2937_HW_LOCK_BIT_SUBADDR LTC2937_WRITE_PROTECTION_CMD_SUBADDR //!< @ref LTC2937_HW_LOCK_BIT "HW_LOCK_BIT"
#define LTC2937_HW_LOCK_BIT_SIZE 1
#define LTC2937_HW_LOCK_BIT_OFFSET 1
#define LTC2937_HW_LOCK_BIT_MSK 0x0002
#define LTC2937_HW_LOCK_BIT (LTC2937_HW_LOCK_BIT_OFFSET << 12 | (LTC2937_HW_LOCK_BIT_SIZE - 1) << 8 | LTC2937_HW_LOCK_BIT_SUBADDR)
#define LTC2937_HW_LOCK_BIT_PRESET_UNLOCKED 0
#define LTC2937_HW_LOCK_BIT_PRESET_LOCKED 1
//!@}
/*! @defgroup LTC2937_SW_LOCK_BIT SW_LOCK_BIT
 *  @ingroup LTC2937_register_map
 *  @brief SW_LOCK_BIT Bit Field
 *
 *  Write lock bit. No register writes are possible when locked.
 *   - Register: @ref LTC2937_WRITE_PROTECTION_CMD "WRITE_PROTECTION_CMD"
 *   - CommandCode: 0
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SW_LOCK_BIT_SUBADDR LTC2937_WRITE_PROTECTION_CMD_SUBADDR //!< @ref LTC2937_SW_LOCK_BIT "SW_LOCK_BIT"
#define LTC2937_SW_LOCK_BIT_SIZE 1
#define LTC2937_SW_LOCK_BIT_OFFSET 0
#define LTC2937_SW_LOCK_BIT_MSK 0x0001
#define LTC2937_SW_LOCK_BIT (LTC2937_SW_LOCK_BIT_OFFSET << 12 | (LTC2937_SW_LOCK_BIT_SIZE - 1) << 8 | LTC2937_SW_LOCK_BIT_SUBADDR)
#define LTC2937_SW_LOCK_BIT_PRESET_UNLOCKED 0
#define LTC2937_SW_LOCK_BIT_PRESET_LOCKED 1
//!@}

/*! @defgroup LTC2937_SPECIAL_LOT_CMD SPECIAL_LOT_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SPECIAL_LOT_CMD Register
 *
 * |        15:0 |
 * |:-----------:|
 * | SPECIAL_LOT |
 *
 *   - CommandCode: 1
 *   - Contains Bit Fields:
 *     + @ref LTC2937_SPECIAL_LOT "SPECIAL_LOT" : Returns two bytes indicating a factory special lot number. Users may over write the register with their own information.
*/

//!@{
#define LTC2937_SPECIAL_LOT_CMD_SUBADDR 1
#define LTC2937_SPECIAL_LOT_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SPECIAL_LOT_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_SPECIAL_LOT SPECIAL_LOT
 *  @ingroup LTC2937_register_map
 *  @brief SPECIAL_LOT Bit Field
 *
 *  Returns two bytes indicating a factory special lot number. Users may over write the register with their own information.
 *   - Register: @ref LTC2937_SPECIAL_LOT_CMD "SPECIAL_LOT_CMD"
 *   - CommandCode: 1
 *   - Size: 16
 *   - Offset: 0
 *   - MSB: 15
 *   - MASK: 0xFFFF
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_SPECIAL_LOT_SUBADDR LTC2937_SPECIAL_LOT_CMD_SUBADDR //!< @ref LTC2937_SPECIAL_LOT "SPECIAL_LOT"
#define LTC2937_SPECIAL_LOT_SIZE 16
#define LTC2937_SPECIAL_LOT_OFFSET 0
#define LTC2937_SPECIAL_LOT_MSK 0xFFFF
#define LTC2937_SPECIAL_LOT (LTC2937_SPECIAL_LOT_OFFSET << 12 | (LTC2937_SPECIAL_LOT_SIZE - 1) << 8 | LTC2937_SPECIAL_LOT_SUBADDR)
//!@}

/*! @defgroup LTC2937_ON_OFF_CONTROL_CMD ON_OFF_CONTROL_CMD
 *  @ingroup LTC2937_register_map
 *  @brief ON_OFF_CONTROL_CMD Register
 *
 * | 15:8 |        7 |          6 |               5 |          4 |               3 |             2 |           1 |             0 |
 * |:----:|:--------:|:----------:|:---------------:|:----------:|:---------------:|:-------------:|:-----------:|:-------------:|
 * |  n/a | ON_STATE | I2C_MARGIN | DISCHARGE_START | I2C_ON_OFF | I2C_ON_OFF_MASK | ON_INPUT_MASK | ON_POLARITY | SEQ_DOWN_QUAL |
 *
 * Configures the combination of ON input and/or I2C inputs needed to control sequencing. Also, activates margin mode of operation.
 *   - CommandCode: 2
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ON_STATE "ON_STATE" : Internal ON status
 *     + @ref LTC2937_I2C_MARGIN "I2C_MARGIN" : RSTB disable
 *     + @ref LTC2937_DISCHARGE_START "DISCHARGE_START" : Require or Not Require that all sequenced Voltage Monitor Channels are discharged below their thresholds before sequencing up.
 *     + @ref LTC2937_I2C_ON_OFF "I2C_ON_OFF" : Software/I2C controlled Sequencing.
 *     + @ref LTC2937_I2C_ON_OFF_MASK "I2C_ON_OFF_MASK" : serial bus on_off control mask
 *     + @ref LTC2937_ON_INPUT_MASK "ON_INPUT_MASK" : Determines how part responds to the ON input.
 *     + @ref LTC2937_ON_POLARITY "ON_POLARITY" : Determines polarity of the ON Input. ACTIVEHIGH = Pull ON high to sequence up. ACTIVELOW = Pull ON low to sequence up.
 *     + @ref LTC2937_SEQ_DOWN_QUAL "SEQ_DOWN_QUAL" : Selects Time or Event based Sequence Down.
*/

//!@{
#define LTC2937_ON_OFF_CONTROL_CMD_SUBADDR 2
#define LTC2937_ON_OFF_CONTROL_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_ON_OFF_CONTROL_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ON_STATE ON_STATE
 *  @ingroup LTC2937_register_map
 *  @brief ON_STATE Bit Field
 *
 *  Internal ON status
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 7
 *   - MSB: 7
 *   - MASK: 0x0080
 *   - Access: R/W
 *   - Default: n/a
 */
//!@{
#define LTC2937_ON_STATE_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_ON_STATE "ON_STATE"
#define LTC2937_ON_STATE_SIZE 1
#define LTC2937_ON_STATE_OFFSET 7
#define LTC2937_ON_STATE_MSK 0x0080
#define LTC2937_ON_STATE (LTC2937_ON_STATE_OFFSET << 12 | (LTC2937_ON_STATE_SIZE - 1) << 8 | LTC2937_ON_STATE_SUBADDR)
#define LTC2937_ON_STATE_PRESET_INTERNAL_ON_LOW 0
#define LTC2937_ON_STATE_PRESET_INTERNAL_ON_HIGH 1
//!@}
/*! @defgroup LTC2937_I2C_MARGIN I2C_MARGIN
 *  @ingroup LTC2937_register_map
 *  @brief I2C_MARGIN Bit Field
 *
 *  RSTB disable
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 6
 *   - MSB: 6
 *   - MASK: 0x0040
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_I2C_MARGIN_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_I2C_MARGIN "I2C_MARGIN"
#define LTC2937_I2C_MARGIN_SIZE 1
#define LTC2937_I2C_MARGIN_OFFSET 6
#define LTC2937_I2C_MARGIN_MSK 0x0040
#define LTC2937_I2C_MARGIN (LTC2937_I2C_MARGIN_OFFSET << 12 | (LTC2937_I2C_MARGIN_SIZE - 1) << 8 | LTC2937_I2C_MARGIN_SUBADDR)
#define LTC2937_I2C_MARGIN_PRESET_RSTB_OPERATES_NORMALLY 0
#define LTC2937_I2C_MARGIN_PRESET_RSTB_PULLS_HIGH 1
//!@}
/*! @defgroup LTC2937_DISCHARGE_START DISCHARGE_START
 *  @ingroup LTC2937_register_map
 *  @brief DISCHARGE_START Bit Field
 *
 *  Require or Not Require that all sequenced Voltage Monitor Channels are discharged below their thresholds before sequencing up.
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 5
 *   - MSB: 5
 *   - MASK: 0x0020
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_DISCHARGE_START_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_DISCHARGE_START "DISCHARGE_START"
#define LTC2937_DISCHARGE_START_SIZE 1
#define LTC2937_DISCHARGE_START_OFFSET 5
#define LTC2937_DISCHARGE_START_MSK 0x0020
#define LTC2937_DISCHARGE_START (LTC2937_DISCHARGE_START_OFFSET << 12 | (LTC2937_DISCHARGE_START_SIZE - 1) << 8 | LTC2937_DISCHARGE_START_SUBADDR)
#define LTC2937_DISCHARGE_START_PRESET_DISCHARGE_NOT_REQUIRED 0
#define LTC2937_DISCHARGE_START_PRESET_DISCHARGE_REQUIRED 1
//!@}
/*! @defgroup LTC2937_I2C_ON_OFF I2C_ON_OFF
 *  @ingroup LTC2937_register_map
 *  @brief I2C_ON_OFF Bit Field
 *
 *  Software/I2C controlled Sequencing.
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 4
 *   - MSB: 4
 *   - MASK: 0x0010
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_I2C_ON_OFF_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_I2C_ON_OFF "I2C_ON_OFF"
#define LTC2937_I2C_ON_OFF_SIZE 1
#define LTC2937_I2C_ON_OFF_OFFSET 4
#define LTC2937_I2C_ON_OFF_MSK 0x0010
#define LTC2937_I2C_ON_OFF (LTC2937_I2C_ON_OFF_OFFSET << 12 | (LTC2937_I2C_ON_OFF_SIZE - 1) << 8 | LTC2937_I2C_ON_OFF_SUBADDR)
#define LTC2937_I2C_ON_OFF_PRESET_SEQUENCE_DOWN 0
#define LTC2937_I2C_ON_OFF_PRESET_SEQUENCE_UP 1
//!@}
/*! @defgroup LTC2937_I2C_ON_OFF_MASK I2C_ON_OFF_MASK
 *  @ingroup LTC2937_register_map
 *  @brief I2C_ON_OFF_MASK Bit Field
 *
 *  serial bus on_off control mask
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 3
 *   - MSB: 3
 *   - MASK: 0x0008
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_I2C_ON_OFF_MASK_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_I2C_ON_OFF_MASK "I2C_ON_OFF_MASK"
#define LTC2937_I2C_ON_OFF_MASK_SIZE 1
#define LTC2937_I2C_ON_OFF_MASK_OFFSET 3
#define LTC2937_I2C_ON_OFF_MASK_MSK 0x0008
#define LTC2937_I2C_ON_OFF_MASK (LTC2937_I2C_ON_OFF_MASK_OFFSET << 12 | (LTC2937_I2C_ON_OFF_MASK_SIZE - 1) << 8 | LTC2937_I2C_ON_OFF_MASK_SUBADDR)
#define LTC2937_I2C_ON_OFF_MASK_PRESET_I2C_IGNORE 0
#define LTC2937_I2C_ON_OFF_MASK_PRESET_I2C_LISTEN 1
//!@}
/*! @defgroup LTC2937_ON_INPUT_MASK ON_INPUT_MASK
 *  @ingroup LTC2937_register_map
 *  @brief ON_INPUT_MASK Bit Field
 *
 *  Determines how part responds to the ON input.
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 2
 *   - MSB: 2
 *   - MASK: 0x0004
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ON_INPUT_MASK_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_ON_INPUT_MASK "ON_INPUT_MASK"
#define LTC2937_ON_INPUT_MASK_SIZE 1
#define LTC2937_ON_INPUT_MASK_OFFSET 2
#define LTC2937_ON_INPUT_MASK_MSK 0x0004
#define LTC2937_ON_INPUT_MASK (LTC2937_ON_INPUT_MASK_OFFSET << 12 | (LTC2937_ON_INPUT_MASK_SIZE - 1) << 8 | LTC2937_ON_INPUT_MASK_SUBADDR)
#define LTC2937_ON_INPUT_MASK_PRESET_ON_PIN_IGNORE 0 //!<part ignores the ON input
#define LTC2937_ON_INPUT_MASK_PRESET_ON_PIN_LISTEN 1 //!<part requires the ON input to sequence
//!@}
/*! @defgroup LTC2937_ON_POLARITY ON_POLARITY
 *  @ingroup LTC2937_register_map
 *  @brief ON_POLARITY Bit Field
 *
 *  Determines polarity of the ON Input. ACTIVEHIGH = Pull ON high to sequence up. ACTIVELOW = Pull ON low to sequence up.
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ON_POLARITY_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_ON_POLARITY "ON_POLARITY"
#define LTC2937_ON_POLARITY_SIZE 1
#define LTC2937_ON_POLARITY_OFFSET 1
#define LTC2937_ON_POLARITY_MSK 0x0002
#define LTC2937_ON_POLARITY (LTC2937_ON_POLARITY_OFFSET << 12 | (LTC2937_ON_POLARITY_SIZE - 1) << 8 | LTC2937_ON_POLARITY_SUBADDR)
#define LTC2937_ON_POLARITY_PRESET_ACTIVE_HIGH 0
#define LTC2937_ON_POLARITY_PRESET_ACTIVE_LOW 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_QUAL SEQ_DOWN_QUAL
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_QUAL Bit Field
 *
 *  Selects Time or Event based Sequence Down.
 *   - Register: @ref LTC2937_ON_OFF_CONTROL_CMD "ON_OFF_CONTROL_CMD"
 *   - CommandCode: 2
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_SEQ_DOWN_QUAL_SUBADDR LTC2937_ON_OFF_CONTROL_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_QUAL "SEQ_DOWN_QUAL"
#define LTC2937_SEQ_DOWN_QUAL_SIZE 1
#define LTC2937_SEQ_DOWN_QUAL_OFFSET 0
#define LTC2937_SEQ_DOWN_QUAL_MSK 0x0001
#define LTC2937_SEQ_DOWN_QUAL (LTC2937_SEQ_DOWN_QUAL_OFFSET << 12 | (LTC2937_SEQ_DOWN_QUAL_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_QUAL_SUBADDR)
#define LTC2937_SEQ_DOWN_QUAL_PRESET_DISCHARGE_BASED 0
#define LTC2937_SEQ_DOWN_QUAL_PRESET_TIME_BASED 1
//!@}

/*! @defgroup LTC2937_V_RANGE_CMD V_RANGE_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_RANGE_CMD Register
 *
 * | 15:12 |    11:10 |      9:8 |      7:6 |      5:4 |      3:2 |      1:0 |
 * |:-----:|:--------:|:--------:|:--------:|:--------:|:--------:|:--------:|
 * |   n/a | V6_RANGE | V5_RANGE | V4_RANGE | V3_RANGE | V2_RANGE | V1_RANGE |
 *
 *   - CommandCode: 3
 *   - Contains Bit Fields:
 *     + @ref LTC2937_V6_RANGE "V6_RANGE" : Monitor range setting for Voltage Monitor 6.
 *     + @ref LTC2937_V5_RANGE "V5_RANGE" : Monitor range setting for Voltage Monitor 5.
 *     + @ref LTC2937_V4_RANGE "V4_RANGE" : Monitor range setting for Voltage Monitor 4.
 *     + @ref LTC2937_V3_RANGE "V3_RANGE" : Monitor range setting for Voltage Monitor 3.
 *     + @ref LTC2937_V2_RANGE "V2_RANGE" : Monitor range setting for Voltage Monitor 2.
 *     + @ref LTC2937_V1_RANGE "V1_RANGE" : Monitor range setting for Voltage Monitor 1.
*/

//!@{
#define LTC2937_V_RANGE_CMD_SUBADDR 3
#define LTC2937_V_RANGE_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_RANGE_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_V6_RANGE V6_RANGE
 *  @ingroup LTC2937_register_map
 *  @brief V6_RANGE Bit Field
 *
 *  Monitor range setting for Voltage Monitor 6.
 *   - Register: @ref LTC2937_V_RANGE_CMD "V_RANGE_CMD"
 *   - CommandCode: 3
 *   - Size: 2
 *   - Offset: 10
 *   - MSB: 11
 *   - MASK: 0x0C00
 *   - Access: R/W
 *   - Default: 00
 */
//!@{
#define LTC2937_V6_RANGE_SUBADDR LTC2937_V_RANGE_CMD_SUBADDR //!< @ref LTC2937_V6_RANGE "V6_RANGE"
#define LTC2937_V6_RANGE_SIZE 2
#define LTC2937_V6_RANGE_OFFSET 10
#define LTC2937_V6_RANGE_MSK 0x0C00
#define LTC2937_V6_RANGE (LTC2937_V6_RANGE_OFFSET << 12 | (LTC2937_V6_RANGE_SIZE - 1) << 8 | LTC2937_V6_RANGE_SUBADDR)
#define LTC2937_V6_RANGE_PRESET_HIGH_RANGE 0
#define LTC2937_V6_RANGE_PRESET_LOW_RANGE 1
#define LTC2937_V6_RANGE_PRESET_POSITIVE_ADJUSTABLE 2
#define LTC2937_V6_RANGE_PRESET_NEGATIVE_ADJUSTABLE 3
//!@}
/*! @defgroup LTC2937_V5_RANGE V5_RANGE
 *  @ingroup LTC2937_register_map
 *  @brief V5_RANGE Bit Field
 *
 *  Monitor range setting for Voltage Monitor 5.
 *   - Register: @ref LTC2937_V_RANGE_CMD "V_RANGE_CMD"
 *   - CommandCode: 3
 *   - Size: 2
 *   - Offset: 8
 *   - MSB: 9
 *   - MASK: 0x0300
 *   - Access: R/W
 *   - Default: 00
 */
//!@{
#define LTC2937_V5_RANGE_SUBADDR LTC2937_V_RANGE_CMD_SUBADDR //!< @ref LTC2937_V5_RANGE "V5_RANGE"
#define LTC2937_V5_RANGE_SIZE 2
#define LTC2937_V5_RANGE_OFFSET 8
#define LTC2937_V5_RANGE_MSK 0x0300
#define LTC2937_V5_RANGE (LTC2937_V5_RANGE_OFFSET << 12 | (LTC2937_V5_RANGE_SIZE - 1) << 8 | LTC2937_V5_RANGE_SUBADDR)
#define LTC2937_V5_RANGE_PRESET_HIGH_RANGE 0
#define LTC2937_V5_RANGE_PRESET_LOW_RANGE 1
#define LTC2937_V5_RANGE_PRESET_POSITIVE_ADJUSTABLE 2
#define LTC2937_V5_RANGE_PRESET_NEGATIVE_ADJUSTABLE 3
//!@}
/*! @defgroup LTC2937_V4_RANGE V4_RANGE
 *  @ingroup LTC2937_register_map
 *  @brief V4_RANGE Bit Field
 *
 *  Monitor range setting for Voltage Monitor 4.
 *   - Register: @ref LTC2937_V_RANGE_CMD "V_RANGE_CMD"
 *   - CommandCode: 3
 *   - Size: 2
 *   - Offset: 6
 *   - MSB: 7
 *   - MASK: 0x00C0
 *   - Access: R/W
 *   - Default: 01
 */
//!@{
#define LTC2937_V4_RANGE_SUBADDR LTC2937_V_RANGE_CMD_SUBADDR //!< @ref LTC2937_V4_RANGE "V4_RANGE"
#define LTC2937_V4_RANGE_SIZE 2
#define LTC2937_V4_RANGE_OFFSET 6
#define LTC2937_V4_RANGE_MSK 0x00C0
#define LTC2937_V4_RANGE (LTC2937_V4_RANGE_OFFSET << 12 | (LTC2937_V4_RANGE_SIZE - 1) << 8 | LTC2937_V4_RANGE_SUBADDR)
#define LTC2937_V4_RANGE_PRESET_HIGH_RANGE 0
#define LTC2937_V4_RANGE_PRESET_LOW_RANGE 1
#define LTC2937_V4_RANGE_PRESET_POSITIVE_ADJUSTABLE 2
#define LTC2937_V4_RANGE_PRESET_NEGATIVE_ADJUSTABLE 3
//!@}
/*! @defgroup LTC2937_V3_RANGE V3_RANGE
 *  @ingroup LTC2937_register_map
 *  @brief V3_RANGE Bit Field
 *
 *  Monitor range setting for Voltage Monitor 3.
 *   - Register: @ref LTC2937_V_RANGE_CMD "V_RANGE_CMD"
 *   - CommandCode: 3
 *   - Size: 2
 *   - Offset: 4
 *   - MSB: 5
 *   - MASK: 0x0030
 *   - Access: R/W
 *   - Default: 01
 */
//!@{
#define LTC2937_V3_RANGE_SUBADDR LTC2937_V_RANGE_CMD_SUBADDR //!< @ref LTC2937_V3_RANGE "V3_RANGE"
#define LTC2937_V3_RANGE_SIZE 2
#define LTC2937_V3_RANGE_OFFSET 4
#define LTC2937_V3_RANGE_MSK 0x0030
#define LTC2937_V3_RANGE (LTC2937_V3_RANGE_OFFSET << 12 | (LTC2937_V3_RANGE_SIZE - 1) << 8 | LTC2937_V3_RANGE_SUBADDR)
#define LTC2937_V3_RANGE_PRESET_HIGH_RANGE 0
#define LTC2937_V3_RANGE_PRESET_LOW_RANGE 1
#define LTC2937_V3_RANGE_PRESET_POSITIVE_ADJUSTABLE 2
#define LTC2937_V3_RANGE_PRESET_NEGATIVE_ADJUSTABLE 3
//!@}
/*! @defgroup LTC2937_V2_RANGE V2_RANGE
 *  @ingroup LTC2937_register_map
 *  @brief V2_RANGE Bit Field
 *
 *  Monitor range setting for Voltage Monitor 2.
 *   - Register: @ref LTC2937_V_RANGE_CMD "V_RANGE_CMD"
 *   - CommandCode: 3
 *   - Size: 2
 *   - Offset: 2
 *   - MSB: 3
 *   - MASK: 0x000C
 *   - Access: R/W
 *   - Default: 01
 */
//!@{
#define LTC2937_V2_RANGE_SUBADDR LTC2937_V_RANGE_CMD_SUBADDR //!< @ref LTC2937_V2_RANGE "V2_RANGE"
#define LTC2937_V2_RANGE_SIZE 2
#define LTC2937_V2_RANGE_OFFSET 2
#define LTC2937_V2_RANGE_MSK 0x000C
#define LTC2937_V2_RANGE (LTC2937_V2_RANGE_OFFSET << 12 | (LTC2937_V2_RANGE_SIZE - 1) << 8 | LTC2937_V2_RANGE_SUBADDR)
#define LTC2937_V2_RANGE_PRESET_HIGH_RANGE 0
#define LTC2937_V2_RANGE_PRESET_LOW_RANGE 1
#define LTC2937_V2_RANGE_PRESET_POSITIVE_ADJUSTABLE 2
#define LTC2937_V2_RANGE_PRESET_NEGATIVE_ADJUSTABLE 3
//!@}
/*! @defgroup LTC2937_V1_RANGE V1_RANGE
 *  @ingroup LTC2937_register_map
 *  @brief V1_RANGE Bit Field
 *
 *  Monitor range setting for Voltage Monitor 1.
 *   - Register: @ref LTC2937_V_RANGE_CMD "V_RANGE_CMD"
 *   - CommandCode: 3
 *   - Size: 2
 *   - Offset: 0
 *   - MSB: 1
 *   - MASK: 0x0003
 *   - Access: R/W
 *   - Default: 01
 */
//!@{
#define LTC2937_V1_RANGE_SUBADDR LTC2937_V_RANGE_CMD_SUBADDR //!< @ref LTC2937_V1_RANGE "V1_RANGE"
#define LTC2937_V1_RANGE_SIZE 2
#define LTC2937_V1_RANGE_OFFSET 0
#define LTC2937_V1_RANGE_MSK 0x0003
#define LTC2937_V1_RANGE (LTC2937_V1_RANGE_OFFSET << 12 | (LTC2937_V1_RANGE_SIZE - 1) << 8 | LTC2937_V1_RANGE_SUBADDR)
#define LTC2937_V1_RANGE_PRESET_HIGH_RANGE 0
#define LTC2937_V1_RANGE_PRESET_LOW_RANGE 1
#define LTC2937_V1_RANGE_PRESET_POSITIVE_ADJUSTABLE 2
#define LTC2937_V1_RANGE_PRESET_NEGATIVE_ADJUSTABLE 3
//!@}

/*! @defgroup LTC2937_V_THRESHOLD_1_CMD V_THRESHOLD_1_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_THRESHOLD_1_CMD Register
 *
 * |           15:8 |            7:0 |
 * |:--------------:|:--------------:|
 * | OV_THRESHOLD_1 | UV_THRESHOLD_1 |
 *
 *   - CommandCode: 4
 *   - Contains Bit Fields:
 *     + @ref LTC2937_OV_THRESHOLD_1 "OV_THRESHOLD_1" : Specify V1 OV Threshold.
 *     + @ref LTC2937_UV_THRESHOLD_1 "UV_THRESHOLD_1" : Specify V1 UV Threshold.
*/

//!@{
#define LTC2937_V_THRESHOLD_1_CMD_SUBADDR 4
#define LTC2937_V_THRESHOLD_1_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_THRESHOLD_1_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_OV_THRESHOLD_1 OV_THRESHOLD_1
 *  @ingroup LTC2937_register_map
 *  @brief OV_THRESHOLD_1 Bit Field
 *
 *  Specify V1 OV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_1_CMD "V_THRESHOLD_1_CMD"
 *   - CommandCode: 4
 *   - Size: 8
 *   - Offset: 8
 *   - MSB: 15
 *   - MASK: 0xFF00
 *   - Access: R/W
 *   - Default: 87
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_OV_THRESHOLD_1_SUBADDR LTC2937_V_THRESHOLD_1_CMD_SUBADDR //!< @ref LTC2937_OV_THRESHOLD_1 "OV_THRESHOLD_1"
#define LTC2937_OV_THRESHOLD_1_SIZE 8
#define LTC2937_OV_THRESHOLD_1_OFFSET 8
#define LTC2937_OV_THRESHOLD_1_MSK 0xFF00
#define LTC2937_OV_THRESHOLD_1 (LTC2937_OV_THRESHOLD_1_OFFSET << 12 | (LTC2937_OV_THRESHOLD_1_SIZE - 1) << 8 | LTC2937_OV_THRESHOLD_1_SUBADDR)
//!@}
/*! @defgroup LTC2937_UV_THRESHOLD_1 UV_THRESHOLD_1
 *  @ingroup LTC2937_register_map
 *  @brief UV_THRESHOLD_1 Bit Field
 *
 *  Specify V1 UV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_1_CMD "V_THRESHOLD_1_CMD"
 *   - CommandCode: 4
 *   - Size: 8
 *   - Offset: 0
 *   - MSB: 7
 *   - MASK: 0x00FF
 *   - Access: R/W
 *   - Default: 63
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_UV_THRESHOLD_1_SUBADDR LTC2937_V_THRESHOLD_1_CMD_SUBADDR //!< @ref LTC2937_UV_THRESHOLD_1 "UV_THRESHOLD_1"
#define LTC2937_UV_THRESHOLD_1_SIZE 8
#define LTC2937_UV_THRESHOLD_1_OFFSET 0
#define LTC2937_UV_THRESHOLD_1_MSK 0x00FF
#define LTC2937_UV_THRESHOLD_1 (LTC2937_UV_THRESHOLD_1_OFFSET << 12 | (LTC2937_UV_THRESHOLD_1_SIZE - 1) << 8 | LTC2937_UV_THRESHOLD_1_SUBADDR)
//!@}

/*! @defgroup LTC2937_V_THRESHOLD_2_CMD V_THRESHOLD_2_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_THRESHOLD_2_CMD Register
 *
 * |           15:8 |            7:0 |
 * |:--------------:|:--------------:|
 * | OV_THRESHOLD_2 | UV_THRESHOLD_2 |
 *
 *   - CommandCode: 5
 *   - Contains Bit Fields:
 *     + @ref LTC2937_OV_THRESHOLD_2 "OV_THRESHOLD_2" : Specify V2 OV Threshold.
 *     + @ref LTC2937_UV_THRESHOLD_2 "UV_THRESHOLD_2" : Specify V2 UV Threshold.
*/

//!@{
#define LTC2937_V_THRESHOLD_2_CMD_SUBADDR 5
#define LTC2937_V_THRESHOLD_2_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_THRESHOLD_2_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_OV_THRESHOLD_2 OV_THRESHOLD_2
 *  @ingroup LTC2937_register_map
 *  @brief OV_THRESHOLD_2 Bit Field
 *
 *  Specify V2 OV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_2_CMD "V_THRESHOLD_2_CMD"
 *   - CommandCode: 5
 *   - Size: 8
 *   - Offset: 8
 *   - MSB: 15
 *   - MASK: 0xFF00
 *   - Access: R/W
 *   - Default: 120
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_OV_THRESHOLD_2_SUBADDR LTC2937_V_THRESHOLD_2_CMD_SUBADDR //!< @ref LTC2937_OV_THRESHOLD_2 "OV_THRESHOLD_2"
#define LTC2937_OV_THRESHOLD_2_SIZE 8
#define LTC2937_OV_THRESHOLD_2_OFFSET 8
#define LTC2937_OV_THRESHOLD_2_MSK 0xFF00
#define LTC2937_OV_THRESHOLD_2 (LTC2937_OV_THRESHOLD_2_OFFSET << 12 | (LTC2937_OV_THRESHOLD_2_SIZE - 1) << 8 | LTC2937_OV_THRESHOLD_2_SUBADDR)
//!@}
/*! @defgroup LTC2937_UV_THRESHOLD_2 UV_THRESHOLD_2
 *  @ingroup LTC2937_register_map
 *  @brief UV_THRESHOLD_2 Bit Field
 *
 *  Specify V2 UV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_2_CMD "V_THRESHOLD_2_CMD"
 *   - CommandCode: 5
 *   - Size: 8
 *   - Offset: 0
 *   - MSB: 7
 *   - MASK: 0x00FF
 *   - Access: R/W
 *   - Default: 90
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_UV_THRESHOLD_2_SUBADDR LTC2937_V_THRESHOLD_2_CMD_SUBADDR //!< @ref LTC2937_UV_THRESHOLD_2 "UV_THRESHOLD_2"
#define LTC2937_UV_THRESHOLD_2_SIZE 8
#define LTC2937_UV_THRESHOLD_2_OFFSET 0
#define LTC2937_UV_THRESHOLD_2_MSK 0x00FF
#define LTC2937_UV_THRESHOLD_2 (LTC2937_UV_THRESHOLD_2_OFFSET << 12 | (LTC2937_UV_THRESHOLD_2_SIZE - 1) << 8 | LTC2937_UV_THRESHOLD_2_SUBADDR)
//!@}

/*! @defgroup LTC2937_V_THRESHOLD_3_CMD V_THRESHOLD_3_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_THRESHOLD_3_CMD Register
 *
 * |           15:8 |            7:0 |
 * |:--------------:|:--------------:|
 * | OV_THRESHOLD_3 | UV_THRESHOLD_3 |
 *
 *   - CommandCode: 6
 *   - Contains Bit Fields:
 *     + @ref LTC2937_OV_THRESHOLD_3 "OV_THRESHOLD_3" : Specify V3 OV Threshold.
 *     + @ref LTC2937_UV_THRESHOLD_3 "UV_THRESHOLD_3" : Specify V3 UV Threshold.
*/

//!@{
#define LTC2937_V_THRESHOLD_3_CMD_SUBADDR 6
#define LTC2937_V_THRESHOLD_3_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_THRESHOLD_3_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_OV_THRESHOLD_3 OV_THRESHOLD_3
 *  @ingroup LTC2937_register_map
 *  @brief OV_THRESHOLD_3 Bit Field
 *
 *  Specify V3 OV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_3_CMD "V_THRESHOLD_3_CMD"
 *   - CommandCode: 6
 *   - Size: 8
 *   - Offset: 8
 *   - MSB: 15
 *   - MASK: 0xFF00
 *   - Access: R/W
 *   - Default: 153
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_OV_THRESHOLD_3_SUBADDR LTC2937_V_THRESHOLD_3_CMD_SUBADDR //!< @ref LTC2937_OV_THRESHOLD_3 "OV_THRESHOLD_3"
#define LTC2937_OV_THRESHOLD_3_SIZE 8
#define LTC2937_OV_THRESHOLD_3_OFFSET 8
#define LTC2937_OV_THRESHOLD_3_MSK 0xFF00
#define LTC2937_OV_THRESHOLD_3 (LTC2937_OV_THRESHOLD_3_OFFSET << 12 | (LTC2937_OV_THRESHOLD_3_SIZE - 1) << 8 | LTC2937_OV_THRESHOLD_3_SUBADDR)
//!@}
/*! @defgroup LTC2937_UV_THRESHOLD_3 UV_THRESHOLD_3
 *  @ingroup LTC2937_register_map
 *  @brief UV_THRESHOLD_3 Bit Field
 *
 *  Specify V3 UV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_3_CMD "V_THRESHOLD_3_CMD"
 *   - CommandCode: 6
 *   - Size: 8
 *   - Offset: 0
 *   - MSB: 7
 *   - MASK: 0x00FF
 *   - Access: R/W
 *   - Default: 117
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_UV_THRESHOLD_3_SUBADDR LTC2937_V_THRESHOLD_3_CMD_SUBADDR //!< @ref LTC2937_UV_THRESHOLD_3 "UV_THRESHOLD_3"
#define LTC2937_UV_THRESHOLD_3_SIZE 8
#define LTC2937_UV_THRESHOLD_3_OFFSET 0
#define LTC2937_UV_THRESHOLD_3_MSK 0x00FF
#define LTC2937_UV_THRESHOLD_3 (LTC2937_UV_THRESHOLD_3_OFFSET << 12 | (LTC2937_UV_THRESHOLD_3_SIZE - 1) << 8 | LTC2937_UV_THRESHOLD_3_SUBADDR)
//!@}

/*! @defgroup LTC2937_V_THRESHOLD_4_CMD V_THRESHOLD_4_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_THRESHOLD_4_CMD Register
 *
 * |           15:8 |            7:0 |
 * |:--------------:|:--------------:|
 * | OV_THRESHOLD_4 | UV_THRESHOLD_4 |
 *
 *   - CommandCode: 7
 *   - Contains Bit Fields:
 *     + @ref LTC2937_OV_THRESHOLD_4 "OV_THRESHOLD_4" : Specify V4 OV Threshold.
 *     + @ref LTC2937_UV_THRESHOLD_4 "UV_THRESHOLD_4" : Specify V4 UV Threshold.
*/

//!@{
#define LTC2937_V_THRESHOLD_4_CMD_SUBADDR 7
#define LTC2937_V_THRESHOLD_4_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_THRESHOLD_4_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_OV_THRESHOLD_4 OV_THRESHOLD_4
 *  @ingroup LTC2937_register_map
 *  @brief OV_THRESHOLD_4 Bit Field
 *
 *  Specify V4 OV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_4_CMD "V_THRESHOLD_4_CMD"
 *   - CommandCode: 7
 *   - Size: 8
 *   - Offset: 8
 *   - MSB: 15
 *   - MASK: 0xFF00
 *   - Access: R/W
 *   - Default: 230
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_OV_THRESHOLD_4_SUBADDR LTC2937_V_THRESHOLD_4_CMD_SUBADDR //!< @ref LTC2937_OV_THRESHOLD_4 "OV_THRESHOLD_4"
#define LTC2937_OV_THRESHOLD_4_SIZE 8
#define LTC2937_OV_THRESHOLD_4_OFFSET 8
#define LTC2937_OV_THRESHOLD_4_MSK 0xFF00
#define LTC2937_OV_THRESHOLD_4 (LTC2937_OV_THRESHOLD_4_OFFSET << 12 | (LTC2937_OV_THRESHOLD_4_SIZE - 1) << 8 | LTC2937_OV_THRESHOLD_4_SUBADDR)
//!@}
/*! @defgroup LTC2937_UV_THRESHOLD_4 UV_THRESHOLD_4
 *  @ingroup LTC2937_register_map
 *  @brief UV_THRESHOLD_4 Bit Field
 *
 *  Specify V4 UV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_4_CMD "V_THRESHOLD_4_CMD"
 *   - CommandCode: 7
 *   - Size: 8
 *   - Offset: 0
 *   - MSB: 7
 *   - MASK: 0x00FF
 *   - Access: R/W
 *   - Default: 180
 *   - Format: LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_UV_THRESHOLD_4_SUBADDR LTC2937_V_THRESHOLD_4_CMD_SUBADDR //!< @ref LTC2937_UV_THRESHOLD_4 "UV_THRESHOLD_4"
#define LTC2937_UV_THRESHOLD_4_SIZE 8
#define LTC2937_UV_THRESHOLD_4_OFFSET 0
#define LTC2937_UV_THRESHOLD_4_MSK 0x00FF
#define LTC2937_UV_THRESHOLD_4 (LTC2937_UV_THRESHOLD_4_OFFSET << 12 | (LTC2937_UV_THRESHOLD_4_SIZE - 1) << 8 | LTC2937_UV_THRESHOLD_4_SUBADDR)
//!@}

/*! @defgroup LTC2937_V_THRESHOLD_5_CMD V_THRESHOLD_5_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_THRESHOLD_5_CMD Register
 *
 * |           15:8 |            7:0 |
 * |:--------------:|:--------------:|
 * | OV_THRESHOLD_5 | UV_THRESHOLD_5 |
 *
 *   - CommandCode: 8
 *   - Contains Bit Fields:
 *     + @ref LTC2937_OV_THRESHOLD_5 "OV_THRESHOLD_5" : Specify V5 OV Threshold..
 *     + @ref LTC2937_UV_THRESHOLD_5 "UV_THRESHOLD_5" : Specify V5 UV Threshold.
*/

//!@{
#define LTC2937_V_THRESHOLD_5_CMD_SUBADDR 8
#define LTC2937_V_THRESHOLD_5_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_THRESHOLD_5_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_OV_THRESHOLD_5 OV_THRESHOLD_5
 *  @ingroup LTC2937_register_map
 *  @brief OV_THRESHOLD_5 Bit Field
 *
 *  Specify V5 OV Threshold..
 *   - Register: @ref LTC2937_V_THRESHOLD_5_CMD "V_THRESHOLD_5_CMD"
 *   - CommandCode: 8
 *   - Size: 8
 *   - Offset: 8
 *   - MSB: 15
 *   - MASK: 0xFF00
 *   - Access: R/W
 *   - Default: 137
 *   - Format: LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_OV_THRESHOLD_5_SUBADDR LTC2937_V_THRESHOLD_5_CMD_SUBADDR //!< @ref LTC2937_OV_THRESHOLD_5 "OV_THRESHOLD_5"
#define LTC2937_OV_THRESHOLD_5_SIZE 8
#define LTC2937_OV_THRESHOLD_5_OFFSET 8
#define LTC2937_OV_THRESHOLD_5_MSK 0xFF00
#define LTC2937_OV_THRESHOLD_5 (LTC2937_OV_THRESHOLD_5_OFFSET << 12 | (LTC2937_OV_THRESHOLD_5_SIZE - 1) << 8 | LTC2937_OV_THRESHOLD_5_SUBADDR)
//!@}
/*! @defgroup LTC2937_UV_THRESHOLD_5 UV_THRESHOLD_5
 *  @ingroup LTC2937_register_map
 *  @brief UV_THRESHOLD_5 Bit Field
 *
 *  Specify V5 UV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_5_CMD "V_THRESHOLD_5_CMD"
 *   - CommandCode: 8
 *   - Size: 8
 *   - Offset: 0
 *   - MSB: 7
 *   - MASK: 0x00FF
 *   - Access: R/W
 *   - Default: 104
 *   - Format: LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_UV_THRESHOLD_5_SUBADDR LTC2937_V_THRESHOLD_5_CMD_SUBADDR //!< @ref LTC2937_UV_THRESHOLD_5 "UV_THRESHOLD_5"
#define LTC2937_UV_THRESHOLD_5_SIZE 8
#define LTC2937_UV_THRESHOLD_5_OFFSET 0
#define LTC2937_UV_THRESHOLD_5_MSK 0x00FF
#define LTC2937_UV_THRESHOLD_5 (LTC2937_UV_THRESHOLD_5_OFFSET << 12 | (LTC2937_UV_THRESHOLD_5_SIZE - 1) << 8 | LTC2937_UV_THRESHOLD_5_SUBADDR)
//!@}

/*! @defgroup LTC2937_V_THRESHOLD_6_CMD V_THRESHOLD_6_CMD
 *  @ingroup LTC2937_register_map
 *  @brief V_THRESHOLD_6_CMD Register
 *
 * |           15:8 |            7:0 |
 * |:--------------:|:--------------:|
 * | OV_THRESHOLD_6 | UV_THRESHOLD_6 |
 *
 *   - CommandCode: 9
 *   - Contains Bit Fields:
 *     + @ref LTC2937_OV_THRESHOLD_6 "OV_THRESHOLD_6" : Specify V6 OV Threshold.
 *     + @ref LTC2937_UV_THRESHOLD_6 "UV_THRESHOLD_6" : Specify V6 UV Threshold.
*/

//!@{
#define LTC2937_V_THRESHOLD_6_CMD_SUBADDR 9
#define LTC2937_V_THRESHOLD_6_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_V_THRESHOLD_6_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_OV_THRESHOLD_6 OV_THRESHOLD_6
 *  @ingroup LTC2937_register_map
 *  @brief OV_THRESHOLD_6 Bit Field
 *
 *  Specify V6 OV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_6_CMD "V_THRESHOLD_6_CMD"
 *   - CommandCode: 9
 *   - Size: 8
 *   - Offset: 8
 *   - MSB: 15
 *   - MASK: 0xFF00
 *   - Access: R/W
 *   - Default: 230
 *   - Format: LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_OV_THRESHOLD_6_SUBADDR LTC2937_V_THRESHOLD_6_CMD_SUBADDR //!< @ref LTC2937_OV_THRESHOLD_6 "OV_THRESHOLD_6"
#define LTC2937_OV_THRESHOLD_6_SIZE 8
#define LTC2937_OV_THRESHOLD_6_OFFSET 8
#define LTC2937_OV_THRESHOLD_6_MSK 0xFF00
#define LTC2937_OV_THRESHOLD_6 (LTC2937_OV_THRESHOLD_6_OFFSET << 12 | (LTC2937_OV_THRESHOLD_6_SIZE - 1) << 8 | LTC2937_OV_THRESHOLD_6_SUBADDR)
//!@}
/*! @defgroup LTC2937_UV_THRESHOLD_6 UV_THRESHOLD_6
 *  @ingroup LTC2937_register_map
 *  @brief UV_THRESHOLD_6 Bit Field
 *
 *  Specify V6 UV Threshold.
 *   - Register: @ref LTC2937_V_THRESHOLD_6_CMD "V_THRESHOLD_6_CMD"
 *   - CommandCode: 9
 *   - Size: 8
 *   - Offset: 0
 *   - MSB: 7
 *   - MASK: 0x00FF
 *   - Access: R/W
 *   - Default: 180
 *   - Format: LTC2937_VOLTS_TO_TE_HR, LTC2937_VOLTS_TO_TE_LR, LTC2937_VOLTS_TO_TE_AR
 */
//!@{
#define LTC2937_UV_THRESHOLD_6_SUBADDR LTC2937_V_THRESHOLD_6_CMD_SUBADDR //!< @ref LTC2937_UV_THRESHOLD_6 "UV_THRESHOLD_6"
#define LTC2937_UV_THRESHOLD_6_SIZE 8
#define LTC2937_UV_THRESHOLD_6_OFFSET 0
#define LTC2937_UV_THRESHOLD_6_MSK 0x00FF
#define LTC2937_UV_THRESHOLD_6 (LTC2937_UV_THRESHOLD_6_OFFSET << 12 | (LTC2937_UV_THRESHOLD_6_SIZE - 1) << 8 | LTC2937_UV_THRESHOLD_6_SUBADDR)
//!@}

/*! @defgroup LTC2937_TON_TIMERS_1_CMD TON_TIMERS_1_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TON_TIMERS_1_CMD Register
 *
 * |     15:13 |        12:0 |
 * |:---------:|:-----------:|
 * | TON_MAX_1 | TON_DELAY_1 |
 *
 *   - CommandCode: 10
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TON_MAX_1 "TON_MAX_1" : Sets the maximum voltage monitor rise time for Channel 1.
 *     + @ref LTC2937_TON_DELAY_1 "TON_DELAY_1" : Sets time delay between the start of V1's selected sequence position and the release of EN1.
*/

//!@{
#define LTC2937_TON_TIMERS_1_CMD_SUBADDR 10
#define LTC2937_TON_TIMERS_1_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TON_TIMERS_1_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TON_MAX_1 TON_MAX_1
 *  @ingroup LTC2937_register_map
 *  @brief TON_MAX_1 Bit Field
 *
 *  Sets the maximum voltage monitor rise time for Channel 1.
 *   - Register: @ref LTC2937_TON_TIMERS_1_CMD "TON_TIMERS_1_CMD"
 *   - CommandCode: 10
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TON_MAX_1_SUBADDR LTC2937_TON_TIMERS_1_CMD_SUBADDR //!< @ref LTC2937_TON_MAX_1 "TON_MAX_1"
#define LTC2937_TON_MAX_1_SIZE 3
#define LTC2937_TON_MAX_1_OFFSET 13
#define LTC2937_TON_MAX_1_MSK 0xE000
#define LTC2937_TON_MAX_1 (LTC2937_TON_MAX_1_OFFSET << 12 | (LTC2937_TON_MAX_1_SIZE - 1) << 8 | LTC2937_TON_MAX_1_SUBADDR)
#define LTC2937_TON_MAX_1_PRESET_INFINITY 0
#define LTC2937_TON_MAX_1_PRESET_160US 1
#define LTC2937_TON_MAX_1_PRESET_640US 2
#define LTC2937_TON_MAX_1_PRESET_2_6MS 3
#define LTC2937_TON_MAX_1_PRESET_10_2MS 4
#define LTC2937_TON_MAX_1_PRESET_41MS 5
#define LTC2937_TON_MAX_1_PRESET_164MS 6
#define LTC2937_TON_MAX_1_PRESET_655MS 7
//!@}
/*! @defgroup LTC2937_TON_DELAY_1 TON_DELAY_1
 *  @ingroup LTC2937_register_map
 *  @brief TON_DELAY_1 Bit Field
 *
 *  Sets time delay between the start of V1's selected sequence position and the release of EN1.
 *   - Register: @ref LTC2937_TON_TIMERS_1_CMD "TON_TIMERS_1_CMD"
 *   - CommandCode: 10
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TON_DELAY_1_SUBADDR LTC2937_TON_TIMERS_1_CMD_SUBADDR //!< @ref LTC2937_TON_DELAY_1 "TON_DELAY_1"
#define LTC2937_TON_DELAY_1_SIZE 13
#define LTC2937_TON_DELAY_1_OFFSET 0
#define LTC2937_TON_DELAY_1_MSK 0x1FFF
#define LTC2937_TON_DELAY_1 (LTC2937_TON_DELAY_1_OFFSET << 12 | (LTC2937_TON_DELAY_1_SIZE - 1) << 8 | LTC2937_TON_DELAY_1_SUBADDR)
//!@}

/*! @defgroup LTC2937_TON_TIMERS_2_CMD TON_TIMERS_2_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TON_TIMERS_2_CMD Register
 *
 * |     15:13 |        12:0 |
 * |:---------:|:-----------:|
 * | TON_MAX_2 | TON_DELAY_2 |
 *
 *   - CommandCode: 11
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TON_MAX_2 "TON_MAX_2" : Sets the maximum voltage monitor rise time for Channel 2.
 *     + @ref LTC2937_TON_DELAY_2 "TON_DELAY_2" : Sets time delay between the start of V2's selected sequence position and the release of EN2.
*/

//!@{
#define LTC2937_TON_TIMERS_2_CMD_SUBADDR 11
#define LTC2937_TON_TIMERS_2_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TON_TIMERS_2_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TON_MAX_2 TON_MAX_2
 *  @ingroup LTC2937_register_map
 *  @brief TON_MAX_2 Bit Field
 *
 *  Sets the maximum voltage monitor rise time for Channel 2.
 *   - Register: @ref LTC2937_TON_TIMERS_2_CMD "TON_TIMERS_2_CMD"
 *   - CommandCode: 11
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TON_MAX_2_SUBADDR LTC2937_TON_TIMERS_2_CMD_SUBADDR //!< @ref LTC2937_TON_MAX_2 "TON_MAX_2"
#define LTC2937_TON_MAX_2_SIZE 3
#define LTC2937_TON_MAX_2_OFFSET 13
#define LTC2937_TON_MAX_2_MSK 0xE000
#define LTC2937_TON_MAX_2 (LTC2937_TON_MAX_2_OFFSET << 12 | (LTC2937_TON_MAX_2_SIZE - 1) << 8 | LTC2937_TON_MAX_2_SUBADDR)
#define LTC2937_TON_MAX_2_PRESET_INFINITY 0
#define LTC2937_TON_MAX_2_PRESET_160US 1
#define LTC2937_TON_MAX_2_PRESET_640US 2
#define LTC2937_TON_MAX_2_PRESET_2_6MS 3
#define LTC2937_TON_MAX_2_PRESET_10_2MS 4
#define LTC2937_TON_MAX_2_PRESET_41MS 5
#define LTC2937_TON_MAX_2_PRESET_164MS 6
#define LTC2937_TON_MAX_2_PRESET_655MS 7
//!@}
/*! @defgroup LTC2937_TON_DELAY_2 TON_DELAY_2
 *  @ingroup LTC2937_register_map
 *  @brief TON_DELAY_2 Bit Field
 *
 *  Sets time delay between the start of V2's selected sequence position and the release of EN2.
 *   - Register: @ref LTC2937_TON_TIMERS_2_CMD "TON_TIMERS_2_CMD"
 *   - CommandCode: 11
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TON_DELAY_2_SUBADDR LTC2937_TON_TIMERS_2_CMD_SUBADDR //!< @ref LTC2937_TON_DELAY_2 "TON_DELAY_2"
#define LTC2937_TON_DELAY_2_SIZE 13
#define LTC2937_TON_DELAY_2_OFFSET 0
#define LTC2937_TON_DELAY_2_MSK 0x1FFF
#define LTC2937_TON_DELAY_2 (LTC2937_TON_DELAY_2_OFFSET << 12 | (LTC2937_TON_DELAY_2_SIZE - 1) << 8 | LTC2937_TON_DELAY_2_SUBADDR)
//!@}

/*! @defgroup LTC2937_TON_TIMERS_3_CMD TON_TIMERS_3_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TON_TIMERS_3_CMD Register
 *
 * |     15:13 |        12:0 |
 * |:---------:|:-----------:|
 * | TON_MAX_3 | TON_DELAY_3 |
 *
 *   - CommandCode: 12
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TON_MAX_3 "TON_MAX_3" : Sets the maximum voltage monitor rise time for Channel 3.
 *     + @ref LTC2937_TON_DELAY_3 "TON_DELAY_3" : Sets time delay between the start of V3's selected sequence position and the release of EN3.
*/

//!@{
#define LTC2937_TON_TIMERS_3_CMD_SUBADDR 12
#define LTC2937_TON_TIMERS_3_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TON_TIMERS_3_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TON_MAX_3 TON_MAX_3
 *  @ingroup LTC2937_register_map
 *  @brief TON_MAX_3 Bit Field
 *
 *  Sets the maximum voltage monitor rise time for Channel 3.
 *   - Register: @ref LTC2937_TON_TIMERS_3_CMD "TON_TIMERS_3_CMD"
 *   - CommandCode: 12
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TON_MAX_3_SUBADDR LTC2937_TON_TIMERS_3_CMD_SUBADDR //!< @ref LTC2937_TON_MAX_3 "TON_MAX_3"
#define LTC2937_TON_MAX_3_SIZE 3
#define LTC2937_TON_MAX_3_OFFSET 13
#define LTC2937_TON_MAX_3_MSK 0xE000
#define LTC2937_TON_MAX_3 (LTC2937_TON_MAX_3_OFFSET << 12 | (LTC2937_TON_MAX_3_SIZE - 1) << 8 | LTC2937_TON_MAX_3_SUBADDR)
#define LTC2937_TON_MAX_3_PRESET_INFINITY 0
#define LTC2937_TON_MAX_3_PRESET_160US 1
#define LTC2937_TON_MAX_3_PRESET_640US 2
#define LTC2937_TON_MAX_3_PRESET_2_6MS 3
#define LTC2937_TON_MAX_3_PRESET_10_2MS 4
#define LTC2937_TON_MAX_3_PRESET_41MS 5
#define LTC2937_TON_MAX_3_PRESET_164MS 6
#define LTC2937_TON_MAX_3_PRESET_655MS 7
//!@}
/*! @defgroup LTC2937_TON_DELAY_3 TON_DELAY_3
 *  @ingroup LTC2937_register_map
 *  @brief TON_DELAY_3 Bit Field
 *
 *  Sets time delay between the start of V3's selected sequence position and the release of EN3.
 *   - Register: @ref LTC2937_TON_TIMERS_3_CMD "TON_TIMERS_3_CMD"
 *   - CommandCode: 12
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TON_DELAY_3_SUBADDR LTC2937_TON_TIMERS_3_CMD_SUBADDR //!< @ref LTC2937_TON_DELAY_3 "TON_DELAY_3"
#define LTC2937_TON_DELAY_3_SIZE 13
#define LTC2937_TON_DELAY_3_OFFSET 0
#define LTC2937_TON_DELAY_3_MSK 0x1FFF
#define LTC2937_TON_DELAY_3 (LTC2937_TON_DELAY_3_OFFSET << 12 | (LTC2937_TON_DELAY_3_SIZE - 1) << 8 | LTC2937_TON_DELAY_3_SUBADDR)
//!@}

/*! @defgroup LTC2937_TON_TIMERS_4_CMD TON_TIMERS_4_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TON_TIMERS_4_CMD Register
 *
 * |     15:13 |        12:0 |
 * |:---------:|:-----------:|
 * | TON_MAX_4 | TON_DELAY_4 |
 *
 *   - CommandCode: 13
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TON_MAX_4 "TON_MAX_4" : Sets the maximum voltage monitor rise time for Channel 4.
 *     + @ref LTC2937_TON_DELAY_4 "TON_DELAY_4" : Sets time delay between the start of V4's selected sequence position and the release of EN4.
*/

//!@{
#define LTC2937_TON_TIMERS_4_CMD_SUBADDR 13
#define LTC2937_TON_TIMERS_4_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TON_TIMERS_4_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TON_MAX_4 TON_MAX_4
 *  @ingroup LTC2937_register_map
 *  @brief TON_MAX_4 Bit Field
 *
 *  Sets the maximum voltage monitor rise time for Channel 4.
 *   - Register: @ref LTC2937_TON_TIMERS_4_CMD "TON_TIMERS_4_CMD"
 *   - CommandCode: 13
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TON_MAX_4_SUBADDR LTC2937_TON_TIMERS_4_CMD_SUBADDR //!< @ref LTC2937_TON_MAX_4 "TON_MAX_4"
#define LTC2937_TON_MAX_4_SIZE 3
#define LTC2937_TON_MAX_4_OFFSET 13
#define LTC2937_TON_MAX_4_MSK 0xE000
#define LTC2937_TON_MAX_4 (LTC2937_TON_MAX_4_OFFSET << 12 | (LTC2937_TON_MAX_4_SIZE - 1) << 8 | LTC2937_TON_MAX_4_SUBADDR)
#define LTC2937_TON_MAX_4_PRESET_INFINITY 0
#define LTC2937_TON_MAX_4_PRESET_160US 1
#define LTC2937_TON_MAX_4_PRESET_640US 2
#define LTC2937_TON_MAX_4_PRESET_2_6MS 3
#define LTC2937_TON_MAX_4_PRESET_10_2MS 4
#define LTC2937_TON_MAX_4_PRESET_41MS 5
#define LTC2937_TON_MAX_4_PRESET_164MS 6
#define LTC2937_TON_MAX_4_PRESET_655MS 7
//!@}
/*! @defgroup LTC2937_TON_DELAY_4 TON_DELAY_4
 *  @ingroup LTC2937_register_map
 *  @brief TON_DELAY_4 Bit Field
 *
 *  Sets time delay between the start of V4's selected sequence position and the release of EN4.
 *   - Register: @ref LTC2937_TON_TIMERS_4_CMD "TON_TIMERS_4_CMD"
 *   - CommandCode: 13
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TON_DELAY_4_SUBADDR LTC2937_TON_TIMERS_4_CMD_SUBADDR //!< @ref LTC2937_TON_DELAY_4 "TON_DELAY_4"
#define LTC2937_TON_DELAY_4_SIZE 13
#define LTC2937_TON_DELAY_4_OFFSET 0
#define LTC2937_TON_DELAY_4_MSK 0x1FFF
#define LTC2937_TON_DELAY_4 (LTC2937_TON_DELAY_4_OFFSET << 12 | (LTC2937_TON_DELAY_4_SIZE - 1) << 8 | LTC2937_TON_DELAY_4_SUBADDR)
//!@}

/*! @defgroup LTC2937_TON_TIMERS_5_CMD TON_TIMERS_5_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TON_TIMERS_5_CMD Register
 *
 * |     15:13 |        12:0 |
 * |:---------:|:-----------:|
 * | TON_MAX_5 | TON_DELAY_5 |
 *
 *   - CommandCode: 14
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TON_MAX_5 "TON_MAX_5" : Sets the maximum voltage monitor rise time for Channel 5.
 *     + @ref LTC2937_TON_DELAY_5 "TON_DELAY_5" : Sets time delay between the start of V5's selected sequence position and the release of EN5.
*/

//!@{
#define LTC2937_TON_TIMERS_5_CMD_SUBADDR 14
#define LTC2937_TON_TIMERS_5_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TON_TIMERS_5_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TON_MAX_5 TON_MAX_5
 *  @ingroup LTC2937_register_map
 *  @brief TON_MAX_5 Bit Field
 *
 *  Sets the maximum voltage monitor rise time for Channel 5.
 *   - Register: @ref LTC2937_TON_TIMERS_5_CMD "TON_TIMERS_5_CMD"
 *   - CommandCode: 14
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TON_MAX_5_SUBADDR LTC2937_TON_TIMERS_5_CMD_SUBADDR //!< @ref LTC2937_TON_MAX_5 "TON_MAX_5"
#define LTC2937_TON_MAX_5_SIZE 3
#define LTC2937_TON_MAX_5_OFFSET 13
#define LTC2937_TON_MAX_5_MSK 0xE000
#define LTC2937_TON_MAX_5 (LTC2937_TON_MAX_5_OFFSET << 12 | (LTC2937_TON_MAX_5_SIZE - 1) << 8 | LTC2937_TON_MAX_5_SUBADDR)
#define LTC2937_TON_MAX_5_PRESET_INFINITY 0
#define LTC2937_TON_MAX_5_PRESET_160US 1
#define LTC2937_TON_MAX_5_PRESET_640US 2
#define LTC2937_TON_MAX_5_PRESET_2_6MS 3
#define LTC2937_TON_MAX_5_PRESET_10_2MS 4
#define LTC2937_TON_MAX_5_PRESET_41MS 5
#define LTC2937_TON_MAX_5_PRESET_164MS 6
#define LTC2937_TON_MAX_5_PRESET_655MS 7
//!@}
/*! @defgroup LTC2937_TON_DELAY_5 TON_DELAY_5
 *  @ingroup LTC2937_register_map
 *  @brief TON_DELAY_5 Bit Field
 *
 *  Sets time delay between the start of V5's selected sequence position and the release of EN5.
 *   - Register: @ref LTC2937_TON_TIMERS_5_CMD "TON_TIMERS_5_CMD"
 *   - CommandCode: 14
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TON_DELAY_5_SUBADDR LTC2937_TON_TIMERS_5_CMD_SUBADDR //!< @ref LTC2937_TON_DELAY_5 "TON_DELAY_5"
#define LTC2937_TON_DELAY_5_SIZE 13
#define LTC2937_TON_DELAY_5_OFFSET 0
#define LTC2937_TON_DELAY_5_MSK 0x1FFF
#define LTC2937_TON_DELAY_5 (LTC2937_TON_DELAY_5_OFFSET << 12 | (LTC2937_TON_DELAY_5_SIZE - 1) << 8 | LTC2937_TON_DELAY_5_SUBADDR)
//!@}

/*! @defgroup LTC2937_TON_TIMERS_6_CMD TON_TIMERS_6_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TON_TIMERS_6_CMD Register
 *
 * |     15:13 |        12:0 |
 * |:---------:|:-----------:|
 * | TON_MAX_6 | TON_DELAY_6 |
 *
 *   - CommandCode: 15
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TON_MAX_6 "TON_MAX_6" : Sets the maximum voltage monitor rise time for Channel 6.
 *     + @ref LTC2937_TON_DELAY_6 "TON_DELAY_6" : Sets time delay between the start of V6's selected sequence position and the release of EN6.
*/

//!@{
#define LTC2937_TON_TIMERS_6_CMD_SUBADDR 15
#define LTC2937_TON_TIMERS_6_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TON_TIMERS_6_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TON_MAX_6 TON_MAX_6
 *  @ingroup LTC2937_register_map
 *  @brief TON_MAX_6 Bit Field
 *
 *  Sets the maximum voltage monitor rise time for Channel 6.
 *   - Register: @ref LTC2937_TON_TIMERS_6_CMD "TON_TIMERS_6_CMD"
 *   - CommandCode: 15
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TON_MAX_6_SUBADDR LTC2937_TON_TIMERS_6_CMD_SUBADDR //!< @ref LTC2937_TON_MAX_6 "TON_MAX_6"
#define LTC2937_TON_MAX_6_SIZE 3
#define LTC2937_TON_MAX_6_OFFSET 13
#define LTC2937_TON_MAX_6_MSK 0xE000
#define LTC2937_TON_MAX_6 (LTC2937_TON_MAX_6_OFFSET << 12 | (LTC2937_TON_MAX_6_SIZE - 1) << 8 | LTC2937_TON_MAX_6_SUBADDR)
#define LTC2937_TON_MAX_6_PRESET_INFINITY 0
#define LTC2937_TON_MAX_6_PRESET_160US 1
#define LTC2937_TON_MAX_6_PRESET_640US 2
#define LTC2937_TON_MAX_6_PRESET_2_6MS 3
#define LTC2937_TON_MAX_6_PRESET_10_2MS 4
#define LTC2937_TON_MAX_6_PRESET_41MS 5
#define LTC2937_TON_MAX_6_PRESET_164MS 6
#define LTC2937_TON_MAX_6_PRESET_655MS 7
//!@}
/*! @defgroup LTC2937_TON_DELAY_6 TON_DELAY_6
 *  @ingroup LTC2937_register_map
 *  @brief TON_DELAY_6 Bit Field
 *
 *  Sets time delay between the start of V6's selected sequence position and the release of EN6.
 *   - Register: @ref LTC2937_TON_TIMERS_6_CMD "TON_TIMERS_6_CMD"
 *   - CommandCode: 15
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TON_DELAY_6_SUBADDR LTC2937_TON_TIMERS_6_CMD_SUBADDR //!< @ref LTC2937_TON_DELAY_6 "TON_DELAY_6"
#define LTC2937_TON_DELAY_6_SIZE 13
#define LTC2937_TON_DELAY_6_OFFSET 0
#define LTC2937_TON_DELAY_6_MSK 0x1FFF
#define LTC2937_TON_DELAY_6 (LTC2937_TON_DELAY_6_OFFSET << 12 | (LTC2937_TON_DELAY_6_SIZE - 1) << 8 | LTC2937_TON_DELAY_6_SUBADDR)
//!@}

/*! @defgroup LTC2937_TOFF_TIMERS_1_CMD TOFF_TIMERS_1_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_TIMERS_1_CMD Register
 *
 * |      15:13 |         12:0 |
 * |:----------:|:------------:|
 * | TOFF_MAX_1 | TOFF_DELAY_1 |
 *
 *   - CommandCode: 16
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TOFF_MAX_1 "TOFF_MAX_1" : Sets the maximum voltage monitor fall time for Channel 1.
 *     + @ref LTC2937_TOFF_DELAY_1 "TOFF_DELAY_1" : Sets time delay between the start of V1's selected sequence position and pulling EN1 low.
*/

//!@{
#define LTC2937_TOFF_TIMERS_1_CMD_SUBADDR 16
#define LTC2937_TOFF_TIMERS_1_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TOFF_TIMERS_1_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TOFF_MAX_1 TOFF_MAX_1
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_MAX_1 Bit Field
 *
 *  Sets the maximum voltage monitor fall time for Channel 1.
 *   - Register: @ref LTC2937_TOFF_TIMERS_1_CMD "TOFF_TIMERS_1_CMD"
 *   - CommandCode: 16
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TOFF_MAX_1_SUBADDR LTC2937_TOFF_TIMERS_1_CMD_SUBADDR //!< @ref LTC2937_TOFF_MAX_1 "TOFF_MAX_1"
#define LTC2937_TOFF_MAX_1_SIZE 3
#define LTC2937_TOFF_MAX_1_OFFSET 13
#define LTC2937_TOFF_MAX_1_MSK 0xE000
#define LTC2937_TOFF_MAX_1 (LTC2937_TOFF_MAX_1_OFFSET << 12 | (LTC2937_TOFF_MAX_1_SIZE - 1) << 8 | LTC2937_TOFF_MAX_1_SUBADDR)
#define LTC2937_TOFF_MAX_1_PRESET_INFINITY 0
#define LTC2937_TOFF_MAX_1_PRESET_2_6MS 1
#define LTC2937_TOFF_MAX_1_PRESET_10_2MS 2
#define LTC2937_TOFF_MAX_1_PRESET_41MS 3
#define LTC2937_TOFF_MAX_1_PRESET_164MS 4
#define LTC2937_TOFF_MAX_1_PRESET_655MS 5
#define LTC2937_TOFF_MAX_1_PRESET_2_6S 6
#define LTC2937_TOFF_MAX_1_PRESET_10_5S 7
//!@}
/*! @defgroup LTC2937_TOFF_DELAY_1 TOFF_DELAY_1
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_DELAY_1 Bit Field
 *
 *  Sets time delay between the start of V1's selected sequence position and pulling EN1 low.
 *   - Register: @ref LTC2937_TOFF_TIMERS_1_CMD "TOFF_TIMERS_1_CMD"
 *   - CommandCode: 16
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TOFF_DELAY_1_SUBADDR LTC2937_TOFF_TIMERS_1_CMD_SUBADDR //!< @ref LTC2937_TOFF_DELAY_1 "TOFF_DELAY_1"
#define LTC2937_TOFF_DELAY_1_SIZE 13
#define LTC2937_TOFF_DELAY_1_OFFSET 0
#define LTC2937_TOFF_DELAY_1_MSK 0x1FFF
#define LTC2937_TOFF_DELAY_1 (LTC2937_TOFF_DELAY_1_OFFSET << 12 | (LTC2937_TOFF_DELAY_1_SIZE - 1) << 8 | LTC2937_TOFF_DELAY_1_SUBADDR)
//!@}

/*! @defgroup LTC2937_TOFF_TIMERS_2_CMD TOFF_TIMERS_2_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_TIMERS_2_CMD Register
 *
 * |      15:13 |         12:0 |
 * |:----------:|:------------:|
 * | TOFF_MAX_2 | TOFF_DELAY_2 |
 *
 *   - CommandCode: 17
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TOFF_MAX_2 "TOFF_MAX_2" : Sets the maximum voltage monitor fall time for Channel 2.
 *     + @ref LTC2937_TOFF_DELAY_2 "TOFF_DELAY_2" : Sets time delay between the start of V2's selected sequence position and pulling EN2 low.
*/

//!@{
#define LTC2937_TOFF_TIMERS_2_CMD_SUBADDR 17
#define LTC2937_TOFF_TIMERS_2_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TOFF_TIMERS_2_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TOFF_MAX_2 TOFF_MAX_2
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_MAX_2 Bit Field
 *
 *  Sets the maximum voltage monitor fall time for Channel 2.
 *   - Register: @ref LTC2937_TOFF_TIMERS_2_CMD "TOFF_TIMERS_2_CMD"
 *   - CommandCode: 17
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TOFF_MAX_2_SUBADDR LTC2937_TOFF_TIMERS_2_CMD_SUBADDR //!< @ref LTC2937_TOFF_MAX_2 "TOFF_MAX_2"
#define LTC2937_TOFF_MAX_2_SIZE 3
#define LTC2937_TOFF_MAX_2_OFFSET 13
#define LTC2937_TOFF_MAX_2_MSK 0xE000
#define LTC2937_TOFF_MAX_2 (LTC2937_TOFF_MAX_2_OFFSET << 12 | (LTC2937_TOFF_MAX_2_SIZE - 1) << 8 | LTC2937_TOFF_MAX_2_SUBADDR)
#define LTC2937_TOFF_MAX_2_PRESET_INFINITY 0
#define LTC2937_TOFF_MAX_2_PRESET_2_6MS 1
#define LTC2937_TOFF_MAX_2_PRESET_10_2MS 2
#define LTC2937_TOFF_MAX_2_PRESET_41MS 3
#define LTC2937_TOFF_MAX_2_PRESET_164MS 4
#define LTC2937_TOFF_MAX_2_PRESET_655MS 5
#define LTC2937_TOFF_MAX_2_PRESET_2_6S 6
#define LTC2937_TOFF_MAX_2_PRESET_10_5S 7
//!@}
/*! @defgroup LTC2937_TOFF_DELAY_2 TOFF_DELAY_2
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_DELAY_2 Bit Field
 *
 *  Sets time delay between the start of V2's selected sequence position and pulling EN2 low.
 *   - Register: @ref LTC2937_TOFF_TIMERS_2_CMD "TOFF_TIMERS_2_CMD"
 *   - CommandCode: 17
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TOFF_DELAY_2_SUBADDR LTC2937_TOFF_TIMERS_2_CMD_SUBADDR //!< @ref LTC2937_TOFF_DELAY_2 "TOFF_DELAY_2"
#define LTC2937_TOFF_DELAY_2_SIZE 13
#define LTC2937_TOFF_DELAY_2_OFFSET 0
#define LTC2937_TOFF_DELAY_2_MSK 0x1FFF
#define LTC2937_TOFF_DELAY_2 (LTC2937_TOFF_DELAY_2_OFFSET << 12 | (LTC2937_TOFF_DELAY_2_SIZE - 1) << 8 | LTC2937_TOFF_DELAY_2_SUBADDR)
//!@}

/*! @defgroup LTC2937_TOFF_TIMERS_3_CMD TOFF_TIMERS_3_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_TIMERS_3_CMD Register
 *
 * |      15:13 |         12:0 |
 * |:----------:|:------------:|
 * | TOFF_MAX_3 | TOFF_DELAY_3 |
 *
 *   - CommandCode: 18
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TOFF_MAX_3 "TOFF_MAX_3" : Sets the maximum voltage monitor fall time for Channel 3.
 *     + @ref LTC2937_TOFF_DELAY_3 "TOFF_DELAY_3" : Sets time delay between the start of V3's selected sequence position and pulling EN3 low.
*/

//!@{
#define LTC2937_TOFF_TIMERS_3_CMD_SUBADDR 18
#define LTC2937_TOFF_TIMERS_3_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TOFF_TIMERS_3_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TOFF_MAX_3 TOFF_MAX_3
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_MAX_3 Bit Field
 *
 *  Sets the maximum voltage monitor fall time for Channel 3.
 *   - Register: @ref LTC2937_TOFF_TIMERS_3_CMD "TOFF_TIMERS_3_CMD"
 *   - CommandCode: 18
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TOFF_MAX_3_SUBADDR LTC2937_TOFF_TIMERS_3_CMD_SUBADDR //!< @ref LTC2937_TOFF_MAX_3 "TOFF_MAX_3"
#define LTC2937_TOFF_MAX_3_SIZE 3
#define LTC2937_TOFF_MAX_3_OFFSET 13
#define LTC2937_TOFF_MAX_3_MSK 0xE000
#define LTC2937_TOFF_MAX_3 (LTC2937_TOFF_MAX_3_OFFSET << 12 | (LTC2937_TOFF_MAX_3_SIZE - 1) << 8 | LTC2937_TOFF_MAX_3_SUBADDR)
#define LTC2937_TOFF_MAX_3_PRESET_INFINITY 0
#define LTC2937_TOFF_MAX_3_PRESET_2_6MS 1
#define LTC2937_TOFF_MAX_3_PRESET_10_2MS 2
#define LTC2937_TOFF_MAX_3_PRESET_41MS 3
#define LTC2937_TOFF_MAX_3_PRESET_164MS 4
#define LTC2937_TOFF_MAX_3_PRESET_655MS 5
#define LTC2937_TOFF_MAX_3_PRESET_2_6S 6
#define LTC2937_TOFF_MAX_3_PRESET_10_5S 7
//!@}
/*! @defgroup LTC2937_TOFF_DELAY_3 TOFF_DELAY_3
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_DELAY_3 Bit Field
 *
 *  Sets time delay between the start of V3's selected sequence position and pulling EN3 low.
 *   - Register: @ref LTC2937_TOFF_TIMERS_3_CMD "TOFF_TIMERS_3_CMD"
 *   - CommandCode: 18
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TOFF_DELAY_3_SUBADDR LTC2937_TOFF_TIMERS_3_CMD_SUBADDR //!< @ref LTC2937_TOFF_DELAY_3 "TOFF_DELAY_3"
#define LTC2937_TOFF_DELAY_3_SIZE 13
#define LTC2937_TOFF_DELAY_3_OFFSET 0
#define LTC2937_TOFF_DELAY_3_MSK 0x1FFF
#define LTC2937_TOFF_DELAY_3 (LTC2937_TOFF_DELAY_3_OFFSET << 12 | (LTC2937_TOFF_DELAY_3_SIZE - 1) << 8 | LTC2937_TOFF_DELAY_3_SUBADDR)
//!@}

/*! @defgroup LTC2937_TOFF_TIMERS_4_CMD TOFF_TIMERS_4_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_TIMERS_4_CMD Register
 *
 * |      15:13 |         12:0 |
 * |:----------:|:------------:|
 * | TOFF_MAX_4 | TOFF_DELAY_4 |
 *
 *   - CommandCode: 19
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TOFF_MAX_4 "TOFF_MAX_4" : Sets the maximum voltage monitor fall time for Channel 4.
 *     + @ref LTC2937_TOFF_DELAY_4 "TOFF_DELAY_4" : Sets time delay between the start of V4's selected sequence position and pulling EN4 low.
*/

//!@{
#define LTC2937_TOFF_TIMERS_4_CMD_SUBADDR 19
#define LTC2937_TOFF_TIMERS_4_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TOFF_TIMERS_4_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TOFF_MAX_4 TOFF_MAX_4
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_MAX_4 Bit Field
 *
 *  Sets the maximum voltage monitor fall time for Channel 4.
 *   - Register: @ref LTC2937_TOFF_TIMERS_4_CMD "TOFF_TIMERS_4_CMD"
 *   - CommandCode: 19
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TOFF_MAX_4_SUBADDR LTC2937_TOFF_TIMERS_4_CMD_SUBADDR //!< @ref LTC2937_TOFF_MAX_4 "TOFF_MAX_4"
#define LTC2937_TOFF_MAX_4_SIZE 3
#define LTC2937_TOFF_MAX_4_OFFSET 13
#define LTC2937_TOFF_MAX_4_MSK 0xE000
#define LTC2937_TOFF_MAX_4 (LTC2937_TOFF_MAX_4_OFFSET << 12 | (LTC2937_TOFF_MAX_4_SIZE - 1) << 8 | LTC2937_TOFF_MAX_4_SUBADDR)
#define LTC2937_TOFF_MAX_4_PRESET_INFINITY 0
#define LTC2937_TOFF_MAX_4_PRESET_2_6MS 1
#define LTC2937_TOFF_MAX_4_PRESET_10_2MS 2
#define LTC2937_TOFF_MAX_4_PRESET_41MS 3
#define LTC2937_TOFF_MAX_4_PRESET_164MS 4
#define LTC2937_TOFF_MAX_4_PRESET_655MS 5
#define LTC2937_TOFF_MAX_4_PRESET_2_6S 6
#define LTC2937_TOFF_MAX_4_PRESET_10_5S 7
//!@}
/*! @defgroup LTC2937_TOFF_DELAY_4 TOFF_DELAY_4
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_DELAY_4 Bit Field
 *
 *  Sets time delay between the start of V4's selected sequence position and pulling EN4 low.
 *   - Register: @ref LTC2937_TOFF_TIMERS_4_CMD "TOFF_TIMERS_4_CMD"
 *   - CommandCode: 19
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TOFF_DELAY_4_SUBADDR LTC2937_TOFF_TIMERS_4_CMD_SUBADDR //!< @ref LTC2937_TOFF_DELAY_4 "TOFF_DELAY_4"
#define LTC2937_TOFF_DELAY_4_SIZE 13
#define LTC2937_TOFF_DELAY_4_OFFSET 0
#define LTC2937_TOFF_DELAY_4_MSK 0x1FFF
#define LTC2937_TOFF_DELAY_4 (LTC2937_TOFF_DELAY_4_OFFSET << 12 | (LTC2937_TOFF_DELAY_4_SIZE - 1) << 8 | LTC2937_TOFF_DELAY_4_SUBADDR)
//!@}

/*! @defgroup LTC2937_TOFF_TIMERS_5_CMD TOFF_TIMERS_5_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_TIMERS_5_CMD Register
 *
 * |      15:13 |         12:0 |
 * |:----------:|:------------:|
 * | TOFF_MAX_5 | TOFF_DELAY_5 |
 *
 *   - CommandCode: 20
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TOFF_MAX_5 "TOFF_MAX_5" : Sets the maximum voltage monitor fall time for Channel 5.
 *     + @ref LTC2937_TOFF_DELAY_5 "TOFF_DELAY_5" : Sets time delay between the start of V5's selected sequence position and pulling EN5 low.
*/

//!@{
#define LTC2937_TOFF_TIMERS_5_CMD_SUBADDR 20
#define LTC2937_TOFF_TIMERS_5_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TOFF_TIMERS_5_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TOFF_MAX_5 TOFF_MAX_5
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_MAX_5 Bit Field
 *
 *  Sets the maximum voltage monitor fall time for Channel 5.
 *   - Register: @ref LTC2937_TOFF_TIMERS_5_CMD "TOFF_TIMERS_5_CMD"
 *   - CommandCode: 20
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TOFF_MAX_5_SUBADDR LTC2937_TOFF_TIMERS_5_CMD_SUBADDR //!< @ref LTC2937_TOFF_MAX_5 "TOFF_MAX_5"
#define LTC2937_TOFF_MAX_5_SIZE 3
#define LTC2937_TOFF_MAX_5_OFFSET 13
#define LTC2937_TOFF_MAX_5_MSK 0xE000
#define LTC2937_TOFF_MAX_5 (LTC2937_TOFF_MAX_5_OFFSET << 12 | (LTC2937_TOFF_MAX_5_SIZE - 1) << 8 | LTC2937_TOFF_MAX_5_SUBADDR)
#define LTC2937_TOFF_MAX_5_PRESET_INFINITY 0
#define LTC2937_TOFF_MAX_5_PRESET_2_6MS 1
#define LTC2937_TOFF_MAX_5_PRESET_10_2MS 2
#define LTC2937_TOFF_MAX_5_PRESET_41MS 3
#define LTC2937_TOFF_MAX_5_PRESET_164MS 4
#define LTC2937_TOFF_MAX_5_PRESET_655MS 5
#define LTC2937_TOFF_MAX_5_PRESET_2_6S 6
#define LTC2937_TOFF_MAX_5_PRESET_10_5S 7
//!@}
/*! @defgroup LTC2937_TOFF_DELAY_5 TOFF_DELAY_5
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_DELAY_5 Bit Field
 *
 *  Sets time delay between the start of V5's selected sequence position and pulling EN5 low.
 *   - Register: @ref LTC2937_TOFF_TIMERS_5_CMD "TOFF_TIMERS_5_CMD"
 *   - CommandCode: 20
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TOFF_DELAY_5_SUBADDR LTC2937_TOFF_TIMERS_5_CMD_SUBADDR //!< @ref LTC2937_TOFF_DELAY_5 "TOFF_DELAY_5"
#define LTC2937_TOFF_DELAY_5_SIZE 13
#define LTC2937_TOFF_DELAY_5_OFFSET 0
#define LTC2937_TOFF_DELAY_5_MSK 0x1FFF
#define LTC2937_TOFF_DELAY_5 (LTC2937_TOFF_DELAY_5_OFFSET << 12 | (LTC2937_TOFF_DELAY_5_SIZE - 1) << 8 | LTC2937_TOFF_DELAY_5_SUBADDR)
//!@}

/*! @defgroup LTC2937_TOFF_TIMERS_6_CMD TOFF_TIMERS_6_CMD
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_TIMERS_6_CMD Register
 *
 * |      15:13 |         12:0 |
 * |:----------:|:------------:|
 * | TOFF_MAX_6 | TOFF_DELAY_6 |
 *
 *   - CommandCode: 21
 *   - Contains Bit Fields:
 *     + @ref LTC2937_TOFF_MAX_6 "TOFF_MAX_6" : Sets the maximum voltage monitor fall time for Channel 6.
 *     + @ref LTC2937_TOFF_DELAY_6 "TOFF_DELAY_6" : Sets time delay between the start of V6's selected sequence position and pulling EN6 low.
*/

//!@{
#define LTC2937_TOFF_TIMERS_6_CMD_SUBADDR 21
#define LTC2937_TOFF_TIMERS_6_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_TOFF_TIMERS_6_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_TOFF_MAX_6 TOFF_MAX_6
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_MAX_6 Bit Field
 *
 *  Sets the maximum voltage monitor fall time for Channel 6.
 *   - Register: @ref LTC2937_TOFF_TIMERS_6_CMD "TOFF_TIMERS_6_CMD"
 *   - CommandCode: 21
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_TOFF_MAX_6_SUBADDR LTC2937_TOFF_TIMERS_6_CMD_SUBADDR //!< @ref LTC2937_TOFF_MAX_6 "TOFF_MAX_6"
#define LTC2937_TOFF_MAX_6_SIZE 3
#define LTC2937_TOFF_MAX_6_OFFSET 13
#define LTC2937_TOFF_MAX_6_MSK 0xE000
#define LTC2937_TOFF_MAX_6 (LTC2937_TOFF_MAX_6_OFFSET << 12 | (LTC2937_TOFF_MAX_6_SIZE - 1) << 8 | LTC2937_TOFF_MAX_6_SUBADDR)
#define LTC2937_TOFF_MAX_6_PRESET_INFINITY 0
#define LTC2937_TOFF_MAX_6_PRESET_2_6MS 1
#define LTC2937_TOFF_MAX_6_PRESET_10_2MS 2
#define LTC2937_TOFF_MAX_6_PRESET_41MS 3
#define LTC2937_TOFF_MAX_6_PRESET_164MS 4
#define LTC2937_TOFF_MAX_6_PRESET_655MS 5
#define LTC2937_TOFF_MAX_6_PRESET_2_6S 6
#define LTC2937_TOFF_MAX_6_PRESET_10_5S 7
//!@}
/*! @defgroup LTC2937_TOFF_DELAY_6 TOFF_DELAY_6
 *  @ingroup LTC2937_register_map
 *  @brief TOFF_DELAY_6 Bit Field
 *
 *  Sets time delay between the start of V6's selected sequence position and pulling EN6 low.
 *   - Register: @ref LTC2937_TOFF_TIMERS_6_CMD "TOFF_TIMERS_6_CMD"
 *   - CommandCode: 21
 *   - Size: 13
 *   - Offset: 0
 *   - MSB: 12
 *   - MASK: 0x1FFF
 *   - Access: R/W
 *   - Default: 0
 *   - Format: LTC2937_DELAY_TIME_TO_INTEGER
 */
//!@{
#define LTC2937_TOFF_DELAY_6_SUBADDR LTC2937_TOFF_TIMERS_6_CMD_SUBADDR //!< @ref LTC2937_TOFF_DELAY_6 "TOFF_DELAY_6"
#define LTC2937_TOFF_DELAY_6_SIZE 13
#define LTC2937_TOFF_DELAY_6_OFFSET 0
#define LTC2937_TOFF_DELAY_6_MSK 0x1FFF
#define LTC2937_TOFF_DELAY_6 (LTC2937_TOFF_DELAY_6_OFFSET << 12 | (LTC2937_TOFF_DELAY_6_SIZE - 1) << 8 | LTC2937_TOFF_DELAY_6_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_UP_POSITION_1_CMD SEQ_UP_POSITION_1_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_1_CMD Register
 *
 * | 15:11 |             10 |               9:0 |
 * |:-----:|:--------------:|:-----------------:|
 * |   n/a | ASYNC_ON_OFF_1 | SEQ_UP_POSITION_1 |
 *
 *   - CommandCode: 22
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ASYNC_ON_OFF_1 "ASYNC_ON_OFF_1" : Ch.1 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *     + @ref LTC2937_SEQ_UP_POSITION_1 "SEQ_UP_POSITION_1" : Specifies sequence position for channel 1. Set to 0 to remove channel from sequencing.
*/

//!@{
#define LTC2937_SEQ_UP_POSITION_1_CMD_SUBADDR 22
#define LTC2937_SEQ_UP_POSITION_1_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_UP_POSITION_1_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ASYNC_ON_OFF_1 ASYNC_ON_OFF_1
 *  @ingroup LTC2937_register_map
 *  @brief ASYNC_ON_OFF_1 Bit Field
 *
 *  Ch.1 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_1_CMD "SEQ_UP_POSITION_1_CMD"
 *   - CommandCode: 22
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ASYNC_ON_OFF_1_SUBADDR LTC2937_SEQ_UP_POSITION_1_CMD_SUBADDR //!< @ref LTC2937_ASYNC_ON_OFF_1 "ASYNC_ON_OFF_1"
#define LTC2937_ASYNC_ON_OFF_1_SIZE 1
#define LTC2937_ASYNC_ON_OFF_1_OFFSET 10
#define LTC2937_ASYNC_ON_OFF_1_MSK 0x0400
#define LTC2937_ASYNC_ON_OFF_1 (LTC2937_ASYNC_ON_OFF_1_OFFSET << 12 | (LTC2937_ASYNC_ON_OFF_1_SIZE - 1) << 8 | LTC2937_ASYNC_ON_OFF_1_SUBADDR)
#define LTC2937_ASYNC_ON_OFF_1_PRESET_HOLD_EN1_LOW 0
#define LTC2937_ASYNC_ON_OFF_1_PRESET_RELEASE_EN1 1
//!@}
/*! @defgroup LTC2937_SEQ_UP_POSITION_1 SEQ_UP_POSITION_1
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_1 Bit Field
 *
 *  Specifies sequence position for channel 1. Set to 0 to remove channel from sequencing.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_1_CMD "SEQ_UP_POSITION_1_CMD"
 *   - CommandCode: 22
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_UP_POSITION_1_SUBADDR LTC2937_SEQ_UP_POSITION_1_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_POSITION_1 "SEQ_UP_POSITION_1"
#define LTC2937_SEQ_UP_POSITION_1_SIZE 10
#define LTC2937_SEQ_UP_POSITION_1_OFFSET 0
#define LTC2937_SEQ_UP_POSITION_1_MSK 0x03FF
#define LTC2937_SEQ_UP_POSITION_1 (LTC2937_SEQ_UP_POSITION_1_OFFSET << 12 | (LTC2937_SEQ_UP_POSITION_1_SIZE - 1) << 8 | LTC2937_SEQ_UP_POSITION_1_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_UP_POSITION_2_CMD SEQ_UP_POSITION_2_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_2_CMD Register
 *
 * | 15:11 |             10 |               9:0 |
 * |:-----:|:--------------:|:-----------------:|
 * |   n/a | ASYNC_ON_OFF_2 | SEQ_UP_POSITION_2 |
 *
 *   - CommandCode: 23
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ASYNC_ON_OFF_2 "ASYNC_ON_OFF_2" : Ch.2 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *     + @ref LTC2937_SEQ_UP_POSITION_2 "SEQ_UP_POSITION_2" : Specifies sequence position for channel 2. Set to 0 to remove channel from sequencing.
*/

//!@{
#define LTC2937_SEQ_UP_POSITION_2_CMD_SUBADDR 23
#define LTC2937_SEQ_UP_POSITION_2_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_UP_POSITION_2_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ASYNC_ON_OFF_2 ASYNC_ON_OFF_2
 *  @ingroup LTC2937_register_map
 *  @brief ASYNC_ON_OFF_2 Bit Field
 *
 *  Ch.2 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_2_CMD "SEQ_UP_POSITION_2_CMD"
 *   - CommandCode: 23
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ASYNC_ON_OFF_2_SUBADDR LTC2937_SEQ_UP_POSITION_2_CMD_SUBADDR //!< @ref LTC2937_ASYNC_ON_OFF_2 "ASYNC_ON_OFF_2"
#define LTC2937_ASYNC_ON_OFF_2_SIZE 1
#define LTC2937_ASYNC_ON_OFF_2_OFFSET 10
#define LTC2937_ASYNC_ON_OFF_2_MSK 0x0400
#define LTC2937_ASYNC_ON_OFF_2 (LTC2937_ASYNC_ON_OFF_2_OFFSET << 12 | (LTC2937_ASYNC_ON_OFF_2_SIZE - 1) << 8 | LTC2937_ASYNC_ON_OFF_2_SUBADDR)
#define LTC2937_ASYNC_ON_OFF_2_PRESET_HOLD_EN2_LOW 0
#define LTC2937_ASYNC_ON_OFF_2_PRESET_RELEASE_EN2 1
//!@}
/*! @defgroup LTC2937_SEQ_UP_POSITION_2 SEQ_UP_POSITION_2
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_2 Bit Field
 *
 *  Specifies sequence position for channel 2. Set to 0 to remove channel from sequencing.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_2_CMD "SEQ_UP_POSITION_2_CMD"
 *   - CommandCode: 23
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_UP_POSITION_2_SUBADDR LTC2937_SEQ_UP_POSITION_2_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_POSITION_2 "SEQ_UP_POSITION_2"
#define LTC2937_SEQ_UP_POSITION_2_SIZE 10
#define LTC2937_SEQ_UP_POSITION_2_OFFSET 0
#define LTC2937_SEQ_UP_POSITION_2_MSK 0x03FF
#define LTC2937_SEQ_UP_POSITION_2 (LTC2937_SEQ_UP_POSITION_2_OFFSET << 12 | (LTC2937_SEQ_UP_POSITION_2_SIZE - 1) << 8 | LTC2937_SEQ_UP_POSITION_2_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_UP_POSITION_3_CMD SEQ_UP_POSITION_3_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_3_CMD Register
 *
 * | 15:11 |             10 |               9:0 |
 * |:-----:|:--------------:|:-----------------:|
 * |   n/a | ASYNC_ON_OFF_3 | SEQ_UP_POSITION_3 |
 *
 *   - CommandCode: 24
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ASYNC_ON_OFF_3 "ASYNC_ON_OFF_3" : Ch.3 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *     + @ref LTC2937_SEQ_UP_POSITION_3 "SEQ_UP_POSITION_3" : Specifies sequence position for channel 3. Set to 0 to remove channel from sequencing.
*/

//!@{
#define LTC2937_SEQ_UP_POSITION_3_CMD_SUBADDR 24
#define LTC2937_SEQ_UP_POSITION_3_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_UP_POSITION_3_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ASYNC_ON_OFF_3 ASYNC_ON_OFF_3
 *  @ingroup LTC2937_register_map
 *  @brief ASYNC_ON_OFF_3 Bit Field
 *
 *  Ch.3 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_3_CMD "SEQ_UP_POSITION_3_CMD"
 *   - CommandCode: 24
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ASYNC_ON_OFF_3_SUBADDR LTC2937_SEQ_UP_POSITION_3_CMD_SUBADDR //!< @ref LTC2937_ASYNC_ON_OFF_3 "ASYNC_ON_OFF_3"
#define LTC2937_ASYNC_ON_OFF_3_SIZE 1
#define LTC2937_ASYNC_ON_OFF_3_OFFSET 10
#define LTC2937_ASYNC_ON_OFF_3_MSK 0x0400
#define LTC2937_ASYNC_ON_OFF_3 (LTC2937_ASYNC_ON_OFF_3_OFFSET << 12 | (LTC2937_ASYNC_ON_OFF_3_SIZE - 1) << 8 | LTC2937_ASYNC_ON_OFF_3_SUBADDR)
#define LTC2937_ASYNC_ON_OFF_3_PRESET_HOLD_EN3_LOW 0
#define LTC2937_ASYNC_ON_OFF_3_PRESET_RELEASE_EN3 1
//!@}
/*! @defgroup LTC2937_SEQ_UP_POSITION_3 SEQ_UP_POSITION_3
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_3 Bit Field
 *
 *  Specifies sequence position for channel 3. Set to 0 to remove channel from sequencing.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_3_CMD "SEQ_UP_POSITION_3_CMD"
 *   - CommandCode: 24
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_UP_POSITION_3_SUBADDR LTC2937_SEQ_UP_POSITION_3_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_POSITION_3 "SEQ_UP_POSITION_3"
#define LTC2937_SEQ_UP_POSITION_3_SIZE 10
#define LTC2937_SEQ_UP_POSITION_3_OFFSET 0
#define LTC2937_SEQ_UP_POSITION_3_MSK 0x03FF
#define LTC2937_SEQ_UP_POSITION_3 (LTC2937_SEQ_UP_POSITION_3_OFFSET << 12 | (LTC2937_SEQ_UP_POSITION_3_SIZE - 1) << 8 | LTC2937_SEQ_UP_POSITION_3_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_UP_POSITION_4_CMD SEQ_UP_POSITION_4_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_4_CMD Register
 *
 * | 15:11 |             10 |               9:0 |
 * |:-----:|:--------------:|:-----------------:|
 * |   n/a | ASYNC_ON_OFF_4 | SEQ_UP_POSITION_4 |
 *
 *   - CommandCode: 25
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ASYNC_ON_OFF_4 "ASYNC_ON_OFF_4" : Ch.4 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *     + @ref LTC2937_SEQ_UP_POSITION_4 "SEQ_UP_POSITION_4" : Specifies sequence position for channel 4. Set to 0 to remove channel from sequencing.
*/

//!@{
#define LTC2937_SEQ_UP_POSITION_4_CMD_SUBADDR 25
#define LTC2937_SEQ_UP_POSITION_4_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_UP_POSITION_4_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ASYNC_ON_OFF_4 ASYNC_ON_OFF_4
 *  @ingroup LTC2937_register_map
 *  @brief ASYNC_ON_OFF_4 Bit Field
 *
 *  Ch.4 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_4_CMD "SEQ_UP_POSITION_4_CMD"
 *   - CommandCode: 25
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ASYNC_ON_OFF_4_SUBADDR LTC2937_SEQ_UP_POSITION_4_CMD_SUBADDR //!< @ref LTC2937_ASYNC_ON_OFF_4 "ASYNC_ON_OFF_4"
#define LTC2937_ASYNC_ON_OFF_4_SIZE 1
#define LTC2937_ASYNC_ON_OFF_4_OFFSET 10
#define LTC2937_ASYNC_ON_OFF_4_MSK 0x0400
#define LTC2937_ASYNC_ON_OFF_4 (LTC2937_ASYNC_ON_OFF_4_OFFSET << 12 | (LTC2937_ASYNC_ON_OFF_4_SIZE - 1) << 8 | LTC2937_ASYNC_ON_OFF_4_SUBADDR)
#define LTC2937_ASYNC_ON_OFF_4_PRESET_HOLD_EN4_LOW 0
#define LTC2937_ASYNC_ON_OFF_4_PRESET_RELEASE_EN4 1
//!@}
/*! @defgroup LTC2937_SEQ_UP_POSITION_4 SEQ_UP_POSITION_4
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_4 Bit Field
 *
 *  Specifies sequence position for channel 4. Set to 0 to remove channel from sequencing.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_4_CMD "SEQ_UP_POSITION_4_CMD"
 *   - CommandCode: 25
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_UP_POSITION_4_SUBADDR LTC2937_SEQ_UP_POSITION_4_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_POSITION_4 "SEQ_UP_POSITION_4"
#define LTC2937_SEQ_UP_POSITION_4_SIZE 10
#define LTC2937_SEQ_UP_POSITION_4_OFFSET 0
#define LTC2937_SEQ_UP_POSITION_4_MSK 0x03FF
#define LTC2937_SEQ_UP_POSITION_4 (LTC2937_SEQ_UP_POSITION_4_OFFSET << 12 | (LTC2937_SEQ_UP_POSITION_4_SIZE - 1) << 8 | LTC2937_SEQ_UP_POSITION_4_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_UP_POSITION_5_CMD SEQ_UP_POSITION_5_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_5_CMD Register
 *
 * | 15:11 |             10 |               9:0 |
 * |:-----:|:--------------:|:-----------------:|
 * |   n/a | ASYNC_ON_OFF_5 | SEQ_UP_POSITION_5 |
 *
 *   - CommandCode: 26
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ASYNC_ON_OFF_5 "ASYNC_ON_OFF_5" : Ch.5 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *     + @ref LTC2937_SEQ_UP_POSITION_5 "SEQ_UP_POSITION_5" : Specifies sequence position for channel 5. Set to 0 to remove channel from sequencing.
*/

//!@{
#define LTC2937_SEQ_UP_POSITION_5_CMD_SUBADDR 26
#define LTC2937_SEQ_UP_POSITION_5_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_UP_POSITION_5_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ASYNC_ON_OFF_5 ASYNC_ON_OFF_5
 *  @ingroup LTC2937_register_map
 *  @brief ASYNC_ON_OFF_5 Bit Field
 *
 *  Ch.5 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_5_CMD "SEQ_UP_POSITION_5_CMD"
 *   - CommandCode: 26
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ASYNC_ON_OFF_5_SUBADDR LTC2937_SEQ_UP_POSITION_5_CMD_SUBADDR //!< @ref LTC2937_ASYNC_ON_OFF_5 "ASYNC_ON_OFF_5"
#define LTC2937_ASYNC_ON_OFF_5_SIZE 1
#define LTC2937_ASYNC_ON_OFF_5_OFFSET 10
#define LTC2937_ASYNC_ON_OFF_5_MSK 0x0400
#define LTC2937_ASYNC_ON_OFF_5 (LTC2937_ASYNC_ON_OFF_5_OFFSET << 12 | (LTC2937_ASYNC_ON_OFF_5_SIZE - 1) << 8 | LTC2937_ASYNC_ON_OFF_5_SUBADDR)
#define LTC2937_ASYNC_ON_OFF_5_PRESET_HOLD_EN5_LOW 0
#define LTC2937_ASYNC_ON_OFF_5_PRESET_RELEASE_EN5 1
//!@}
/*! @defgroup LTC2937_SEQ_UP_POSITION_5 SEQ_UP_POSITION_5
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_5 Bit Field
 *
 *  Specifies sequence position for channel 5. Set to 0 to remove channel from sequencing.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_5_CMD "SEQ_UP_POSITION_5_CMD"
 *   - CommandCode: 26
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_UP_POSITION_5_SUBADDR LTC2937_SEQ_UP_POSITION_5_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_POSITION_5 "SEQ_UP_POSITION_5"
#define LTC2937_SEQ_UP_POSITION_5_SIZE 10
#define LTC2937_SEQ_UP_POSITION_5_OFFSET 0
#define LTC2937_SEQ_UP_POSITION_5_MSK 0x03FF
#define LTC2937_SEQ_UP_POSITION_5 (LTC2937_SEQ_UP_POSITION_5_OFFSET << 12 | (LTC2937_SEQ_UP_POSITION_5_SIZE - 1) << 8 | LTC2937_SEQ_UP_POSITION_5_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_UP_POSITION_6_CMD SEQ_UP_POSITION_6_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_6_CMD Register
 *
 * | 15:11 |             10 |               9:0 |
 * |:-----:|:--------------:|:-----------------:|
 * |   n/a | ASYNC_ON_OFF_6 | SEQ_UP_POSITION_6 |
 *
 *   - CommandCode: 27
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ASYNC_ON_OFF_6 "ASYNC_ON_OFF_6" : Ch.6 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *     + @ref LTC2937_SEQ_UP_POSITION_6 "SEQ_UP_POSITION_6" : Specifies sequence position for channel 6. Set to 0 to remove channel from sequencing.
*/

//!@{
#define LTC2937_SEQ_UP_POSITION_6_CMD_SUBADDR 27
#define LTC2937_SEQ_UP_POSITION_6_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_UP_POSITION_6_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ASYNC_ON_OFF_6 ASYNC_ON_OFF_6
 *  @ingroup LTC2937_register_map
 *  @brief ASYNC_ON_OFF_6 Bit Field
 *
 *  Ch.6 Asynchronous enable control. Bits 9:0 have to be 0 to use.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_6_CMD "SEQ_UP_POSITION_6_CMD"
 *   - CommandCode: 27
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ASYNC_ON_OFF_6_SUBADDR LTC2937_SEQ_UP_POSITION_6_CMD_SUBADDR //!< @ref LTC2937_ASYNC_ON_OFF_6 "ASYNC_ON_OFF_6"
#define LTC2937_ASYNC_ON_OFF_6_SIZE 1
#define LTC2937_ASYNC_ON_OFF_6_OFFSET 10
#define LTC2937_ASYNC_ON_OFF_6_MSK 0x0400
#define LTC2937_ASYNC_ON_OFF_6 (LTC2937_ASYNC_ON_OFF_6_OFFSET << 12 | (LTC2937_ASYNC_ON_OFF_6_SIZE - 1) << 8 | LTC2937_ASYNC_ON_OFF_6_SUBADDR)
#define LTC2937_ASYNC_ON_OFF_6_PRESET_HOLD_EN6_LOW 0
#define LTC2937_ASYNC_ON_OFF_6_PRESET_RELEASE_EN6 1
//!@}
/*! @defgroup LTC2937_SEQ_UP_POSITION_6 SEQ_UP_POSITION_6
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_POSITION_6 Bit Field
 *
 *  Specifies sequence position for channel 6. Set to 0 to remove channel from sequencing.
 *   - Register: @ref LTC2937_SEQ_UP_POSITION_6_CMD "SEQ_UP_POSITION_6_CMD"
 *   - CommandCode: 27
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_UP_POSITION_6_SUBADDR LTC2937_SEQ_UP_POSITION_6_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_POSITION_6 "SEQ_UP_POSITION_6"
#define LTC2937_SEQ_UP_POSITION_6_SIZE 10
#define LTC2937_SEQ_UP_POSITION_6_OFFSET 0
#define LTC2937_SEQ_UP_POSITION_6_MSK 0x03FF
#define LTC2937_SEQ_UP_POSITION_6 (LTC2937_SEQ_UP_POSITION_6_OFFSET << 12 | (LTC2937_SEQ_UP_POSITION_6_SIZE - 1) << 8 | LTC2937_SEQ_UP_POSITION_6_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_DOWN_POSITION_1_CMD SEQ_DOWN_POSITION_1_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_1_CMD Register
 *
 * | 15:11 |                 10 |                 9:0 |
 * |:-----:|:------------------:|:-------------------:|
 * |   n/a | ACTIVE_PULL_DOWN_1 | SEQ_DOWN_POSITION_1 |
 *
 *   - CommandCode: 28
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ACTIVE_PULL_DOWN_1 "ACTIVE_PULL_DOWN_1" : Voltage Monitor 1 active pull_down ON/OFF control.
 *     + @ref LTC2937_SEQ_DOWN_POSITION_1 "SEQ_DOWN_POSITION_1" : Specifies sequence down position for channel 1.
*/

//!@{
#define LTC2937_SEQ_DOWN_POSITION_1_CMD_SUBADDR 28
#define LTC2937_SEQ_DOWN_POSITION_1_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_1_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ACTIVE_PULL_DOWN_1 ACTIVE_PULL_DOWN_1
 *  @ingroup LTC2937_register_map
 *  @brief ACTIVE_PULL_DOWN_1 Bit Field
 *
 *  Voltage Monitor 1 active pull_down ON/OFF control.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_1_CMD "SEQ_DOWN_POSITION_1_CMD"
 *   - CommandCode: 28
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ACTIVE_PULL_DOWN_1_SUBADDR LTC2937_SEQ_DOWN_POSITION_1_CMD_SUBADDR //!< @ref LTC2937_ACTIVE_PULL_DOWN_1 "ACTIVE_PULL_DOWN_1"
#define LTC2937_ACTIVE_PULL_DOWN_1_SIZE 1
#define LTC2937_ACTIVE_PULL_DOWN_1_OFFSET 10
#define LTC2937_ACTIVE_PULL_DOWN_1_MSK 0x0400
#define LTC2937_ACTIVE_PULL_DOWN_1 (LTC2937_ACTIVE_PULL_DOWN_1_OFFSET << 12 | (LTC2937_ACTIVE_PULL_DOWN_1_SIZE - 1) << 8 | LTC2937_ACTIVE_PULL_DOWN_1_SUBADDR)
#define LTC2937_ACTIVE_PULL_DOWN_1_PRESET_PULL_DOWN_DISABLED 0
#define LTC2937_ACTIVE_PULL_DOWN_1_PRESET_PULL_DOWN_ENABLED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_POSITION_1 SEQ_DOWN_POSITION_1
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_1 Bit Field
 *
 *  Specifies sequence down position for channel 1.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_1_CMD "SEQ_DOWN_POSITION_1_CMD"
 *   - CommandCode: 28
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_DOWN_POSITION_1_SUBADDR LTC2937_SEQ_DOWN_POSITION_1_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_POSITION_1 "SEQ_DOWN_POSITION_1"
#define LTC2937_SEQ_DOWN_POSITION_1_SIZE 10
#define LTC2937_SEQ_DOWN_POSITION_1_OFFSET 0
#define LTC2937_SEQ_DOWN_POSITION_1_MSK 0x03FF
#define LTC2937_SEQ_DOWN_POSITION_1 (LTC2937_SEQ_DOWN_POSITION_1_OFFSET << 12 | (LTC2937_SEQ_DOWN_POSITION_1_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_1_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_DOWN_POSITION_2_CMD SEQ_DOWN_POSITION_2_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_2_CMD Register
 *
 * | 15:11 |                 10 |                 9:0 |
 * |:-----:|:------------------:|:-------------------:|
 * |   n/a | ACTIVE_PULL_DOWN_2 | SEQ_DOWN_POSITION_2 |
 *
 *   - CommandCode: 29
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ACTIVE_PULL_DOWN_2 "ACTIVE_PULL_DOWN_2" : Voltage Monitor 2 active pull_down ON/OFF control.
 *     + @ref LTC2937_SEQ_DOWN_POSITION_2 "SEQ_DOWN_POSITION_2" : Specifies sequence down position for channel 2.
*/

//!@{
#define LTC2937_SEQ_DOWN_POSITION_2_CMD_SUBADDR 29
#define LTC2937_SEQ_DOWN_POSITION_2_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_2_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ACTIVE_PULL_DOWN_2 ACTIVE_PULL_DOWN_2
 *  @ingroup LTC2937_register_map
 *  @brief ACTIVE_PULL_DOWN_2 Bit Field
 *
 *  Voltage Monitor 2 active pull_down ON/OFF control.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_2_CMD "SEQ_DOWN_POSITION_2_CMD"
 *   - CommandCode: 29
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ACTIVE_PULL_DOWN_2_SUBADDR LTC2937_SEQ_DOWN_POSITION_2_CMD_SUBADDR //!< @ref LTC2937_ACTIVE_PULL_DOWN_2 "ACTIVE_PULL_DOWN_2"
#define LTC2937_ACTIVE_PULL_DOWN_2_SIZE 1
#define LTC2937_ACTIVE_PULL_DOWN_2_OFFSET 10
#define LTC2937_ACTIVE_PULL_DOWN_2_MSK 0x0400
#define LTC2937_ACTIVE_PULL_DOWN_2 (LTC2937_ACTIVE_PULL_DOWN_2_OFFSET << 12 | (LTC2937_ACTIVE_PULL_DOWN_2_SIZE - 1) << 8 | LTC2937_ACTIVE_PULL_DOWN_2_SUBADDR)
#define LTC2937_ACTIVE_PULL_DOWN_2_PRESET_PULL_DOWN_DISABLED 0
#define LTC2937_ACTIVE_PULL_DOWN_2_PRESET_PULL_DOWN_ENABLED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_POSITION_2 SEQ_DOWN_POSITION_2
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_2 Bit Field
 *
 *  Specifies sequence down position for channel 2.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_2_CMD "SEQ_DOWN_POSITION_2_CMD"
 *   - CommandCode: 29
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_DOWN_POSITION_2_SUBADDR LTC2937_SEQ_DOWN_POSITION_2_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_POSITION_2 "SEQ_DOWN_POSITION_2"
#define LTC2937_SEQ_DOWN_POSITION_2_SIZE 10
#define LTC2937_SEQ_DOWN_POSITION_2_OFFSET 0
#define LTC2937_SEQ_DOWN_POSITION_2_MSK 0x03FF
#define LTC2937_SEQ_DOWN_POSITION_2 (LTC2937_SEQ_DOWN_POSITION_2_OFFSET << 12 | (LTC2937_SEQ_DOWN_POSITION_2_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_2_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_DOWN_POSITION_3_CMD SEQ_DOWN_POSITION_3_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_3_CMD Register
 *
 * | 15:11 |                 10 |                 9:0 |
 * |:-----:|:------------------:|:-------------------:|
 * |   n/a | ACTIVE_PULL_DOWN_3 | SEQ_DOWN_POSITION_3 |
 *
 *   - CommandCode: 30
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ACTIVE_PULL_DOWN_3 "ACTIVE_PULL_DOWN_3" : Voltage Monitor 3 active pull_down ON/OFF control.
 *     + @ref LTC2937_SEQ_DOWN_POSITION_3 "SEQ_DOWN_POSITION_3" : Specifies sequence down position for channel 3.
*/

//!@{
#define LTC2937_SEQ_DOWN_POSITION_3_CMD_SUBADDR 30
#define LTC2937_SEQ_DOWN_POSITION_3_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_3_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ACTIVE_PULL_DOWN_3 ACTIVE_PULL_DOWN_3
 *  @ingroup LTC2937_register_map
 *  @brief ACTIVE_PULL_DOWN_3 Bit Field
 *
 *  Voltage Monitor 3 active pull_down ON/OFF control.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_3_CMD "SEQ_DOWN_POSITION_3_CMD"
 *   - CommandCode: 30
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ACTIVE_PULL_DOWN_3_SUBADDR LTC2937_SEQ_DOWN_POSITION_3_CMD_SUBADDR //!< @ref LTC2937_ACTIVE_PULL_DOWN_3 "ACTIVE_PULL_DOWN_3"
#define LTC2937_ACTIVE_PULL_DOWN_3_SIZE 1
#define LTC2937_ACTIVE_PULL_DOWN_3_OFFSET 10
#define LTC2937_ACTIVE_PULL_DOWN_3_MSK 0x0400
#define LTC2937_ACTIVE_PULL_DOWN_3 (LTC2937_ACTIVE_PULL_DOWN_3_OFFSET << 12 | (LTC2937_ACTIVE_PULL_DOWN_3_SIZE - 1) << 8 | LTC2937_ACTIVE_PULL_DOWN_3_SUBADDR)
#define LTC2937_ACTIVE_PULL_DOWN_3_PRESET_PULL_DOWN_DISABLED 0
#define LTC2937_ACTIVE_PULL_DOWN_3_PRESET_PULL_DOWN_ENABLED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_POSITION_3 SEQ_DOWN_POSITION_3
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_3 Bit Field
 *
 *  Specifies sequence down position for channel 3.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_3_CMD "SEQ_DOWN_POSITION_3_CMD"
 *   - CommandCode: 30
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_DOWN_POSITION_3_SUBADDR LTC2937_SEQ_DOWN_POSITION_3_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_POSITION_3 "SEQ_DOWN_POSITION_3"
#define LTC2937_SEQ_DOWN_POSITION_3_SIZE 10
#define LTC2937_SEQ_DOWN_POSITION_3_OFFSET 0
#define LTC2937_SEQ_DOWN_POSITION_3_MSK 0x03FF
#define LTC2937_SEQ_DOWN_POSITION_3 (LTC2937_SEQ_DOWN_POSITION_3_OFFSET << 12 | (LTC2937_SEQ_DOWN_POSITION_3_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_3_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_DOWN_POSITION_4_CMD SEQ_DOWN_POSITION_4_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_4_CMD Register
 *
 * | 15:11 |                 10 |                 9:0 |
 * |:-----:|:------------------:|:-------------------:|
 * |   n/a | ACTIVE_PULL_DOWN_4 | SEQ_DOWN_POSITION_4 |
 *
 *   - CommandCode: 31
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ACTIVE_PULL_DOWN_4 "ACTIVE_PULL_DOWN_4" : Voltage Monitor 4 active pull_down ON/OFF control.
 *     + @ref LTC2937_SEQ_DOWN_POSITION_4 "SEQ_DOWN_POSITION_4" : Specifies sequence down position for channel 4.
*/

//!@{
#define LTC2937_SEQ_DOWN_POSITION_4_CMD_SUBADDR 31
#define LTC2937_SEQ_DOWN_POSITION_4_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_4_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ACTIVE_PULL_DOWN_4 ACTIVE_PULL_DOWN_4
 *  @ingroup LTC2937_register_map
 *  @brief ACTIVE_PULL_DOWN_4 Bit Field
 *
 *  Voltage Monitor 4 active pull_down ON/OFF control.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_4_CMD "SEQ_DOWN_POSITION_4_CMD"
 *   - CommandCode: 31
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ACTIVE_PULL_DOWN_4_SUBADDR LTC2937_SEQ_DOWN_POSITION_4_CMD_SUBADDR //!< @ref LTC2937_ACTIVE_PULL_DOWN_4 "ACTIVE_PULL_DOWN_4"
#define LTC2937_ACTIVE_PULL_DOWN_4_SIZE 1
#define LTC2937_ACTIVE_PULL_DOWN_4_OFFSET 10
#define LTC2937_ACTIVE_PULL_DOWN_4_MSK 0x0400
#define LTC2937_ACTIVE_PULL_DOWN_4 (LTC2937_ACTIVE_PULL_DOWN_4_OFFSET << 12 | (LTC2937_ACTIVE_PULL_DOWN_4_SIZE - 1) << 8 | LTC2937_ACTIVE_PULL_DOWN_4_SUBADDR)
#define LTC2937_ACTIVE_PULL_DOWN_4_PRESET_PULL_DOWN_DISABLED 0
#define LTC2937_ACTIVE_PULL_DOWN_4_PRESET_PULL_DOWN_ENABLED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_POSITION_4 SEQ_DOWN_POSITION_4
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_4 Bit Field
 *
 *  Specifies sequence down position for channel 4.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_4_CMD "SEQ_DOWN_POSITION_4_CMD"
 *   - CommandCode: 31
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_DOWN_POSITION_4_SUBADDR LTC2937_SEQ_DOWN_POSITION_4_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_POSITION_4 "SEQ_DOWN_POSITION_4"
#define LTC2937_SEQ_DOWN_POSITION_4_SIZE 10
#define LTC2937_SEQ_DOWN_POSITION_4_OFFSET 0
#define LTC2937_SEQ_DOWN_POSITION_4_MSK 0x03FF
#define LTC2937_SEQ_DOWN_POSITION_4 (LTC2937_SEQ_DOWN_POSITION_4_OFFSET << 12 | (LTC2937_SEQ_DOWN_POSITION_4_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_4_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_DOWN_POSITION_5_CMD SEQ_DOWN_POSITION_5_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_5_CMD Register
 *
 * | 15:11 |                 10 |                 9:0 |
 * |:-----:|:------------------:|:-------------------:|
 * |   n/a | ACTIVE_PULL_DOWN_5 | SEQ_DOWN_POSITION_5 |
 *
 *   - CommandCode: 32
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ACTIVE_PULL_DOWN_5 "ACTIVE_PULL_DOWN_5" : Voltage Monitor 5 active pull_down ON/OFF control.
 *     + @ref LTC2937_SEQ_DOWN_POSITION_5 "SEQ_DOWN_POSITION_5" : Specifies sequence down position for channel 5.
*/

//!@{
#define LTC2937_SEQ_DOWN_POSITION_5_CMD_SUBADDR 32
#define LTC2937_SEQ_DOWN_POSITION_5_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_5_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ACTIVE_PULL_DOWN_5 ACTIVE_PULL_DOWN_5
 *  @ingroup LTC2937_register_map
 *  @brief ACTIVE_PULL_DOWN_5 Bit Field
 *
 *  Voltage Monitor 5 active pull_down ON/OFF control.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_5_CMD "SEQ_DOWN_POSITION_5_CMD"
 *   - CommandCode: 32
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ACTIVE_PULL_DOWN_5_SUBADDR LTC2937_SEQ_DOWN_POSITION_5_CMD_SUBADDR //!< @ref LTC2937_ACTIVE_PULL_DOWN_5 "ACTIVE_PULL_DOWN_5"
#define LTC2937_ACTIVE_PULL_DOWN_5_SIZE 1
#define LTC2937_ACTIVE_PULL_DOWN_5_OFFSET 10
#define LTC2937_ACTIVE_PULL_DOWN_5_MSK 0x0400
#define LTC2937_ACTIVE_PULL_DOWN_5 (LTC2937_ACTIVE_PULL_DOWN_5_OFFSET << 12 | (LTC2937_ACTIVE_PULL_DOWN_5_SIZE - 1) << 8 | LTC2937_ACTIVE_PULL_DOWN_5_SUBADDR)
#define LTC2937_ACTIVE_PULL_DOWN_5_PRESET_PULL_DOWN_DISABLED 0
#define LTC2937_ACTIVE_PULL_DOWN_5_PRESET_PULL_DOWN_ENABLED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_POSITION_5 SEQ_DOWN_POSITION_5
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_5 Bit Field
 *
 *  Specifies sequence down position for channel 5.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_5_CMD "SEQ_DOWN_POSITION_5_CMD"
 *   - CommandCode: 32
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_DOWN_POSITION_5_SUBADDR LTC2937_SEQ_DOWN_POSITION_5_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_POSITION_5 "SEQ_DOWN_POSITION_5"
#define LTC2937_SEQ_DOWN_POSITION_5_SIZE 10
#define LTC2937_SEQ_DOWN_POSITION_5_OFFSET 0
#define LTC2937_SEQ_DOWN_POSITION_5_MSK 0x03FF
#define LTC2937_SEQ_DOWN_POSITION_5 (LTC2937_SEQ_DOWN_POSITION_5_OFFSET << 12 | (LTC2937_SEQ_DOWN_POSITION_5_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_5_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_DOWN_POSITION_6_CMD SEQ_DOWN_POSITION_6_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_6_CMD Register
 *
 * | 15:11 |                 10 |                 9:0 |
 * |:-----:|:------------------:|:-------------------:|
 * |   n/a | ACTIVE_PULL_DOWN_6 | SEQ_DOWN_POSITION_6 |
 *
 *   - CommandCode: 33
 *   - Contains Bit Fields:
 *     + @ref LTC2937_ACTIVE_PULL_DOWN_6 "ACTIVE_PULL_DOWN_6" : Voltage Monitor 6 active pull_down ON/OFF control.
 *     + @ref LTC2937_SEQ_DOWN_POSITION_6 "SEQ_DOWN_POSITION_6" : Specifies sequence down position for channel 6.
*/

//!@{
#define LTC2937_SEQ_DOWN_POSITION_6_CMD_SUBADDR 33
#define LTC2937_SEQ_DOWN_POSITION_6_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_6_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_ACTIVE_PULL_DOWN_6 ACTIVE_PULL_DOWN_6
 *  @ingroup LTC2937_register_map
 *  @brief ACTIVE_PULL_DOWN_6 Bit Field
 *
 *  Voltage Monitor 6 active pull_down ON/OFF control.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_6_CMD "SEQ_DOWN_POSITION_6_CMD"
 *   - CommandCode: 33
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_ACTIVE_PULL_DOWN_6_SUBADDR LTC2937_SEQ_DOWN_POSITION_6_CMD_SUBADDR //!< @ref LTC2937_ACTIVE_PULL_DOWN_6 "ACTIVE_PULL_DOWN_6"
#define LTC2937_ACTIVE_PULL_DOWN_6_SIZE 1
#define LTC2937_ACTIVE_PULL_DOWN_6_OFFSET 10
#define LTC2937_ACTIVE_PULL_DOWN_6_MSK 0x0400
#define LTC2937_ACTIVE_PULL_DOWN_6 (LTC2937_ACTIVE_PULL_DOWN_6_OFFSET << 12 | (LTC2937_ACTIVE_PULL_DOWN_6_SIZE - 1) << 8 | LTC2937_ACTIVE_PULL_DOWN_6_SUBADDR)
#define LTC2937_ACTIVE_PULL_DOWN_6_PRESET_PULL_DOWN_DISABLED 0
#define LTC2937_ACTIVE_PULL_DOWN_6_PRESET_PULL_DOWN_ENABLED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_POSITION_6 SEQ_DOWN_POSITION_6
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_POSITION_6 Bit Field
 *
 *  Specifies sequence down position for channel 6.
 *   - Register: @ref LTC2937_SEQ_DOWN_POSITION_6_CMD "SEQ_DOWN_POSITION_6_CMD"
 *   - CommandCode: 33
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_SEQ_DOWN_POSITION_6_SUBADDR LTC2937_SEQ_DOWN_POSITION_6_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_POSITION_6 "SEQ_DOWN_POSITION_6"
#define LTC2937_SEQ_DOWN_POSITION_6_SIZE 10
#define LTC2937_SEQ_DOWN_POSITION_6_OFFSET 0
#define LTC2937_SEQ_DOWN_POSITION_6_MSK 0x03FF
#define LTC2937_SEQ_DOWN_POSITION_6 (LTC2937_SEQ_DOWN_POSITION_6_OFFSET << 12 | (LTC2937_SEQ_DOWN_POSITION_6_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_POSITION_6_SUBADDR)
//!@}

/*! @defgroup LTC2937_RSTB_CONFIG_CMD RSTB_CONFIG_CMD
 *  @ingroup LTC2937_register_map
 *  @brief RSTB_CONFIG_CMD Register
 *
 * |      15:13 |              12 |           11 |           10 |            9 |            8 |            7 |            6 |            5 |            4 |            3 |            2 |            1 |            0 |
 * |:----------:|:---------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|
 * | RSTB_DELAY | SV_FAULT_ENABLE | V6_OV_ENABLE | V5_OV_ENABLE | V4_OV_ENABLE | V3_OV_ENABLE | V2_OV_ENABLE | V1_OV_ENABLE | V6_UV_ENABLE | V5_UV_ENABLE | V4_UV_ENABLE | V3_UV_ENABLE | V2_UV_ENABLE | V1_UV_ENABLE |
 *
 *   - CommandCode: 34
 *   - Contains Bit Fields:
 *     + @ref LTC2937_RSTB_DELAY "RSTB_DELAY" : Sets the RSTB assertion delay.
 *     + @ref LTC2937_SV_FAULT_ENABLE "SV_FAULT_ENABLE" : Allows SUPERVISOR fault to pull FAULTB.
 *     + @ref LTC2937_V6_OV_ENABLE "V6_OV_ENABLE" : Maps Channel 6 OV into RSTB output.
 *     + @ref LTC2937_V5_OV_ENABLE "V5_OV_ENABLE" : Maps Channel 5 OV into RSTB output.
 *     + @ref LTC2937_V4_OV_ENABLE "V4_OV_ENABLE" : Maps Channel 4 OV into RSTB output.
 *     + @ref LTC2937_V3_OV_ENABLE "V3_OV_ENABLE" : Maps Channel 3 OV into RSTB output.
 *     + @ref LTC2937_V2_OV_ENABLE "V2_OV_ENABLE" : Maps Channel 2 OV into RSTB output.
 *     + @ref LTC2937_V1_OV_ENABLE "V1_OV_ENABLE" : Maps Channel 1 OV into RSTB output.
 *     + @ref LTC2937_V6_UV_ENABLE "V6_UV_ENABLE" : Maps Channel 6 UV into RSTB output.
 *     + @ref LTC2937_V5_UV_ENABLE "V5_UV_ENABLE" : Maps Channel 5 UV into RSTB output.
 *     + @ref LTC2937_V4_UV_ENABLE "V4_UV_ENABLE" : Maps Channel 4 UV into RSTB output.
 *     + @ref LTC2937_V3_UV_ENABLE "V3_UV_ENABLE" : Maps Channel 3 UV into RSTB output.
 *     + @ref LTC2937_V2_UV_ENABLE "V2_UV_ENABLE" : Maps Channel 2 UV into RSTB output.
 *     + @ref LTC2937_V1_UV_ENABLE "V1_UV_ENABLE" : Maps Channel 1 UV into RSTB output.
*/

//!@{
#define LTC2937_RSTB_CONFIG_CMD_SUBADDR 34
#define LTC2937_RSTB_CONFIG_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_RSTB_CONFIG_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_RSTB_DELAY RSTB_DELAY
 *  @ingroup LTC2937_register_map
 *  @brief RSTB_DELAY Bit Field
 *
 *  Sets the RSTB assertion delay.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_RSTB_DELAY_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_RSTB_DELAY "RSTB_DELAY"
#define LTC2937_RSTB_DELAY_SIZE 3
#define LTC2937_RSTB_DELAY_OFFSET 13
#define LTC2937_RSTB_DELAY_MSK 0xE000
#define LTC2937_RSTB_DELAY (LTC2937_RSTB_DELAY_OFFSET << 12 | (LTC2937_RSTB_DELAY_SIZE - 1) << 8 | LTC2937_RSTB_DELAY_SUBADDR)
#define LTC2937_RSTB_DELAY_PRESET_0_05MS 0
#define LTC2937_RSTB_DELAY_PRESET_1_6MS 1
#define LTC2937_RSTB_DELAY_PRESET_6_4MS 2
#define LTC2937_RSTB_DELAY_PRESET_26MS 3
#define LTC2937_RSTB_DELAY_PRESET_51MS 4
#define LTC2937_RSTB_DELAY_PRESET_200MS 5
#define LTC2937_RSTB_DELAY_PRESET_410MS 6
#define LTC2937_RSTB_DELAY_PRESET_1640MS 7
//!@}
/*! @defgroup LTC2937_SV_FAULT_ENABLE SV_FAULT_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief SV_FAULT_ENABLE Bit Field
 *
 *  Allows SUPERVISOR fault to pull FAULTB.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 12
 *   - MSB: 12
 *   - MASK: 0x1000
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_SV_FAULT_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_SV_FAULT_ENABLE "SV_FAULT_ENABLE"
#define LTC2937_SV_FAULT_ENABLE_SIZE 1
#define LTC2937_SV_FAULT_ENABLE_OFFSET 12
#define LTC2937_SV_FAULT_ENABLE_MSK 0x1000
#define LTC2937_SV_FAULT_ENABLE (LTC2937_SV_FAULT_ENABLE_OFFSET << 12 | (LTC2937_SV_FAULT_ENABLE_SIZE - 1) << 8 | LTC2937_SV_FAULT_ENABLE_SUBADDR)
#define LTC2937_SV_FAULT_ENABLE_PRESET_SUPERVISOR_FAULT_DOES_NOT_PULL_FAULTB 0
#define LTC2937_SV_FAULT_ENABLE_PRESET_SUPERVISOR_FAULT_PULLS_FAULTB 1
//!@}
/*! @defgroup LTC2937_V6_OV_ENABLE V6_OV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V6_OV_ENABLE Bit Field
 *
 *  Maps Channel 6 OV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 11
 *   - MSB: 11
 *   - MASK: 0x0800
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_V6_OV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V6_OV_ENABLE "V6_OV_ENABLE"
#define LTC2937_V6_OV_ENABLE_SIZE 1
#define LTC2937_V6_OV_ENABLE_OFFSET 11
#define LTC2937_V6_OV_ENABLE_MSK 0x0800
#define LTC2937_V6_OV_ENABLE (LTC2937_V6_OV_ENABLE_OFFSET << 12 | (LTC2937_V6_OV_ENABLE_SIZE - 1) << 8 | LTC2937_V6_OV_ENABLE_SUBADDR)
#define LTC2937_V6_OV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V6_OV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V5_OV_ENABLE V5_OV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V5_OV_ENABLE Bit Field
 *
 *  Maps Channel 5 OV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_V5_OV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V5_OV_ENABLE "V5_OV_ENABLE"
#define LTC2937_V5_OV_ENABLE_SIZE 1
#define LTC2937_V5_OV_ENABLE_OFFSET 10
#define LTC2937_V5_OV_ENABLE_MSK 0x0400
#define LTC2937_V5_OV_ENABLE (LTC2937_V5_OV_ENABLE_OFFSET << 12 | (LTC2937_V5_OV_ENABLE_SIZE - 1) << 8 | LTC2937_V5_OV_ENABLE_SUBADDR)
#define LTC2937_V5_OV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V5_OV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V4_OV_ENABLE V4_OV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V4_OV_ENABLE Bit Field
 *
 *  Maps Channel 4 OV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 9
 *   - MSB: 9
 *   - MASK: 0x0200
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_V4_OV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V4_OV_ENABLE "V4_OV_ENABLE"
#define LTC2937_V4_OV_ENABLE_SIZE 1
#define LTC2937_V4_OV_ENABLE_OFFSET 9
#define LTC2937_V4_OV_ENABLE_MSK 0x0200
#define LTC2937_V4_OV_ENABLE (LTC2937_V4_OV_ENABLE_OFFSET << 12 | (LTC2937_V4_OV_ENABLE_SIZE - 1) << 8 | LTC2937_V4_OV_ENABLE_SUBADDR)
#define LTC2937_V4_OV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V4_OV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V3_OV_ENABLE V3_OV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V3_OV_ENABLE Bit Field
 *
 *  Maps Channel 3 OV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 8
 *   - MSB: 8
 *   - MASK: 0x0100
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_V3_OV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V3_OV_ENABLE "V3_OV_ENABLE"
#define LTC2937_V3_OV_ENABLE_SIZE 1
#define LTC2937_V3_OV_ENABLE_OFFSET 8
#define LTC2937_V3_OV_ENABLE_MSK 0x0100
#define LTC2937_V3_OV_ENABLE (LTC2937_V3_OV_ENABLE_OFFSET << 12 | (LTC2937_V3_OV_ENABLE_SIZE - 1) << 8 | LTC2937_V3_OV_ENABLE_SUBADDR)
#define LTC2937_V3_OV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V3_OV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V2_OV_ENABLE V2_OV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V2_OV_ENABLE Bit Field
 *
 *  Maps Channel 2 OV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 7
 *   - MSB: 7
 *   - MASK: 0x0080
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_V2_OV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V2_OV_ENABLE "V2_OV_ENABLE"
#define LTC2937_V2_OV_ENABLE_SIZE 1
#define LTC2937_V2_OV_ENABLE_OFFSET 7
#define LTC2937_V2_OV_ENABLE_MSK 0x0080
#define LTC2937_V2_OV_ENABLE (LTC2937_V2_OV_ENABLE_OFFSET << 12 | (LTC2937_V2_OV_ENABLE_SIZE - 1) << 8 | LTC2937_V2_OV_ENABLE_SUBADDR)
#define LTC2937_V2_OV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V2_OV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V1_OV_ENABLE V1_OV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V1_OV_ENABLE Bit Field
 *
 *  Maps Channel 1 OV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 6
 *   - MSB: 6
 *   - MASK: 0x0040
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_V1_OV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V1_OV_ENABLE "V1_OV_ENABLE"
#define LTC2937_V1_OV_ENABLE_SIZE 1
#define LTC2937_V1_OV_ENABLE_OFFSET 6
#define LTC2937_V1_OV_ENABLE_MSK 0x0040
#define LTC2937_V1_OV_ENABLE (LTC2937_V1_OV_ENABLE_OFFSET << 12 | (LTC2937_V1_OV_ENABLE_SIZE - 1) << 8 | LTC2937_V1_OV_ENABLE_SUBADDR)
#define LTC2937_V1_OV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V1_OV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V6_UV_ENABLE V6_UV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V6_UV_ENABLE Bit Field
 *
 *  Maps Channel 6 UV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 5
 *   - MSB: 5
 *   - MASK: 0x0020
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_V6_UV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V6_UV_ENABLE "V6_UV_ENABLE"
#define LTC2937_V6_UV_ENABLE_SIZE 1
#define LTC2937_V6_UV_ENABLE_OFFSET 5
#define LTC2937_V6_UV_ENABLE_MSK 0x0020
#define LTC2937_V6_UV_ENABLE (LTC2937_V6_UV_ENABLE_OFFSET << 12 | (LTC2937_V6_UV_ENABLE_SIZE - 1) << 8 | LTC2937_V6_UV_ENABLE_SUBADDR)
#define LTC2937_V6_UV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V6_UV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V5_UV_ENABLE V5_UV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V5_UV_ENABLE Bit Field
 *
 *  Maps Channel 5 UV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 4
 *   - MSB: 4
 *   - MASK: 0x0010
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_V5_UV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V5_UV_ENABLE "V5_UV_ENABLE"
#define LTC2937_V5_UV_ENABLE_SIZE 1
#define LTC2937_V5_UV_ENABLE_OFFSET 4
#define LTC2937_V5_UV_ENABLE_MSK 0x0010
#define LTC2937_V5_UV_ENABLE (LTC2937_V5_UV_ENABLE_OFFSET << 12 | (LTC2937_V5_UV_ENABLE_SIZE - 1) << 8 | LTC2937_V5_UV_ENABLE_SUBADDR)
#define LTC2937_V5_UV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V5_UV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V4_UV_ENABLE V4_UV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V4_UV_ENABLE Bit Field
 *
 *  Maps Channel 4 UV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 3
 *   - MSB: 3
 *   - MASK: 0x0008
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_V4_UV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V4_UV_ENABLE "V4_UV_ENABLE"
#define LTC2937_V4_UV_ENABLE_SIZE 1
#define LTC2937_V4_UV_ENABLE_OFFSET 3
#define LTC2937_V4_UV_ENABLE_MSK 0x0008
#define LTC2937_V4_UV_ENABLE (LTC2937_V4_UV_ENABLE_OFFSET << 12 | (LTC2937_V4_UV_ENABLE_SIZE - 1) << 8 | LTC2937_V4_UV_ENABLE_SUBADDR)
#define LTC2937_V4_UV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V4_UV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V3_UV_ENABLE V3_UV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V3_UV_ENABLE Bit Field
 *
 *  Maps Channel 3 UV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 2
 *   - MSB: 2
 *   - MASK: 0x0004
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_V3_UV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V3_UV_ENABLE "V3_UV_ENABLE"
#define LTC2937_V3_UV_ENABLE_SIZE 1
#define LTC2937_V3_UV_ENABLE_OFFSET 2
#define LTC2937_V3_UV_ENABLE_MSK 0x0004
#define LTC2937_V3_UV_ENABLE (LTC2937_V3_UV_ENABLE_OFFSET << 12 | (LTC2937_V3_UV_ENABLE_SIZE - 1) << 8 | LTC2937_V3_UV_ENABLE_SUBADDR)
#define LTC2937_V3_UV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V3_UV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V2_UV_ENABLE V2_UV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V2_UV_ENABLE Bit Field
 *
 *  Maps Channel 2 UV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_V2_UV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V2_UV_ENABLE "V2_UV_ENABLE"
#define LTC2937_V2_UV_ENABLE_SIZE 1
#define LTC2937_V2_UV_ENABLE_OFFSET 1
#define LTC2937_V2_UV_ENABLE_MSK 0x0002
#define LTC2937_V2_UV_ENABLE (LTC2937_V2_UV_ENABLE_OFFSET << 12 | (LTC2937_V2_UV_ENABLE_SIZE - 1) << 8 | LTC2937_V2_UV_ENABLE_SUBADDR)
#define LTC2937_V2_UV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V2_UV_ENABLE_PRESET_ENABLED 1
//!@}
/*! @defgroup LTC2937_V1_UV_ENABLE V1_UV_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief V1_UV_ENABLE Bit Field
 *
 *  Maps Channel 1 UV into RSTB output.
 *   - Register: @ref LTC2937_RSTB_CONFIG_CMD "RSTB_CONFIG_CMD"
 *   - CommandCode: 34
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_V1_UV_ENABLE_SUBADDR LTC2937_RSTB_CONFIG_CMD_SUBADDR //!< @ref LTC2937_V1_UV_ENABLE "V1_UV_ENABLE"
#define LTC2937_V1_UV_ENABLE_SIZE 1
#define LTC2937_V1_UV_ENABLE_OFFSET 0
#define LTC2937_V1_UV_ENABLE_MSK 0x0001
#define LTC2937_V1_UV_ENABLE (LTC2937_V1_UV_ENABLE_OFFSET << 12 | (LTC2937_V1_UV_ENABLE_SIZE - 1) << 8 | LTC2937_V1_UV_ENABLE_SUBADDR)
#define LTC2937_V1_UV_ENABLE_PRESET_NOT_ENABLED 0
#define LTC2937_V1_UV_ENABLE_PRESET_ENABLED 1
//!@}

/*! @defgroup LTC2937_FAULT_RESPONSE_CMD FAULT_RESPONSE_CMD
 *  @ingroup LTC2937_register_map
 *  @brief FAULT_RESPONSE_CMD Register
 *
 * | 15:14 |       13:11 |           10 |           9 |      8 |         7:5 |                   4:3 |          2:0 |
 * |:-----:|:-----------:|:------------:|:-----------:|:------:|:-----------:|:---------------------:|:------------:|
 * |   n/a | RETRY_COUNT | FAULTB_STATE | FAULTB_MASK | FREEZE | RETRY_DELAY | FAULT_RESPONSE_ACTION | RETRY_NUMBER |
 *
 *   - CommandCode: 35
 *   - Contains Bit Fields:
 *     + @ref LTC2937_RETRY_COUNT "RETRY_COUNT" : Read the number of retries attempted.
 *     + @ref LTC2937_FAULTB_STATE "FAULTB_STATE" : Reports the Fault Pin state.
 *     + @ref LTC2937_FAULTB_MASK "FAULTB_MASK" : Determines how device responds to external faults.
 *     + @ref LTC2937_FREEZE "FREEZE" : System Freeze Control. Refer to Presets for Values
 *     + @ref LTC2937_RETRY_DELAY "RETRY_DELAY" : Fault Retry Delay Settings.
 *     + @ref LTC2937_FAULT_RESPONSE_ACTION "FAULT_RESPONSE_ACTION" : Fault response action.
 *     + @ref LTC2937_RETRY_NUMBER "RETRY_NUMBER" : Automatic Retry count.
*/

//!@{
#define LTC2937_FAULT_RESPONSE_CMD_SUBADDR 35
#define LTC2937_FAULT_RESPONSE_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_FAULT_RESPONSE_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_RETRY_COUNT RETRY_COUNT
 *  @ingroup LTC2937_register_map
 *  @brief RETRY_COUNT Bit Field
 *
 *  Read the number of retries attempted.
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 3
 *   - Offset: 11
 *   - MSB: 13
 *   - MASK: 0x3800
 *   - Access: R/W
 *   - Default: n/a
 */
//!@{
#define LTC2937_RETRY_COUNT_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_RETRY_COUNT "RETRY_COUNT"
#define LTC2937_RETRY_COUNT_SIZE 3
#define LTC2937_RETRY_COUNT_OFFSET 11
#define LTC2937_RETRY_COUNT_MSK 0x3800
#define LTC2937_RETRY_COUNT (LTC2937_RETRY_COUNT_OFFSET << 12 | (LTC2937_RETRY_COUNT_SIZE - 1) << 8 | LTC2937_RETRY_COUNT_SUBADDR)
#define LTC2937_RETRY_COUNT_PRESET_UNDEFINED 7
//!@}
/*! @defgroup LTC2937_FAULTB_STATE FAULTB_STATE
 *  @ingroup LTC2937_register_map
 *  @brief FAULTB_STATE Bit Field
 *
 *  Reports the Fault Pin state.
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: n/a
 */
//!@{
#define LTC2937_FAULTB_STATE_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_FAULTB_STATE "FAULTB_STATE"
#define LTC2937_FAULTB_STATE_SIZE 1
#define LTC2937_FAULTB_STATE_OFFSET 10
#define LTC2937_FAULTB_STATE_MSK 0x0400
#define LTC2937_FAULTB_STATE (LTC2937_FAULTB_STATE_OFFSET << 12 | (LTC2937_FAULTB_STATE_SIZE - 1) << 8 | LTC2937_FAULTB_STATE_SUBADDR)
#define LTC2937_FAULTB_STATE_PRESET_HIGH 1
#define LTC2937_FAULTB_STATE_PRESET_LOW 0
//!@}
/*! @defgroup LTC2937_FAULTB_MASK FAULTB_MASK
 *  @ingroup LTC2937_register_map
 *  @brief FAULTB_MASK Bit Field
 *
 *  Determines how device responds to external faults.
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 1
 *   - Offset: 9
 *   - MSB: 9
 *   - MASK: 0x0200
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_FAULTB_MASK_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_FAULTB_MASK "FAULTB_MASK"
#define LTC2937_FAULTB_MASK_SIZE 1
#define LTC2937_FAULTB_MASK_OFFSET 9
#define LTC2937_FAULTB_MASK_MSK 0x0200
#define LTC2937_FAULTB_MASK (LTC2937_FAULTB_MASK_OFFSET << 12 | (LTC2937_FAULTB_MASK_SIZE - 1) << 8 | LTC2937_FAULTB_MASK_SUBADDR)
#define LTC2937_FAULTB_MASK_PRESET_IGNORE_EXTERNAL_FAULTB_PULLDOWN 0
#define LTC2937_FAULTB_MASK_PRESET_RESPOND_TO_EXTERNAL_FAULTB_PULLDOWN 1
//!@}
/*! @defgroup LTC2937_FREEZE FREEZE
 *  @ingroup LTC2937_register_map
 *  @brief FREEZE Bit Field
 *
 *  System Freeze Control. Refer to Presets for Values
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 1
 *   - Offset: 8
 *   - MSB: 8
 *   - MASK: 0x0100
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_FREEZE_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_FREEZE "FREEZE"
#define LTC2937_FREEZE_SIZE 1
#define LTC2937_FREEZE_OFFSET 8
#define LTC2937_FREEZE_MSK 0x0100
#define LTC2937_FREEZE (LTC2937_FREEZE_OFFSET << 12 | (LTC2937_FREEZE_SIZE - 1) << 8 | LTC2937_FREEZE_SUBADDR)
#define LTC2937_FREEZE_PRESET_DO_NOT_FREEZE_ON_FAULT 0
#define LTC2937_FREEZE_PRESET_FREEZE_DEVICE_STATE_ON_FAULT 1
//!@}
/*! @defgroup LTC2937_RETRY_DELAY RETRY_DELAY
 *  @ingroup LTC2937_register_map
 *  @brief RETRY_DELAY Bit Field
 *
 *  Fault Retry Delay Settings.
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 3
 *   - Offset: 5
 *   - MSB: 7
 *   - MASK: 0x00E0
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_RETRY_DELAY_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_RETRY_DELAY "RETRY_DELAY"
#define LTC2937_RETRY_DELAY_SIZE 3
#define LTC2937_RETRY_DELAY_OFFSET 5
#define LTC2937_RETRY_DELAY_MSK 0x00E0
#define LTC2937_RETRY_DELAY (LTC2937_RETRY_DELAY_OFFSET << 12 | (LTC2937_RETRY_DELAY_SIZE - 1) << 8 | LTC2937_RETRY_DELAY_SUBADDR)
#define LTC2937_RETRY_DELAY_PRESET_0_05MS 0
#define LTC2937_RETRY_DELAY_PRESET_200MS 1
#define LTC2937_RETRY_DELAY_PRESET_410MS 2
#define LTC2937_RETRY_DELAY_PRESET_820MS 3
#define LTC2937_RETRY_DELAY_PRESET_1_64S 4
#define LTC2937_RETRY_DELAY_PRESET_3_28S 5
#define LTC2937_RETRY_DELAY_PRESET_6_55S 6
#define LTC2937_RETRY_DELAY_PRESET_13_1S 7
//!@}
/*! @defgroup LTC2937_FAULT_RESPONSE_ACTION FAULT_RESPONSE_ACTION
 *  @ingroup LTC2937_register_map
 *  @brief FAULT_RESPONSE_ACTION Bit Field
 *
 *  Fault response action.
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 2
 *   - Offset: 3
 *   - MSB: 4
 *   - MASK: 0x0018
 *   - Access: R/W
 *   - Default: 1
 */
//!@{
#define LTC2937_FAULT_RESPONSE_ACTION_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_FAULT_RESPONSE_ACTION "FAULT_RESPONSE_ACTION"
#define LTC2937_FAULT_RESPONSE_ACTION_SIZE 2
#define LTC2937_FAULT_RESPONSE_ACTION_OFFSET 3
#define LTC2937_FAULT_RESPONSE_ACTION_MSK 0x0018
#define LTC2937_FAULT_RESPONSE_ACTION (LTC2937_FAULT_RESPONSE_ACTION_OFFSET << 12 | (LTC2937_FAULT_RESPONSE_ACTION_SIZE - 1) << 8 | LTC2937_FAULT_RESPONSE_ACTION_SUBADDR)
#define LTC2937_FAULT_RESPONSE_ACTION_PRESET_CONTINUE_OPERATION 0
#define LTC2937_FAULT_RESPONSE_ACTION_PRESET_DISCHARGED_RETRY 1
#define LTC2937_FAULT_RESPONSE_ACTION_PRESET_DELAYED_RETRY 2
#define LTC2937_FAULT_RESPONSE_ACTION_PRESET_DISCHARGE_AND_DELAY_RETRY 3
//!@}
/*! @defgroup LTC2937_RETRY_NUMBER RETRY_NUMBER
 *  @ingroup LTC2937_register_map
 *  @brief RETRY_NUMBER Bit Field
 *
 *  Automatic Retry count.
 *   - Register: @ref LTC2937_FAULT_RESPONSE_CMD "FAULT_RESPONSE_CMD"
 *   - CommandCode: 35
 *   - Size: 3
 *   - Offset: 0
 *   - MSB: 2
 *   - MASK: 0x0007
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_RETRY_NUMBER_SUBADDR LTC2937_FAULT_RESPONSE_CMD_SUBADDR //!< @ref LTC2937_RETRY_NUMBER "RETRY_NUMBER"
#define LTC2937_RETRY_NUMBER_SIZE 3
#define LTC2937_RETRY_NUMBER_OFFSET 0
#define LTC2937_RETRY_NUMBER_MSK 0x0007
#define LTC2937_RETRY_NUMBER (LTC2937_RETRY_NUMBER_OFFSET << 12 | (LTC2937_RETRY_NUMBER_SIZE - 1) << 8 | LTC2937_RETRY_NUMBER_SUBADDR)
#define LTC2937_RETRY_NUMBER_PRESET_DO_NOT_ATTEMPT_TO_RETRY 0
#define LTC2937_RETRY_NUMBER_PRESET_RETRY_1_TIMES 1
#define LTC2937_RETRY_NUMBER_PRESET_RETRY_2_TIMES 2
#define LTC2937_RETRY_NUMBER_PRESET_RETRY_3_TIMES 3
#define LTC2937_RETRY_NUMBER_PRESET_RETRY_4_TIMES 4
#define LTC2937_RETRY_NUMBER_PRESET_RETRY_5_TIMES 5
#define LTC2937_RETRY_NUMBER_PRESET_RETRY_6_TIMES 6
#define LTC2937_RETRY_NUMBER_PRESET_UNLIMITED_RETRIES 7
//!@}

/*! @defgroup LTC2937_MONITOR_STATUS_HISTORY_CMD MONITOR_STATUS_HISTORY_CMD
 *  @ingroup LTC2937_register_map
 *  @brief MONITOR_STATUS_HISTORY_CMD Register
 *
 * |        15:13 |              12 |             11 |             10 |              9 |              8 |              7 |              6 |              5 |              4 |              3 |              2 |              1 |              0 |
 * |:------------:|:---------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|:--------------:|
 * | SF_CHAN_HIST | SV_FAULT_STATUS | V6_OV_SV_FAULT | V6_UV_SV_FAULT | V5_OV_SV_FAULT | V5_UV_SV_FAULT | V4_OV_SV_FAULT | V4_UV_SV_FAULT | V3_OV_SV_FAULT | V3_UV_SV_FAULT | V2_OV_SV_FAULT | V2_UV_SV_FAULT | V1_OV_SV_FAULT | V1_UV_SV_FAULT |
 *
 *   - CommandCode: 38
 *   - Contains Bit Fields:
 *     + @ref LTC2937_SF_CHAN_HIST "SF_CHAN_HIST" : Reports the channel responsible for a sequence fault. If multiple channels fault, the lowest channel is reported.
 *     + @ref LTC2937_SV_FAULT_STATUS "SV_FAULT_STATUS" : Indicates the occurrence of a Supervisor fault.
 *     + @ref LTC2937_V6_OV_SV_FAULT "V6_OV_SV_FAULT" : V6 OV Supervisor Fault history.
 *     + @ref LTC2937_V6_UV_SV_FAULT "V6_UV_SV_FAULT" : V6 UV Supervisor Fault history.
 *     + @ref LTC2937_V5_OV_SV_FAULT "V5_OV_SV_FAULT" : V5 OV Supervisor Fault history.
 *     + @ref LTC2937_V5_UV_SV_FAULT "V5_UV_SV_FAULT" : V5 UV Supervisor Fault history.
 *     + @ref LTC2937_V4_OV_SV_FAULT "V4_OV_SV_FAULT" : V4 OV Supervisor Fault history.
 *     + @ref LTC2937_V4_UV_SV_FAULT "V4_UV_SV_FAULT" : V4 UV Supervisor Fault history.
 *     + @ref LTC2937_V3_OV_SV_FAULT "V3_OV_SV_FAULT" : V3 OV Supervisor Fault history.
 *     + @ref LTC2937_V3_UV_SV_FAULT "V3_UV_SV_FAULT" : V3 UV Supervisor Fault history.
 *     + @ref LTC2937_V2_OV_SV_FAULT "V2_OV_SV_FAULT" : V2 OV Supervisor Fault history.
 *     + @ref LTC2937_V2_UV_SV_FAULT "V2_UV_SV_FAULT" : V2 UV Supervisor Fault history.
 *     + @ref LTC2937_V1_OV_SV_FAULT "V1_OV_SV_FAULT" : V1 OV Supervisor Fault history.
 *     + @ref LTC2937_V1_UV_SV_FAULT "V1_UV_SV_FAULT" : V1 UV Supervisor Fault history.
*/

//!@{
#define LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR 38
#define LTC2937_MONITOR_STATUS_HISTORY_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_SF_CHAN_HIST SF_CHAN_HIST
 *  @ingroup LTC2937_register_map
 *  @brief SF_CHAN_HIST Bit Field
 *
 *  Reports the channel responsible for a sequence fault. If multiple channels fault, the lowest channel is reported.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SF_CHAN_HIST_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_SF_CHAN_HIST "SF_CHAN_HIST"
#define LTC2937_SF_CHAN_HIST_SIZE 3
#define LTC2937_SF_CHAN_HIST_OFFSET 13
#define LTC2937_SF_CHAN_HIST_MSK 0xE000
#define LTC2937_SF_CHAN_HIST (LTC2937_SF_CHAN_HIST_OFFSET << 12 | (LTC2937_SF_CHAN_HIST_SIZE - 1) << 8 | LTC2937_SF_CHAN_HIST_SUBADDR)
#define LTC2937_SF_CHAN_HIST_PRESET_NONE 0
#define LTC2937_SF_CHAN_HIST_PRESET_V1 1
#define LTC2937_SF_CHAN_HIST_PRESET_V2 2
#define LTC2937_SF_CHAN_HIST_PRESET_V3 3
#define LTC2937_SF_CHAN_HIST_PRESET_V4 4
#define LTC2937_SF_CHAN_HIST_PRESET_V5 5
#define LTC2937_SF_CHAN_HIST_PRESET_V6 6
#define LTC2937_SF_CHAN_HIST_PRESET_UNDEFINED 7
//!@}
/*! @defgroup LTC2937_SV_FAULT_STATUS SV_FAULT_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief SV_FAULT_STATUS Bit Field
 *
 *  Indicates the occurrence of a Supervisor fault.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 12
 *   - MSB: 12
 *   - MASK: 0x1000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SV_FAULT_STATUS_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_SV_FAULT_STATUS "SV_FAULT_STATUS"
#define LTC2937_SV_FAULT_STATUS_SIZE 1
#define LTC2937_SV_FAULT_STATUS_OFFSET 12
#define LTC2937_SV_FAULT_STATUS_MSK 0x1000
#define LTC2937_SV_FAULT_STATUS (LTC2937_SV_FAULT_STATUS_OFFSET << 12 | (LTC2937_SV_FAULT_STATUS_SIZE - 1) << 8 | LTC2937_SV_FAULT_STATUS_SUBADDR)
#define LTC2937_SV_FAULT_STATUS_PRESET_SUPERVISOR_FAULT_HAS_NOT_OCCURRED 0
#define LTC2937_SV_FAULT_STATUS_PRESET_SUPERVISOR_FAULT_HAS_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V6_OV_SV_FAULT V6_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V6_OV_SV_FAULT Bit Field
 *
 *  V6 OV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 11
 *   - MSB: 11
 *   - MASK: 0x0800
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V6_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V6_OV_SV_FAULT "V6_OV_SV_FAULT"
#define LTC2937_V6_OV_SV_FAULT_SIZE 1
#define LTC2937_V6_OV_SV_FAULT_OFFSET 11
#define LTC2937_V6_OV_SV_FAULT_MSK 0x0800
#define LTC2937_V6_OV_SV_FAULT (LTC2937_V6_OV_SV_FAULT_OFFSET << 12 | (LTC2937_V6_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V6_OV_SV_FAULT_SUBADDR)
#define LTC2937_V6_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V6_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V6_UV_SV_FAULT V6_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V6_UV_SV_FAULT Bit Field
 *
 *  V6 UV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V6_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V6_UV_SV_FAULT "V6_UV_SV_FAULT"
#define LTC2937_V6_UV_SV_FAULT_SIZE 1
#define LTC2937_V6_UV_SV_FAULT_OFFSET 10
#define LTC2937_V6_UV_SV_FAULT_MSK 0x0400
#define LTC2937_V6_UV_SV_FAULT (LTC2937_V6_UV_SV_FAULT_OFFSET << 12 | (LTC2937_V6_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V6_UV_SV_FAULT_SUBADDR)
#define LTC2937_V6_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V6_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V5_OV_SV_FAULT V5_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V5_OV_SV_FAULT Bit Field
 *
 *  V5 OV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 9
 *   - MSB: 9
 *   - MASK: 0x0200
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V5_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V5_OV_SV_FAULT "V5_OV_SV_FAULT"
#define LTC2937_V5_OV_SV_FAULT_SIZE 1
#define LTC2937_V5_OV_SV_FAULT_OFFSET 9
#define LTC2937_V5_OV_SV_FAULT_MSK 0x0200
#define LTC2937_V5_OV_SV_FAULT (LTC2937_V5_OV_SV_FAULT_OFFSET << 12 | (LTC2937_V5_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V5_OV_SV_FAULT_SUBADDR)
#define LTC2937_V5_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V5_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V5_UV_SV_FAULT V5_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V5_UV_SV_FAULT Bit Field
 *
 *  V5 UV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 8
 *   - MSB: 8
 *   - MASK: 0x0100
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V5_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V5_UV_SV_FAULT "V5_UV_SV_FAULT"
#define LTC2937_V5_UV_SV_FAULT_SIZE 1
#define LTC2937_V5_UV_SV_FAULT_OFFSET 8
#define LTC2937_V5_UV_SV_FAULT_MSK 0x0100
#define LTC2937_V5_UV_SV_FAULT (LTC2937_V5_UV_SV_FAULT_OFFSET << 12 | (LTC2937_V5_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V5_UV_SV_FAULT_SUBADDR)
#define LTC2937_V5_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V5_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V4_OV_SV_FAULT V4_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V4_OV_SV_FAULT Bit Field
 *
 *  V4 OV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 7
 *   - MSB: 7
 *   - MASK: 0x0080
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V4_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V4_OV_SV_FAULT "V4_OV_SV_FAULT"
#define LTC2937_V4_OV_SV_FAULT_SIZE 1
#define LTC2937_V4_OV_SV_FAULT_OFFSET 7
#define LTC2937_V4_OV_SV_FAULT_MSK 0x0080
#define LTC2937_V4_OV_SV_FAULT (LTC2937_V4_OV_SV_FAULT_OFFSET << 12 | (LTC2937_V4_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V4_OV_SV_FAULT_SUBADDR)
#define LTC2937_V4_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V4_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V4_UV_SV_FAULT V4_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V4_UV_SV_FAULT Bit Field
 *
 *  V4 UV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 6
 *   - MSB: 6
 *   - MASK: 0x0040
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V4_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V4_UV_SV_FAULT "V4_UV_SV_FAULT"
#define LTC2937_V4_UV_SV_FAULT_SIZE 1
#define LTC2937_V4_UV_SV_FAULT_OFFSET 6
#define LTC2937_V4_UV_SV_FAULT_MSK 0x0040
#define LTC2937_V4_UV_SV_FAULT (LTC2937_V4_UV_SV_FAULT_OFFSET << 12 | (LTC2937_V4_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V4_UV_SV_FAULT_SUBADDR)
#define LTC2937_V4_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V4_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V3_OV_SV_FAULT V3_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V3_OV_SV_FAULT Bit Field
 *
 *  V3 OV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 5
 *   - MSB: 5
 *   - MASK: 0x0020
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V3_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V3_OV_SV_FAULT "V3_OV_SV_FAULT"
#define LTC2937_V3_OV_SV_FAULT_SIZE 1
#define LTC2937_V3_OV_SV_FAULT_OFFSET 5
#define LTC2937_V3_OV_SV_FAULT_MSK 0x0020
#define LTC2937_V3_OV_SV_FAULT (LTC2937_V3_OV_SV_FAULT_OFFSET << 12 | (LTC2937_V3_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V3_OV_SV_FAULT_SUBADDR)
#define LTC2937_V3_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V3_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V3_UV_SV_FAULT V3_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V3_UV_SV_FAULT Bit Field
 *
 *  V3 UV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 4
 *   - MSB: 4
 *   - MASK: 0x0010
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V3_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V3_UV_SV_FAULT "V3_UV_SV_FAULT"
#define LTC2937_V3_UV_SV_FAULT_SIZE 1
#define LTC2937_V3_UV_SV_FAULT_OFFSET 4
#define LTC2937_V3_UV_SV_FAULT_MSK 0x0010
#define LTC2937_V3_UV_SV_FAULT (LTC2937_V3_UV_SV_FAULT_OFFSET << 12 | (LTC2937_V3_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V3_UV_SV_FAULT_SUBADDR)
#define LTC2937_V3_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V3_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V2_OV_SV_FAULT V2_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V2_OV_SV_FAULT Bit Field
 *
 *  V2 OV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 3
 *   - MSB: 3
 *   - MASK: 0x0008
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V2_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V2_OV_SV_FAULT "V2_OV_SV_FAULT"
#define LTC2937_V2_OV_SV_FAULT_SIZE 1
#define LTC2937_V2_OV_SV_FAULT_OFFSET 3
#define LTC2937_V2_OV_SV_FAULT_MSK 0x0008
#define LTC2937_V2_OV_SV_FAULT (LTC2937_V2_OV_SV_FAULT_OFFSET << 12 | (LTC2937_V2_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V2_OV_SV_FAULT_SUBADDR)
#define LTC2937_V2_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V2_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V2_UV_SV_FAULT V2_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V2_UV_SV_FAULT Bit Field
 *
 *  V2 UV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 2
 *   - MSB: 2
 *   - MASK: 0x0004
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V2_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V2_UV_SV_FAULT "V2_UV_SV_FAULT"
#define LTC2937_V2_UV_SV_FAULT_SIZE 1
#define LTC2937_V2_UV_SV_FAULT_OFFSET 2
#define LTC2937_V2_UV_SV_FAULT_MSK 0x0004
#define LTC2937_V2_UV_SV_FAULT (LTC2937_V2_UV_SV_FAULT_OFFSET << 12 | (LTC2937_V2_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V2_UV_SV_FAULT_SUBADDR)
#define LTC2937_V2_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V2_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V1_OV_SV_FAULT V1_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V1_OV_SV_FAULT Bit Field
 *
 *  V1 OV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V1_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V1_OV_SV_FAULT "V1_OV_SV_FAULT"
#define LTC2937_V1_OV_SV_FAULT_SIZE 1
#define LTC2937_V1_OV_SV_FAULT_OFFSET 1
#define LTC2937_V1_OV_SV_FAULT_MSK 0x0002
#define LTC2937_V1_OV_SV_FAULT (LTC2937_V1_OV_SV_FAULT_OFFSET << 12 | (LTC2937_V1_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V1_OV_SV_FAULT_SUBADDR)
#define LTC2937_V1_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V1_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_V1_UV_SV_FAULT V1_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief V1_UV_SV_FAULT Bit Field
 *
 *  V1 UV Supervisor Fault history.
 *   - Register: @ref LTC2937_MONITOR_STATUS_HISTORY_CMD "MONITOR_STATUS_HISTORY_CMD"
 *   - CommandCode: 38
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V1_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_STATUS_HISTORY_CMD_SUBADDR //!< @ref LTC2937_V1_UV_SV_FAULT "V1_UV_SV_FAULT"
#define LTC2937_V1_UV_SV_FAULT_SIZE 1
#define LTC2937_V1_UV_SV_FAULT_OFFSET 0
#define LTC2937_V1_UV_SV_FAULT_MSK 0x0001
#define LTC2937_V1_UV_SV_FAULT (LTC2937_V1_UV_SV_FAULT_OFFSET << 12 | (LTC2937_V1_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_V1_UV_SV_FAULT_SUBADDR)
#define LTC2937_V1_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_V1_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}

/*! @defgroup LTC2937_CLEAR_ALERTB_CMD CLEAR_ALERTB_CMD
 *  @ingroup LTC2937_register_map
 *  @brief CLEAR_ALERTB_CMD Register
 *
 * |         15:0 |
 * |:------------:|
 * | CLEAR_ALERTB |
 *
 *   - CommandCode: 40
 *   - Contains Bit Fields:
 *     + @ref LTC2937_CLEAR_ALERTB "CLEAR_ALERTB" : Release the ALERTB pin.
*/

//!@{
#define LTC2937_CLEAR_ALERTB_CMD_SUBADDR 40
#define LTC2937_CLEAR_ALERTB_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_CLEAR_ALERTB_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_CLEAR_ALERTB CLEAR_ALERTB
 *  @ingroup LTC2937_register_map
 *  @brief CLEAR_ALERTB Bit Field
 *
 *  Release the ALERTB pin.
 *   - Register: @ref LTC2937_CLEAR_ALERTB_CMD "CLEAR_ALERTB_CMD"
 *   - CommandCode: 40
 *   - Size: 16
 *   - Offset: 0
 *   - MSB: 15
 *   - MASK: 0xFFFF
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_CLEAR_ALERTB_SUBADDR LTC2937_CLEAR_ALERTB_CMD_SUBADDR //!< @ref LTC2937_CLEAR_ALERTB "CLEAR_ALERTB"
#define LTC2937_CLEAR_ALERTB_SIZE 16
#define LTC2937_CLEAR_ALERTB_OFFSET 0
#define LTC2937_CLEAR_ALERTB_MSK 0xFFFF
#define LTC2937_CLEAR_ALERTB (LTC2937_CLEAR_ALERTB_OFFSET << 12 | (LTC2937_CLEAR_ALERTB_SIZE - 1) << 8 | LTC2937_CLEAR_ALERTB_SUBADDR)
//!@}

/*! @defgroup LTC2937_STATUS_INFORMATION_CMD STATUS_INFORMATION_CMD
 *  @ingroup LTC2937_register_map
 *  @brief STATUS_INFORMATION_CMD Register
 *
 * |      15:13 |       12 |            11:10 |              9:8 |            7 |              6 |        5 |        4 |        3 |         2 |                 1 |           0 |
 * |:----------:|:--------:|:----------------:|:----------------:|:------------:|:--------------:|:--------:|:--------:|:--------:|:---------:|:-----------------:|:-----------:|
 * | SF_CHANNEL | MB_STATE | LOCAL_SEQ_STATUS | GROUP_SEQ_STATUS | SEQ_UP_FAULT | SEQ_DOWN_FAULT | OV_FAULT | UV_FAULT | SV_FAULT | DISCHARGE | SEQ_CONTROL_FAULT | OTHER_FAULT |
 *
 *   - CommandCode: 41
 *   - Contains Bit Fields:
 *     + @ref LTC2937_SF_CHANNEL "SF_CHANNEL" : Reports the channel responsible for a sequence fault. If multiple channels fault, the lowest channel is reported.
 *     + @ref LTC2937_MB_STATE "MB_STATE" : Monitor Backup Status.
 *     + @ref LTC2937_LOCAL_SEQ_STATUS "LOCAL_SEQ_STATUS" : Addressed Device Sequencing Status.
 *     + @ref LTC2937_GROUP_SEQ_STATUS "GROUP_SEQ_STATUS" : Group Sequencing Status.
 *     + @ref LTC2937_SEQ_UP_FAULT "SEQ_UP_FAULT" : Maximum Turn_on time Fault.
 *     + @ref LTC2937_SEQ_DOWN_FAULT "SEQ_DOWN_FAULT" : Maximum Turn_off time Fault.
 *     + @ref LTC2937_OV_FAULT "OV_FAULT" : Supervisor fault by mapped OV channel.
 *     + @ref LTC2937_UV_FAULT "UV_FAULT" : Supervisor fault by mapped UV channel.
 *     + @ref LTC2937_SV_FAULT "SV_FAULT" : Supervisor Fault Status.
 *     + @ref LTC2937_DISCHARGE "DISCHARGE" : Sequenced channel group discharge status.
 *     + @ref LTC2937_SEQ_CONTROL_FAULT "SEQ_CONTROL_FAULT" : Control Fault Status.
 *     + @ref LTC2937_OTHER_FAULT "OTHER_FAULT" : External or SHARE_CLK fault status.
*/

//!@{
#define LTC2937_STATUS_INFORMATION_CMD_SUBADDR 41
#define LTC2937_STATUS_INFORMATION_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_STATUS_INFORMATION_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_SF_CHANNEL SF_CHANNEL
 *  @ingroup LTC2937_register_map
 *  @brief SF_CHANNEL Bit Field
 *
 *  Reports the channel responsible for a sequence fault. If multiple channels fault, the lowest channel is reported.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SF_CHANNEL_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_SF_CHANNEL "SF_CHANNEL"
#define LTC2937_SF_CHANNEL_SIZE 3
#define LTC2937_SF_CHANNEL_OFFSET 13
#define LTC2937_SF_CHANNEL_MSK 0xE000
#define LTC2937_SF_CHANNEL (LTC2937_SF_CHANNEL_OFFSET << 12 | (LTC2937_SF_CHANNEL_SIZE - 1) << 8 | LTC2937_SF_CHANNEL_SUBADDR)
#define LTC2937_SF_CHANNEL_PRESET_NONE 0
#define LTC2937_SF_CHANNEL_PRESET_V1 1
#define LTC2937_SF_CHANNEL_PRESET_V2 2
#define LTC2937_SF_CHANNEL_PRESET_V3 3
#define LTC2937_SF_CHANNEL_PRESET_V4 4
#define LTC2937_SF_CHANNEL_PRESET_V5 5
#define LTC2937_SF_CHANNEL_PRESET_V6 6
#define LTC2937_SF_CHANNEL_PRESET_UNDEFINED 7
//!@}
/*! @defgroup LTC2937_MB_STATE MB_STATE
 *  @ingroup LTC2937_register_map
 *  @brief MB_STATE Bit Field
 *
 *  Monitor Backup Status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 12
 *   - MSB: 12
 *   - MASK: 0x1000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_MB_STATE_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_MB_STATE "MB_STATE"
#define LTC2937_MB_STATE_SIZE 1
#define LTC2937_MB_STATE_OFFSET 12
#define LTC2937_MB_STATE_MSK 0x1000
#define LTC2937_MB_STATE (LTC2937_MB_STATE_OFFSET << 12 | (LTC2937_MB_STATE_SIZE - 1) << 8 | LTC2937_MB_STATE_SUBADDR)
#define LTC2937_MB_STATE_PRESET_EMPTY 0
#define LTC2937_MB_STATE_PRESET_WRITTEN 1
//!@}
/*! @defgroup LTC2937_LOCAL_SEQ_STATUS LOCAL_SEQ_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief LOCAL_SEQ_STATUS Bit Field
 *
 *  Addressed Device Sequencing Status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 2
 *   - Offset: 10
 *   - MSB: 11
 *   - MASK: 0x0C00
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_LOCAL_SEQ_STATUS_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_LOCAL_SEQ_STATUS "LOCAL_SEQ_STATUS"
#define LTC2937_LOCAL_SEQ_STATUS_SIZE 2
#define LTC2937_LOCAL_SEQ_STATUS_OFFSET 10
#define LTC2937_LOCAL_SEQ_STATUS_MSK 0x0C00
#define LTC2937_LOCAL_SEQ_STATUS (LTC2937_LOCAL_SEQ_STATUS_OFFSET << 12 | (LTC2937_LOCAL_SEQ_STATUS_SIZE - 1) << 8 | LTC2937_LOCAL_SEQ_STATUS_SUBADDR)
#define LTC2937_LOCAL_SEQ_STATUS_PRESET_SEQUENCE_DOWN_DONE 0
#define LTC2937_LOCAL_SEQ_STATUS_PRESET_SEQUENCE_UP_IN_PROGRESS 1
#define LTC2937_LOCAL_SEQ_STATUS_PRESET_SEQUENCE_DOWN_IN_PROGRESS 2
#define LTC2937_LOCAL_SEQ_STATUS_PRESET_SEQUENCE_UP_DONE 3
//!@}
/*! @defgroup LTC2937_GROUP_SEQ_STATUS GROUP_SEQ_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief GROUP_SEQ_STATUS Bit Field
 *
 *  Group Sequencing Status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 2
 *   - Offset: 8
 *   - MSB: 9
 *   - MASK: 0x0300
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_GROUP_SEQ_STATUS_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_GROUP_SEQ_STATUS "GROUP_SEQ_STATUS"
#define LTC2937_GROUP_SEQ_STATUS_SIZE 2
#define LTC2937_GROUP_SEQ_STATUS_OFFSET 8
#define LTC2937_GROUP_SEQ_STATUS_MSK 0x0300
#define LTC2937_GROUP_SEQ_STATUS (LTC2937_GROUP_SEQ_STATUS_OFFSET << 12 | (LTC2937_GROUP_SEQ_STATUS_SIZE - 1) << 8 | LTC2937_GROUP_SEQ_STATUS_SUBADDR)
#define LTC2937_GROUP_SEQ_STATUS_PRESET_SEQUENCE_DOWN_DONE 0
#define LTC2937_GROUP_SEQ_STATUS_PRESET_SEQUENCE_UP_IN_PROGRESS 1
#define LTC2937_GROUP_SEQ_STATUS_PRESET_SEQUENCE_DOWN_IN_PROGRESS 2
#define LTC2937_GROUP_SEQ_STATUS_PRESET_SEQUENCE_UP_DONE 3
//!@}
/*! @defgroup LTC2937_SEQ_UP_FAULT SEQ_UP_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_UP_FAULT Bit Field
 *
 *  Maximum Turn_on time Fault.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 7
 *   - MSB: 7
 *   - MASK: 0x0080
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SEQ_UP_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_SEQ_UP_FAULT "SEQ_UP_FAULT"
#define LTC2937_SEQ_UP_FAULT_SIZE 1
#define LTC2937_SEQ_UP_FAULT_OFFSET 7
#define LTC2937_SEQ_UP_FAULT_MSK 0x0080
#define LTC2937_SEQ_UP_FAULT (LTC2937_SEQ_UP_FAULT_OFFSET << 12 | (LTC2937_SEQ_UP_FAULT_SIZE - 1) << 8 | LTC2937_SEQ_UP_FAULT_SUBADDR)
#define LTC2937_SEQ_UP_FAULT_PRESET_NO_FAULT 0
#define LTC2937_SEQ_UP_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_SEQ_DOWN_FAULT SEQ_DOWN_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_DOWN_FAULT Bit Field
 *
 *  Maximum Turn_off time Fault.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 6
 *   - MSB: 6
 *   - MASK: 0x0040
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SEQ_DOWN_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_SEQ_DOWN_FAULT "SEQ_DOWN_FAULT"
#define LTC2937_SEQ_DOWN_FAULT_SIZE 1
#define LTC2937_SEQ_DOWN_FAULT_OFFSET 6
#define LTC2937_SEQ_DOWN_FAULT_MSK 0x0040
#define LTC2937_SEQ_DOWN_FAULT (LTC2937_SEQ_DOWN_FAULT_OFFSET << 12 | (LTC2937_SEQ_DOWN_FAULT_SIZE - 1) << 8 | LTC2937_SEQ_DOWN_FAULT_SUBADDR)
#define LTC2937_SEQ_DOWN_FAULT_PRESET_NO_FAULT 0
#define LTC2937_SEQ_DOWN_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_OV_FAULT OV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief OV_FAULT Bit Field
 *
 *  Supervisor fault by mapped OV channel.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 5
 *   - MSB: 5
 *   - MASK: 0x0020
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_OV_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_OV_FAULT "OV_FAULT"
#define LTC2937_OV_FAULT_SIZE 1
#define LTC2937_OV_FAULT_OFFSET 5
#define LTC2937_OV_FAULT_MSK 0x0020
#define LTC2937_OV_FAULT (LTC2937_OV_FAULT_OFFSET << 12 | (LTC2937_OV_FAULT_SIZE - 1) << 8 | LTC2937_OV_FAULT_SUBADDR)
#define LTC2937_OV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_OV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_UV_FAULT UV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief UV_FAULT Bit Field
 *
 *  Supervisor fault by mapped UV channel.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 4
 *   - MSB: 4
 *   - MASK: 0x0010
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_UV_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_UV_FAULT "UV_FAULT"
#define LTC2937_UV_FAULT_SIZE 1
#define LTC2937_UV_FAULT_OFFSET 4
#define LTC2937_UV_FAULT_MSK 0x0010
#define LTC2937_UV_FAULT (LTC2937_UV_FAULT_OFFSET << 12 | (LTC2937_UV_FAULT_SIZE - 1) << 8 | LTC2937_UV_FAULT_SUBADDR)
#define LTC2937_UV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_UV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_SV_FAULT SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief SV_FAULT Bit Field
 *
 *  Supervisor Fault Status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 3
 *   - MSB: 3
 *   - MASK: 0x0008
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SV_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_SV_FAULT "SV_FAULT"
#define LTC2937_SV_FAULT_SIZE 1
#define LTC2937_SV_FAULT_OFFSET 3
#define LTC2937_SV_FAULT_MSK 0x0008
#define LTC2937_SV_FAULT (LTC2937_SV_FAULT_OFFSET << 12 | (LTC2937_SV_FAULT_SIZE - 1) << 8 | LTC2937_SV_FAULT_SUBADDR)
#define LTC2937_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_DISCHARGE DISCHARGE
 *  @ingroup LTC2937_register_map
 *  @brief DISCHARGE Bit Field
 *
 *  Sequenced channel group discharge status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 2
 *   - MSB: 2
 *   - MASK: 0x0004
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_DISCHARGE_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_DISCHARGE "DISCHARGE"
#define LTC2937_DISCHARGE_SIZE 1
#define LTC2937_DISCHARGE_OFFSET 2
#define LTC2937_DISCHARGE_MSK 0x0004
#define LTC2937_DISCHARGE (LTC2937_DISCHARGE_OFFSET << 12 | (LTC2937_DISCHARGE_SIZE - 1) << 8 | LTC2937_DISCHARGE_SUBADDR)
#define LTC2937_DISCHARGE_PRESET_ONE_OR_MORE_SEQUENCED_CHANNELS_NOT_DISCHARGED 0
#define LTC2937_DISCHARGE_PRESET_ALL_SEQUENCED_CHANNELS_ARE_BELOW_DISCHARGE_THRESHOLDS 1
//!@}
/*! @defgroup LTC2937_SEQ_CONTROL_FAULT SEQ_CONTROL_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_CONTROL_FAULT Bit Field
 *
 *  Control Fault Status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SEQ_CONTROL_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_SEQ_CONTROL_FAULT "SEQ_CONTROL_FAULT"
#define LTC2937_SEQ_CONTROL_FAULT_SIZE 1
#define LTC2937_SEQ_CONTROL_FAULT_OFFSET 1
#define LTC2937_SEQ_CONTROL_FAULT_MSK 0x0002
#define LTC2937_SEQ_CONTROL_FAULT (LTC2937_SEQ_CONTROL_FAULT_OFFSET << 12 | (LTC2937_SEQ_CONTROL_FAULT_SIZE - 1) << 8 | LTC2937_SEQ_CONTROL_FAULT_SUBADDR)
#define LTC2937_SEQ_CONTROL_FAULT_PRESET_NO_FAULT 0
#define LTC2937_SEQ_CONTROL_FAULT_PRESET_FAULT 1
//!@}
/*! @defgroup LTC2937_OTHER_FAULT OTHER_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief OTHER_FAULT Bit Field
 *
 *  External or SHARE_CLK fault status.
 *   - Register: @ref LTC2937_STATUS_INFORMATION_CMD "STATUS_INFORMATION_CMD"
 *   - CommandCode: 41
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_OTHER_FAULT_SUBADDR LTC2937_STATUS_INFORMATION_CMD_SUBADDR //!< @ref LTC2937_OTHER_FAULT "OTHER_FAULT"
#define LTC2937_OTHER_FAULT_SIZE 1
#define LTC2937_OTHER_FAULT_OFFSET 0
#define LTC2937_OTHER_FAULT_MSK 0x0001
#define LTC2937_OTHER_FAULT (LTC2937_OTHER_FAULT_OFFSET << 12 | (LTC2937_OTHER_FAULT_SIZE - 1) << 8 | LTC2937_OTHER_FAULT_SUBADDR)
#define LTC2937_OTHER_FAULT_PRESET_NO_FAULT 0
#define LTC2937_OTHER_FAULT_PRESET_FAULT_OCCURRED 1
//!@}

/*! @defgroup LTC2937_BREAK_POINT_CMD BREAK_POINT_CMD
 *  @ingroup LTC2937_register_map
 *  @brief BREAK_POINT_CMD Register
 *
 * | 15:11 |        10 |      9:0 |
 * |:-----:|:---------:|:--------:|
 * |   n/a | BP_ENABLE | BP_VALUE |
 *
 *   - CommandCode: 42
 *   - Contains Bit Fields:
 *     + @ref LTC2937_BP_ENABLE "BP_ENABLE" : Break Point Enable.
 *     + @ref LTC2937_BP_VALUE "BP_VALUE" : Break Point Sequence Position Value.
*/

//!@{
#define LTC2937_BREAK_POINT_CMD_SUBADDR 42
#define LTC2937_BREAK_POINT_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_BREAK_POINT_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_BP_ENABLE BP_ENABLE
 *  @ingroup LTC2937_register_map
 *  @brief BP_ENABLE Bit Field
 *
 *  Break Point Enable.
 *   - Register: @ref LTC2937_BREAK_POINT_CMD "BREAK_POINT_CMD"
 *   - CommandCode: 42
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_BP_ENABLE_SUBADDR LTC2937_BREAK_POINT_CMD_SUBADDR //!< @ref LTC2937_BP_ENABLE "BP_ENABLE"
#define LTC2937_BP_ENABLE_SIZE 1
#define LTC2937_BP_ENABLE_OFFSET 10
#define LTC2937_BP_ENABLE_MSK 0x0400
#define LTC2937_BP_ENABLE (LTC2937_BP_ENABLE_OFFSET << 12 | (LTC2937_BP_ENABLE_SIZE - 1) << 8 | LTC2937_BP_ENABLE_SUBADDR)
#define LTC2937_BP_ENABLE_PRESET_BREAK_POINT_NOT_ENABLED 0
#define LTC2937_BP_ENABLE_PRESET_BREAK_POINT_ENABLED 1
//!@}
/*! @defgroup LTC2937_BP_VALUE BP_VALUE
 *  @ingroup LTC2937_register_map
 *  @brief BP_VALUE Bit Field
 *
 *  Break Point Sequence Position Value.
 *   - Register: @ref LTC2937_BREAK_POINT_CMD "BREAK_POINT_CMD"
 *   - CommandCode: 42
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R/W
 *   - Default: 0
 */
//!@{
#define LTC2937_BP_VALUE_SUBADDR LTC2937_BREAK_POINT_CMD_SUBADDR //!< @ref LTC2937_BP_VALUE "BP_VALUE"
#define LTC2937_BP_VALUE_SIZE 10
#define LTC2937_BP_VALUE_OFFSET 0
#define LTC2937_BP_VALUE_MSK 0x03FF
#define LTC2937_BP_VALUE (LTC2937_BP_VALUE_OFFSET << 12 | (LTC2937_BP_VALUE_SIZE - 1) << 8 | LTC2937_BP_VALUE_SUBADDR)
//!@}

/*! @defgroup LTC2937_SEQ_POSITION_COUNT_CMD SEQ_POSITION_COUNT_CMD
 *  @ingroup LTC2937_register_map
 *  @brief SEQ_POSITION_COUNT_CMD Register
 *
 * | 15:11 |         10 |      9:0 |
 * |:-----:|:----------:|:--------:|
 * |   n/a | SP_BP_TEST | SP_COUNT |
 *
 *   - CommandCode: 43
 *   - Contains Bit Fields:
 *     + @ref LTC2937_SP_BP_TEST "SP_BP_TEST" : Compare sp_count with bp_value.
 *     + @ref LTC2937_SP_COUNT "SP_COUNT" : Sequence Position Count.
*/

//!@{
#define LTC2937_SEQ_POSITION_COUNT_CMD_SUBADDR 43
#define LTC2937_SEQ_POSITION_COUNT_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_SEQ_POSITION_COUNT_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_SP_BP_TEST SP_BP_TEST
 *  @ingroup LTC2937_register_map
 *  @brief SP_BP_TEST Bit Field
 *
 *  Compare sp_count with bp_value.
 *   - Register: @ref LTC2937_SEQ_POSITION_COUNT_CMD "SEQ_POSITION_COUNT_CMD"
 *   - CommandCode: 43
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SP_BP_TEST_SUBADDR LTC2937_SEQ_POSITION_COUNT_CMD_SUBADDR //!< @ref LTC2937_SP_BP_TEST "SP_BP_TEST"
#define LTC2937_SP_BP_TEST_SIZE 1
#define LTC2937_SP_BP_TEST_OFFSET 10
#define LTC2937_SP_BP_TEST_MSK 0x0400
#define LTC2937_SP_BP_TEST (LTC2937_SP_BP_TEST_OFFSET << 12 | (LTC2937_SP_BP_TEST_SIZE - 1) << 8 | LTC2937_SP_BP_TEST_SUBADDR)
#define LTC2937_SP_BP_TEST_PRESET_NOT_EQUAL 0
#define LTC2937_SP_BP_TEST_PRESET_EQUAL 1
//!@}
/*! @defgroup LTC2937_SP_COUNT SP_COUNT
 *  @ingroup LTC2937_register_map
 *  @brief SP_COUNT Bit Field
 *
 *  Sequence Position Count.
 *   - Register: @ref LTC2937_SEQ_POSITION_COUNT_CMD "SEQ_POSITION_COUNT_CMD"
 *   - CommandCode: 43
 *   - Size: 10
 *   - Offset: 0
 *   - MSB: 9
 *   - MASK: 0x03FF
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_SP_COUNT_SUBADDR LTC2937_SEQ_POSITION_COUNT_CMD_SUBADDR //!< @ref LTC2937_SP_COUNT "SP_COUNT"
#define LTC2937_SP_COUNT_SIZE 10
#define LTC2937_SP_COUNT_OFFSET 0
#define LTC2937_SP_COUNT_MSK 0x03FF
#define LTC2937_SP_COUNT (LTC2937_SP_COUNT_OFFSET << 12 | (LTC2937_SP_COUNT_SIZE - 1) << 8 | LTC2937_SP_COUNT_SUBADDR)
//!@}

/*! @defgroup LTC2937_MONITOR_BACKUP_CMD MONITOR_BACKUP_CMD
 *  @ingroup LTC2937_register_map
 *  @brief MONITOR_BACKUP_CMD Register
 *
 * |      15:13 |           12 |                11 |                10 |                 9 |                 8 |                 7 |                 6 |                 5 |                 4 |                 3 |                 2 |                 1 |                 0 |
 * |:----------:|:------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|:-----------------:|
 * | BU_SF_CHAN | BU_SVF_STATE | BU_V6_OV_SV_FAULT | BU_V6_UV_SV_FAULT | BU_V5_OV_SV_FAULT | BU_V5_UV_SV_FAULT | BU_V4_OV_SV_FAULT | BU_V4_UV_SV_FAULT | BU_V3_OV_SV_FAULT | BU_V3_UV_SV_FAULT | BU_V2_OV_SV_FAULT | BU_V2_UV_SV_FAULT | BU_V1_OV_SV_FAULT | BU_V1_UV_SV_FAULT |
 *
 *   - CommandCode: 47
 *   - Contains Bit Fields:
 *     + @ref LTC2937_BU_SF_CHAN "BU_SF_CHAN" : Reports the channel responsible for a sequence fault. If multiple channels fault, the lowest channel is reported.
 *     + @ref LTC2937_BU_SVF_STATE "BU_SVF_STATE" : Supervisor Fault status backup.
 *     + @ref LTC2937_BU_V6_OV_SV_FAULT "BU_V6_OV_SV_FAULT" : V6 OV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V6_UV_SV_FAULT "BU_V6_UV_SV_FAULT" : V6 UV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V5_OV_SV_FAULT "BU_V5_OV_SV_FAULT" : V5 OV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V5_UV_SV_FAULT "BU_V5_UV_SV_FAULT" : V5 UV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V4_OV_SV_FAULT "BU_V4_OV_SV_FAULT" : V4 OV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V4_UV_SV_FAULT "BU_V4_UV_SV_FAULT" : V4 UV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V3_OV_SV_FAULT "BU_V3_OV_SV_FAULT" : V3 OV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V3_UV_SV_FAULT "BU_V3_UV_SV_FAULT" : V3 UV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V2_OV_SV_FAULT "BU_V2_OV_SV_FAULT" : V2 OV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V2_UV_SV_FAULT "BU_V2_UV_SV_FAULT" : V2 UV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V1_OV_SV_FAULT "BU_V1_OV_SV_FAULT" : V1 OV Supervisor Fault backup.
 *     + @ref LTC2937_BU_V1_UV_SV_FAULT "BU_V1_UV_SV_FAULT" : V1 UV Supervisor Fault backup.
*/

//!@{
#define LTC2937_MONITOR_BACKUP_CMD_SUBADDR 47
#define LTC2937_MONITOR_BACKUP_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_MONITOR_BACKUP_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_BU_SF_CHAN BU_SF_CHAN
 *  @ingroup LTC2937_register_map
 *  @brief BU_SF_CHAN Bit Field
 *
 *  Reports the channel responsible for a sequence fault. If multiple channels fault, the lowest channel is reported.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 3
 *   - Offset: 13
 *   - MSB: 15
 *   - MASK: 0xE000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_SF_CHAN_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_SF_CHAN "BU_SF_CHAN"
#define LTC2937_BU_SF_CHAN_SIZE 3
#define LTC2937_BU_SF_CHAN_OFFSET 13
#define LTC2937_BU_SF_CHAN_MSK 0xE000
#define LTC2937_BU_SF_CHAN (LTC2937_BU_SF_CHAN_OFFSET << 12 | (LTC2937_BU_SF_CHAN_SIZE - 1) << 8 | LTC2937_BU_SF_CHAN_SUBADDR)
#define LTC2937_BU_SF_CHAN_PRESET_NONE 0
#define LTC2937_BU_SF_CHAN_PRESET_V1 1
#define LTC2937_BU_SF_CHAN_PRESET_V2 2
#define LTC2937_BU_SF_CHAN_PRESET_V3 3
#define LTC2937_BU_SF_CHAN_PRESET_V4 4
#define LTC2937_BU_SF_CHAN_PRESET_V5 5
#define LTC2937_BU_SF_CHAN_PRESET_V6 6
#define LTC2937_BU_SF_CHAN_PRESET_UNDEFINED 7
//!@}
/*! @defgroup LTC2937_BU_SVF_STATE BU_SVF_STATE
 *  @ingroup LTC2937_register_map
 *  @brief BU_SVF_STATE Bit Field
 *
 *  Supervisor Fault status backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 12
 *   - MSB: 12
 *   - MASK: 0x1000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_SVF_STATE_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_SVF_STATE "BU_SVF_STATE"
#define LTC2937_BU_SVF_STATE_SIZE 1
#define LTC2937_BU_SVF_STATE_OFFSET 12
#define LTC2937_BU_SVF_STATE_MSK 0x1000
#define LTC2937_BU_SVF_STATE (LTC2937_BU_SVF_STATE_OFFSET << 12 | (LTC2937_BU_SVF_STATE_SIZE - 1) << 8 | LTC2937_BU_SVF_STATE_SUBADDR)
#define LTC2937_BU_SVF_STATE_PRESET_SUPERVISOR_FAULT_HAS_NOT_OCCURRED 0
#define LTC2937_BU_SVF_STATE_PRESET_SUPERVISOR_FAULT_HAS_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V6_OV_SV_FAULT BU_V6_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V6_OV_SV_FAULT Bit Field
 *
 *  V6 OV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 11
 *   - MSB: 11
 *   - MASK: 0x0800
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V6_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V6_OV_SV_FAULT "BU_V6_OV_SV_FAULT"
#define LTC2937_BU_V6_OV_SV_FAULT_SIZE 1
#define LTC2937_BU_V6_OV_SV_FAULT_OFFSET 11
#define LTC2937_BU_V6_OV_SV_FAULT_MSK 0x0800
#define LTC2937_BU_V6_OV_SV_FAULT (LTC2937_BU_V6_OV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V6_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V6_OV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V6_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V6_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V6_UV_SV_FAULT BU_V6_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V6_UV_SV_FAULT Bit Field
 *
 *  V6 UV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V6_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V6_UV_SV_FAULT "BU_V6_UV_SV_FAULT"
#define LTC2937_BU_V6_UV_SV_FAULT_SIZE 1
#define LTC2937_BU_V6_UV_SV_FAULT_OFFSET 10
#define LTC2937_BU_V6_UV_SV_FAULT_MSK 0x0400
#define LTC2937_BU_V6_UV_SV_FAULT (LTC2937_BU_V6_UV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V6_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V6_UV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V6_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V6_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V5_OV_SV_FAULT BU_V5_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V5_OV_SV_FAULT Bit Field
 *
 *  V5 OV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 9
 *   - MSB: 9
 *   - MASK: 0x0200
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V5_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V5_OV_SV_FAULT "BU_V5_OV_SV_FAULT"
#define LTC2937_BU_V5_OV_SV_FAULT_SIZE 1
#define LTC2937_BU_V5_OV_SV_FAULT_OFFSET 9
#define LTC2937_BU_V5_OV_SV_FAULT_MSK 0x0200
#define LTC2937_BU_V5_OV_SV_FAULT (LTC2937_BU_V5_OV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V5_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V5_OV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V5_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V5_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V5_UV_SV_FAULT BU_V5_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V5_UV_SV_FAULT Bit Field
 *
 *  V5 UV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 8
 *   - MSB: 8
 *   - MASK: 0x0100
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V5_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V5_UV_SV_FAULT "BU_V5_UV_SV_FAULT"
#define LTC2937_BU_V5_UV_SV_FAULT_SIZE 1
#define LTC2937_BU_V5_UV_SV_FAULT_OFFSET 8
#define LTC2937_BU_V5_UV_SV_FAULT_MSK 0x0100
#define LTC2937_BU_V5_UV_SV_FAULT (LTC2937_BU_V5_UV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V5_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V5_UV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V5_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V5_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V4_OV_SV_FAULT BU_V4_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V4_OV_SV_FAULT Bit Field
 *
 *  V4 OV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 7
 *   - MSB: 7
 *   - MASK: 0x0080
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V4_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V4_OV_SV_FAULT "BU_V4_OV_SV_FAULT"
#define LTC2937_BU_V4_OV_SV_FAULT_SIZE 1
#define LTC2937_BU_V4_OV_SV_FAULT_OFFSET 7
#define LTC2937_BU_V4_OV_SV_FAULT_MSK 0x0080
#define LTC2937_BU_V4_OV_SV_FAULT (LTC2937_BU_V4_OV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V4_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V4_OV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V4_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V4_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V4_UV_SV_FAULT BU_V4_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V4_UV_SV_FAULT Bit Field
 *
 *  V4 UV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 6
 *   - MSB: 6
 *   - MASK: 0x0040
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V4_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V4_UV_SV_FAULT "BU_V4_UV_SV_FAULT"
#define LTC2937_BU_V4_UV_SV_FAULT_SIZE 1
#define LTC2937_BU_V4_UV_SV_FAULT_OFFSET 6
#define LTC2937_BU_V4_UV_SV_FAULT_MSK 0x0040
#define LTC2937_BU_V4_UV_SV_FAULT (LTC2937_BU_V4_UV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V4_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V4_UV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V4_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V4_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V3_OV_SV_FAULT BU_V3_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V3_OV_SV_FAULT Bit Field
 *
 *  V3 OV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 5
 *   - MSB: 5
 *   - MASK: 0x0020
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V3_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V3_OV_SV_FAULT "BU_V3_OV_SV_FAULT"
#define LTC2937_BU_V3_OV_SV_FAULT_SIZE 1
#define LTC2937_BU_V3_OV_SV_FAULT_OFFSET 5
#define LTC2937_BU_V3_OV_SV_FAULT_MSK 0x0020
#define LTC2937_BU_V3_OV_SV_FAULT (LTC2937_BU_V3_OV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V3_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V3_OV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V3_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V3_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V3_UV_SV_FAULT BU_V3_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V3_UV_SV_FAULT Bit Field
 *
 *  V3 UV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 4
 *   - MSB: 4
 *   - MASK: 0x0010
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V3_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V3_UV_SV_FAULT "BU_V3_UV_SV_FAULT"
#define LTC2937_BU_V3_UV_SV_FAULT_SIZE 1
#define LTC2937_BU_V3_UV_SV_FAULT_OFFSET 4
#define LTC2937_BU_V3_UV_SV_FAULT_MSK 0x0010
#define LTC2937_BU_V3_UV_SV_FAULT (LTC2937_BU_V3_UV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V3_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V3_UV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V3_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V3_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V2_OV_SV_FAULT BU_V2_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V2_OV_SV_FAULT Bit Field
 *
 *  V2 OV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 3
 *   - MSB: 3
 *   - MASK: 0x0008
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V2_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V2_OV_SV_FAULT "BU_V2_OV_SV_FAULT"
#define LTC2937_BU_V2_OV_SV_FAULT_SIZE 1
#define LTC2937_BU_V2_OV_SV_FAULT_OFFSET 3
#define LTC2937_BU_V2_OV_SV_FAULT_MSK 0x0008
#define LTC2937_BU_V2_OV_SV_FAULT (LTC2937_BU_V2_OV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V2_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V2_OV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V2_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V2_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V2_UV_SV_FAULT BU_V2_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V2_UV_SV_FAULT Bit Field
 *
 *  V2 UV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 2
 *   - MSB: 2
 *   - MASK: 0x0004
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V2_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V2_UV_SV_FAULT "BU_V2_UV_SV_FAULT"
#define LTC2937_BU_V2_UV_SV_FAULT_SIZE 1
#define LTC2937_BU_V2_UV_SV_FAULT_OFFSET 2
#define LTC2937_BU_V2_UV_SV_FAULT_MSK 0x0004
#define LTC2937_BU_V2_UV_SV_FAULT (LTC2937_BU_V2_UV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V2_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V2_UV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V2_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V2_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V1_OV_SV_FAULT BU_V1_OV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V1_OV_SV_FAULT Bit Field
 *
 *  V1 OV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V1_OV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V1_OV_SV_FAULT "BU_V1_OV_SV_FAULT"
#define LTC2937_BU_V1_OV_SV_FAULT_SIZE 1
#define LTC2937_BU_V1_OV_SV_FAULT_OFFSET 1
#define LTC2937_BU_V1_OV_SV_FAULT_MSK 0x0002
#define LTC2937_BU_V1_OV_SV_FAULT (LTC2937_BU_V1_OV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V1_OV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V1_OV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V1_OV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V1_OV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}
/*! @defgroup LTC2937_BU_V1_UV_SV_FAULT BU_V1_UV_SV_FAULT
 *  @ingroup LTC2937_register_map
 *  @brief BU_V1_UV_SV_FAULT Bit Field
 *
 *  V1 UV Supervisor Fault backup.
 *   - Register: @ref LTC2937_MONITOR_BACKUP_CMD "MONITOR_BACKUP_CMD"
 *   - CommandCode: 47
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_BU_V1_UV_SV_FAULT_SUBADDR LTC2937_MONITOR_BACKUP_CMD_SUBADDR //!< @ref LTC2937_BU_V1_UV_SV_FAULT "BU_V1_UV_SV_FAULT"
#define LTC2937_BU_V1_UV_SV_FAULT_SIZE 1
#define LTC2937_BU_V1_UV_SV_FAULT_OFFSET 0
#define LTC2937_BU_V1_UV_SV_FAULT_MSK 0x0001
#define LTC2937_BU_V1_UV_SV_FAULT (LTC2937_BU_V1_UV_SV_FAULT_OFFSET << 12 | (LTC2937_BU_V1_UV_SV_FAULT_SIZE - 1) << 8 | LTC2937_BU_V1_UV_SV_FAULT_SUBADDR)
#define LTC2937_BU_V1_UV_SV_FAULT_PRESET_NO_FAULT 0
#define LTC2937_BU_V1_UV_SV_FAULT_PRESET_FAULT_OCCURRED 1
//!@}

/*! @defgroup LTC2937_MONITOR_STATUS_CMD MONITOR_STATUS_CMD
 *  @ingroup LTC2937_register_map
 *  @brief MONITOR_STATUS_CMD Register
 *
 * | 15:14 |            13 |          12 |           11 |           10 |            9 |            8 |            7 |            6 |            5 |            4 |            3 |            2 |            1 |            0 |
 * |:-----:|:-------------:|:-----------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|:------------:|
 * |   n/a | MARGIN_STATUS | RSTB_STATUS | V6_OV_STATUS | V6_UV_STATUS | V5_OV_STATUS | V5_UV_STATUS | V4_OV_STATUS | V4_UV_STATUS | V3_OV_STATUS | V3_UV_STATUS | V2_OV_STATUS | V2_UV_STATUS | V1_OV_STATUS | V1_UV_STATUS |
 *
 *   - CommandCode: 48
 *   - Contains Bit Fields:
 *     + @ref LTC2937_MARGIN_STATUS "MARGIN_STATUS" : Logical representation of external margb input and/or i2c margin bit.
 *     + @ref LTC2937_RSTB_STATUS "RSTB_STATUS" : Status of the RSTB pin.
 *     + @ref LTC2937_V6_OV_STATUS "V6_OV_STATUS" : V6 OV comparator live status.
 *     + @ref LTC2937_V6_UV_STATUS "V6_UV_STATUS" : V6 UV comparator live status.
 *     + @ref LTC2937_V5_OV_STATUS "V5_OV_STATUS" : V5 OV comparator live status.
 *     + @ref LTC2937_V5_UV_STATUS "V5_UV_STATUS" : V5 UV comparator live status.
 *     + @ref LTC2937_V4_OV_STATUS "V4_OV_STATUS" : V4 OV comparator live status.
 *     + @ref LTC2937_V4_UV_STATUS "V4_UV_STATUS" : V4 UV comparator live status.
 *     + @ref LTC2937_V3_OV_STATUS "V3_OV_STATUS" : V3 OV comparator live status.
 *     + @ref LTC2937_V3_UV_STATUS "V3_UV_STATUS" : V3 UV comparator live status.
 *     + @ref LTC2937_V2_OV_STATUS "V2_OV_STATUS" : V2 OV comparator live status.
 *     + @ref LTC2937_V2_UV_STATUS "V2_UV_STATUS" : V2 UV comparator live status.
 *     + @ref LTC2937_V1_OV_STATUS "V1_OV_STATUS" : V1 OV comparator live status.
 *     + @ref LTC2937_V1_UV_STATUS "V1_UV_STATUS" : V1 UV comparator live status.
*/

//!@{
#define LTC2937_MONITOR_STATUS_CMD_SUBADDR 48
#define LTC2937_MONITOR_STATUS_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_MONITOR_STATUS_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_MARGIN_STATUS MARGIN_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief MARGIN_STATUS Bit Field
 *
 *  Logical representation of external margb input and/or i2c margin bit.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 13
 *   - MSB: 13
 *   - MASK: 0x2000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_MARGIN_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_MARGIN_STATUS "MARGIN_STATUS"
#define LTC2937_MARGIN_STATUS_SIZE 1
#define LTC2937_MARGIN_STATUS_OFFSET 13
#define LTC2937_MARGIN_STATUS_MSK 0x2000
#define LTC2937_MARGIN_STATUS (LTC2937_MARGIN_STATUS_OFFSET << 12 | (LTC2937_MARGIN_STATUS_SIZE - 1) << 8 | LTC2937_MARGIN_STATUS_SUBADDR)
#define LTC2937_MARGIN_STATUS_PRESET_MARGIN_FUNCTION_INACTIVE 0
#define LTC2937_MARGIN_STATUS_PRESET_MARGIN_FUNCTION_ACTIVE 1
//!@}
/*! @defgroup LTC2937_RSTB_STATUS RSTB_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief RSTB_STATUS Bit Field
 *
 *  Status of the RSTB pin.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 12
 *   - MSB: 12
 *   - MASK: 0x1000
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_RSTB_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_RSTB_STATUS "RSTB_STATUS"
#define LTC2937_RSTB_STATUS_SIZE 1
#define LTC2937_RSTB_STATUS_OFFSET 12
#define LTC2937_RSTB_STATUS_MSK 0x1000
#define LTC2937_RSTB_STATUS (LTC2937_RSTB_STATUS_OFFSET << 12 | (LTC2937_RSTB_STATUS_SIZE - 1) << 8 | LTC2937_RSTB_STATUS_SUBADDR)
#define LTC2937_RSTB_STATUS_PRESET_RSTB_IS_HIGH 0
#define LTC2937_RSTB_STATUS_PRESET_RSTB_IS_LOW 1
//!@}
/*! @defgroup LTC2937_V6_OV_STATUS V6_OV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V6_OV_STATUS Bit Field
 *
 *  V6 OV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 11
 *   - MSB: 11
 *   - MASK: 0x0800
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V6_OV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V6_OV_STATUS "V6_OV_STATUS"
#define LTC2937_V6_OV_STATUS_SIZE 1
#define LTC2937_V6_OV_STATUS_OFFSET 11
#define LTC2937_V6_OV_STATUS_MSK 0x0800
#define LTC2937_V6_OV_STATUS (LTC2937_V6_OV_STATUS_OFFSET << 12 | (LTC2937_V6_OV_STATUS_SIZE - 1) << 8 | LTC2937_V6_OV_STATUS_SUBADDR)
#define LTC2937_V6_OV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V6_OV_STATUS_PRESET_HIGH_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V6_UV_STATUS V6_UV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V6_UV_STATUS Bit Field
 *
 *  V6 UV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 10
 *   - MSB: 10
 *   - MASK: 0x0400
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V6_UV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V6_UV_STATUS "V6_UV_STATUS"
#define LTC2937_V6_UV_STATUS_SIZE 1
#define LTC2937_V6_UV_STATUS_OFFSET 10
#define LTC2937_V6_UV_STATUS_MSK 0x0400
#define LTC2937_V6_UV_STATUS (LTC2937_V6_UV_STATUS_OFFSET << 12 | (LTC2937_V6_UV_STATUS_SIZE - 1) << 8 | LTC2937_V6_UV_STATUS_SUBADDR)
#define LTC2937_V6_UV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V6_UV_STATUS_PRESET_LOW_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V5_OV_STATUS V5_OV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V5_OV_STATUS Bit Field
 *
 *  V5 OV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 9
 *   - MSB: 9
 *   - MASK: 0x0200
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V5_OV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V5_OV_STATUS "V5_OV_STATUS"
#define LTC2937_V5_OV_STATUS_SIZE 1
#define LTC2937_V5_OV_STATUS_OFFSET 9
#define LTC2937_V5_OV_STATUS_MSK 0x0200
#define LTC2937_V5_OV_STATUS (LTC2937_V5_OV_STATUS_OFFSET << 12 | (LTC2937_V5_OV_STATUS_SIZE - 1) << 8 | LTC2937_V5_OV_STATUS_SUBADDR)
#define LTC2937_V5_OV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V5_OV_STATUS_PRESET_HIGH_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V5_UV_STATUS V5_UV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V5_UV_STATUS Bit Field
 *
 *  V5 UV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 8
 *   - MSB: 8
 *   - MASK: 0x0100
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V5_UV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V5_UV_STATUS "V5_UV_STATUS"
#define LTC2937_V5_UV_STATUS_SIZE 1
#define LTC2937_V5_UV_STATUS_OFFSET 8
#define LTC2937_V5_UV_STATUS_MSK 0x0100
#define LTC2937_V5_UV_STATUS (LTC2937_V5_UV_STATUS_OFFSET << 12 | (LTC2937_V5_UV_STATUS_SIZE - 1) << 8 | LTC2937_V5_UV_STATUS_SUBADDR)
#define LTC2937_V5_UV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V5_UV_STATUS_PRESET_LOW_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V4_OV_STATUS V4_OV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V4_OV_STATUS Bit Field
 *
 *  V4 OV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 7
 *   - MSB: 7
 *   - MASK: 0x0080
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V4_OV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V4_OV_STATUS "V4_OV_STATUS"
#define LTC2937_V4_OV_STATUS_SIZE 1
#define LTC2937_V4_OV_STATUS_OFFSET 7
#define LTC2937_V4_OV_STATUS_MSK 0x0080
#define LTC2937_V4_OV_STATUS (LTC2937_V4_OV_STATUS_OFFSET << 12 | (LTC2937_V4_OV_STATUS_SIZE - 1) << 8 | LTC2937_V4_OV_STATUS_SUBADDR)
#define LTC2937_V4_OV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V4_OV_STATUS_PRESET_HIGH_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V4_UV_STATUS V4_UV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V4_UV_STATUS Bit Field
 *
 *  V4 UV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 6
 *   - MSB: 6
 *   - MASK: 0x0040
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V4_UV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V4_UV_STATUS "V4_UV_STATUS"
#define LTC2937_V4_UV_STATUS_SIZE 1
#define LTC2937_V4_UV_STATUS_OFFSET 6
#define LTC2937_V4_UV_STATUS_MSK 0x0040
#define LTC2937_V4_UV_STATUS (LTC2937_V4_UV_STATUS_OFFSET << 12 | (LTC2937_V4_UV_STATUS_SIZE - 1) << 8 | LTC2937_V4_UV_STATUS_SUBADDR)
#define LTC2937_V4_UV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V4_UV_STATUS_PRESET_LOW_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V3_OV_STATUS V3_OV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V3_OV_STATUS Bit Field
 *
 *  V3 OV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 5
 *   - MSB: 5
 *   - MASK: 0x0020
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V3_OV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V3_OV_STATUS "V3_OV_STATUS"
#define LTC2937_V3_OV_STATUS_SIZE 1
#define LTC2937_V3_OV_STATUS_OFFSET 5
#define LTC2937_V3_OV_STATUS_MSK 0x0020
#define LTC2937_V3_OV_STATUS (LTC2937_V3_OV_STATUS_OFFSET << 12 | (LTC2937_V3_OV_STATUS_SIZE - 1) << 8 | LTC2937_V3_OV_STATUS_SUBADDR)
#define LTC2937_V3_OV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V3_OV_STATUS_PRESET_HIGH_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V3_UV_STATUS V3_UV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V3_UV_STATUS Bit Field
 *
 *  V3 UV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 4
 *   - MSB: 4
 *   - MASK: 0x0010
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V3_UV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V3_UV_STATUS "V3_UV_STATUS"
#define LTC2937_V3_UV_STATUS_SIZE 1
#define LTC2937_V3_UV_STATUS_OFFSET 4
#define LTC2937_V3_UV_STATUS_MSK 0x0010
#define LTC2937_V3_UV_STATUS (LTC2937_V3_UV_STATUS_OFFSET << 12 | (LTC2937_V3_UV_STATUS_SIZE - 1) << 8 | LTC2937_V3_UV_STATUS_SUBADDR)
#define LTC2937_V3_UV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V3_UV_STATUS_PRESET_LOW_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V2_OV_STATUS V2_OV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V2_OV_STATUS Bit Field
 *
 *  V2 OV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 3
 *   - MSB: 3
 *   - MASK: 0x0008
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V2_OV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V2_OV_STATUS "V2_OV_STATUS"
#define LTC2937_V2_OV_STATUS_SIZE 1
#define LTC2937_V2_OV_STATUS_OFFSET 3
#define LTC2937_V2_OV_STATUS_MSK 0x0008
#define LTC2937_V2_OV_STATUS (LTC2937_V2_OV_STATUS_OFFSET << 12 | (LTC2937_V2_OV_STATUS_SIZE - 1) << 8 | LTC2937_V2_OV_STATUS_SUBADDR)
#define LTC2937_V2_OV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V2_OV_STATUS_PRESET_HIGH_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V2_UV_STATUS V2_UV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V2_UV_STATUS Bit Field
 *
 *  V2 UV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 2
 *   - MSB: 2
 *   - MASK: 0x0004
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V2_UV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V2_UV_STATUS "V2_UV_STATUS"
#define LTC2937_V2_UV_STATUS_SIZE 1
#define LTC2937_V2_UV_STATUS_OFFSET 2
#define LTC2937_V2_UV_STATUS_MSK 0x0004
#define LTC2937_V2_UV_STATUS (LTC2937_V2_UV_STATUS_OFFSET << 12 | (LTC2937_V2_UV_STATUS_SIZE - 1) << 8 | LTC2937_V2_UV_STATUS_SUBADDR)
#define LTC2937_V2_UV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V2_UV_STATUS_PRESET_LOW_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V1_OV_STATUS V1_OV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V1_OV_STATUS Bit Field
 *
 *  V1 OV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 1
 *   - MSB: 1
 *   - MASK: 0x0002
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V1_OV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V1_OV_STATUS "V1_OV_STATUS"
#define LTC2937_V1_OV_STATUS_SIZE 1
#define LTC2937_V1_OV_STATUS_OFFSET 1
#define LTC2937_V1_OV_STATUS_MSK 0x0002
#define LTC2937_V1_OV_STATUS (LTC2937_V1_OV_STATUS_OFFSET << 12 | (LTC2937_V1_OV_STATUS_SIZE - 1) << 8 | LTC2937_V1_OV_STATUS_SUBADDR)
#define LTC2937_V1_OV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V1_OV_STATUS_PRESET_HIGH_LIMIT_VIOLATION 1
//!@}
/*! @defgroup LTC2937_V1_UV_STATUS V1_UV_STATUS
 *  @ingroup LTC2937_register_map
 *  @brief V1_UV_STATUS Bit Field
 *
 *  V1 UV comparator live status.
 *   - Register: @ref LTC2937_MONITOR_STATUS_CMD "MONITOR_STATUS_CMD"
 *   - CommandCode: 48
 *   - Size: 1
 *   - Offset: 0
 *   - MSB: 0
 *   - MASK: 0x0001
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_V1_UV_STATUS_SUBADDR LTC2937_MONITOR_STATUS_CMD_SUBADDR //!< @ref LTC2937_V1_UV_STATUS "V1_UV_STATUS"
#define LTC2937_V1_UV_STATUS_SIZE 1
#define LTC2937_V1_UV_STATUS_OFFSET 0
#define LTC2937_V1_UV_STATUS_MSK 0x0001
#define LTC2937_V1_UV_STATUS (LTC2937_V1_UV_STATUS_OFFSET << 12 | (LTC2937_V1_UV_STATUS_SIZE - 1) << 8 | LTC2937_V1_UV_STATUS_SUBADDR)
#define LTC2937_V1_UV_STATUS_PRESET_NO_VIOLATION 0
#define LTC2937_V1_UV_STATUS_PRESET_LOW_LIMIT_VIOLATION 1
//!@}

/*! @defgroup LTC2937_DEVICE_ID_CMD DEVICE_ID_CMD
 *  @ingroup LTC2937_register_map
 *  @brief DEVICE_ID_CMD Register
 *
 * |      15:0 |
 * |:---------:|
 * | DEVICE_ID |
 *
 *   - CommandCode: 49
 *   - Contains Bit Fields:
 *     + @ref LTC2937_DEVICE_ID "DEVICE_ID" : Contents of DEVICE_ID = 0x2937
*/

//!@{
#define LTC2937_DEVICE_ID_CMD_SUBADDR 49
#define LTC2937_DEVICE_ID_CMD (0 << 12 | (16 - 1) << 8 | LTC2937_DEVICE_ID_CMD_SUBADDR)
//!@}
/*! @defgroup LTC2937_DEVICE_ID DEVICE_ID
 *  @ingroup LTC2937_register_map
 *  @brief DEVICE_ID Bit Field
 *
 *  Contents of DEVICE_ID = 0x2937
 *   - Register: @ref LTC2937_DEVICE_ID_CMD "DEVICE_ID_CMD"
 *   - CommandCode: 49
 *   - Size: 16
 *   - Offset: 0
 *   - MSB: 15
 *   - MASK: 0xFFFF
 *   - Access: R
 *   - Default: n/a
 */
//!@{
#define LTC2937_DEVICE_ID_SUBADDR LTC2937_DEVICE_ID_CMD_SUBADDR //!< @ref LTC2937_DEVICE_ID "DEVICE_ID"
#define LTC2937_DEVICE_ID_SIZE 16
#define LTC2937_DEVICE_ID_OFFSET 0
#define LTC2937_DEVICE_ID_MSK 0xFFFF
#define LTC2937_DEVICE_ID (LTC2937_DEVICE_ID_OFFSET << 12 | (LTC2937_DEVICE_ID_SIZE - 1) << 8 | LTC2937_DEVICE_ID_SUBADDR)
//!@}

#endif
